(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    358168,       9563]
NotebookOptionsPosition[    343617,       9123]
NotebookOutlinePosition[    344168,       9145]
CellTagsIndexPosition[    344125,       9142]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Exit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.651218426338436*^9, 3.6512184284984703`*^9}}],

Cell[TextData[{
 StyleBox["HR system with live gauges and parameter fixing. \nBuild General \
L2 solution for LF system ",
  FontWeight->"Bold"],
 StyleBox["without",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" boundary frame.\n",
  FontWeight->"Bold"],
 StyleBox["David Hilditch and Milton Ruiz.\n ",
  FontSlant->"Italic"],
 StyleBox["In this notebook we construct the L2-solution for generic gauges \
for which we use the preferred choice \n of the formulation of \
[arXiv:1303.4783].",
  FontSize->16]
}], "Subtitle",
 CellChangeTimes->{{3.530345106049459*^9, 3.530345117173244*^9}, {
   3.536995309680488*^9, 3.536995313709453*^9}, 3.5372623602272997`*^9, {
   3.5472123969042664`*^9, 3.547212407211228*^9}, {3.5483997446856956`*^9, 
   3.548399750808976*^9}, {3.651173859883544*^9, 3.651173861961891*^9}, {
   3.6513767653477583`*^9, 3.651376765687461*^9}, {3.651428363782976*^9, 
   3.651428364334887*^9}, {3.6514284082689953`*^9, 3.6514284094535913`*^9}, {
   3.651428445677929*^9, 3.6514284465650663`*^9}, {3.6514307380135527`*^9, 
   3.6514307504933023`*^9}, {3.651675705705524*^9, 3.651675705819215*^9}, {
   3.652789705818685*^9, 3.652789729993272*^9}, {3.6527897981531143`*^9, 
   3.65278980104867*^9}, {3.6530407726560802`*^9, 3.6530408073128567`*^9}, {
   3.6732301023142023`*^9, 3.673230282146158*^9}, 3.673230319486923*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Setup ",
 StyleBox["preferred",
  FontSlant->"Italic"],
 " formulation as in [arXiv:1303.4783]."
}], "Subsection",
 CellChangeTimes->{{3.652797361526671*^9, 3.652797369522779*^9}, {
  3.652797542933208*^9, 3.652797556344241*^9}, {3.652797723717732*^9, 
  3.6527977653599*^9}, {3.6528160472618*^9, 3.652816047623438*^9}, {
  3.653040653172439*^9, 3.6530406626505423`*^9}}],

Cell[CellGroupData[{

Cell["Laplace-Fourier transformation of the Gauge EoMs", "Text",
 CellChangeTimes->{{3.652784236480344*^9, 3.652784239962298*^9}, {
  3.6732297493462067`*^9, 3.673229750297332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaugeEoMs", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"\[Alpha]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "g1"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Kss", "[", "x", "]"}], "+", 
          RowBox[{"Kqq", "[", "x", "]"}]}], ")"}]}], "+", 
       RowBox[{"g2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Beta]s", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", "c1", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"\[Beta]s", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"\[Beta]s", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"g3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gss", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"gs\[Omega]", "[", "x", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"g4", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gss", "'"}], "[", "x", "]"}], "+", 
          RowBox[{
           RowBox[{"gqq", "'"}], "[", "x", "]"}]}], ")"}]}], "-", 
       RowBox[{"g5", " ", 
        RowBox[{
         RowBox[{"\[Alpha]", "'"}], "[", "x", "]"}]}], "+", 
       RowBox[{"2", "c2", " ", 
        RowBox[{"Zs", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"\[Beta]\[Omega]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"g3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gs\[Omega]", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"gqq", "[", "x", "]"}], "-", 
             RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{"g4", " ", "I", " ", "\[Omega]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gss", "[", "x", "]"}], "+", 
          RowBox[{"gqq", "[", "x", "]"}]}], ")"}]}], "-", 
       RowBox[{"g5", " ", "I", " ", "\[Omega]", " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}], "+", 
       RowBox[{"2", "c2", " ", 
        RowBox[{"Z\[Omega]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"\[Beta]\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"g3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gs\[Nu]", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", "c2", " ", 
        RowBox[{"Z\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652784044501865*^9, 3.6527842075902433`*^9}, {
  3.652784362252232*^9, 3.652784364225174*^9}, {3.6527844149687433`*^9, 
  3.6527845320299892`*^9}, {3.652785732073542*^9, 3.6527857625247097`*^9}, {
  3.652785913180176*^9, 3.6527859433121977`*^9}, {3.652786029675954*^9, 
  3.6527860560678673`*^9}, {3.652787507758995*^9, 3.652787514056611*^9}, {
  3.652787679421596*^9, 3.652787682594412*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Laplace-Fourier transformation of Metric EoMs", "Text",
 CellChangeTimes->{{3.652787224964044*^9, 3.652787230119459*^9}, {
  3.673230467082171*^9, 3.673230467426326*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MetricEoMs", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"gss", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"gss", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"Kss", "[", "x", "]"}]}], "+", 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"\[Beta]s", "'"}], "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "3"}], "c3", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"gqq", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"gqq", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"Kqq", "[", "x", "]"}]}], "+", 
       RowBox[{"2", "I", " ", "\[Omega]", " ", 
        RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"2", "/", "3"}], "c3", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"gs\[Omega]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"gs\[Omega]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"Ks\[Omega]", "[", "x", "]"}]}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"\[Beta]s", "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Beta]\[Omega]", "'"}], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"gs\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"gs\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"Ks\[Nu]", "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Beta]\[Nu]", "'"}], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"g\[Omega]\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"K\[Omega]\[Nu]", "[", "x", "]"}]}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"g\[Nu]\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"K\[Nu]\[Nu]", "[", "x", "]"}]}]}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.652787234269599*^9, 3.652787263322262*^9}, {
  3.652787301978957*^9, 3.652787482902459*^9}, {3.652787521691478*^9, 
  3.6527875977896557`*^9}, {3.652787629661603*^9, 3.652787655917136*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Rules to remove constraints", "Text",
 CellChangeTimes->{{3.652788902935603*^9, 3.652788914964048*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VariablesToRemove", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Kss", "[", "x", "]"}], ",", 
     RowBox[{"Kqq", "[", "x", "]"}], ",", 
     RowBox[{"Ks\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"Ks\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"K\[Omega]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"K\[Nu]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "x", "]"}], ",", 
     RowBox[{"Zs", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Nu]", "[", "x", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652787729885627*^9, 3.652787813520224*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RemoveKContraintRules", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Union", "[", 
          RowBox[{"MetricEoMs", ",", "GaugeEoMs"}], "]"}], "//", "Flatten"}], 
        ")"}], ",", "VariablesToRemove"}], "]"}], "//", "Simplify"}], "//", 
    "Flatten"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652787699726358*^9, 3.652787724527939*^9}, {
  3.652787818443407*^9, 3.652787859713953*^9}, {3.6527879406922503`*^9, 
  3.65278795873978*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DRemoveKContraintRules", "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], "RemoveKContraintRules"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.652788023094966*^9, 3.652788037104641*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HamMomRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gss", "''"}], "[", "x", "]"}], "+", 
          RowBox[{
           RowBox[{"gqq", "''"}], "[", "x", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"\[Omega]", "^", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gss", "[", "x", "]"}], "+", 
          RowBox[{"gqq", "[", "x", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"gss", "''"}], "[", "x", "]"}], "-", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gqq", "[", "x", "]"}], "-", 
          RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], ")"}]}], "+", 
       RowBox[{"2", "I", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"gs\[Omega]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"Ms", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"Ks\[Omega]", "[", "x", "]"}]}], "-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], 
        RowBox[{"Kqq", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"M\[Omega]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Ks\[Omega]", "'"}], "[", "x", "]"}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Kqq", "[", "x", "]"}], "-", 
          RowBox[{"K\[Nu]\[Nu]", "[", "x", "]"}]}], ")"}]}], "-", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Kss", "[", "x", "]"}], "+", 
          RowBox[{"Kqq", "[", "x", "]"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"M\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Ks\[Nu]", "'"}], "[", "x", "]"}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{"K\[Omega]\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.652788252500123*^9, 3.652788256269866*^9}, {
   3.652788294237462*^9, 3.65278830452535*^9}, 3.652788526213192*^9, {
   3.6527885831209583`*^9, 3.652788627377926*^9}, {3.652788709543894*^9, 
   3.652788710154241*^9}, {3.6527887857556973`*^9, 3.6527887934896383`*^9}, {
   3.6527888712534103`*^9, 3.6527888783196363`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Rules to remove Ricci", "Text",
 CellChangeTimes->{{3.652789491137385*^9, 3.652789498469211*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RicciRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Rss", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"gss", "[", "x", "]"}]}], "-", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{
         RowBox[{"gqq", "''"}], "[", "x", "]"}]}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"gs\[Omega]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"Rqq", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], 
        RowBox[{
         RowBox[{"gqq", "''"}], "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"gss", "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], "+", 
       RowBox[{"I", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"gs\[Omega]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"Rs\[Omega]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], "I", " ", "\[Omega]", " ", 
       RowBox[{
        RowBox[{"g\[Nu]\[Nu]", "'"}], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Rs\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"gs\[Nu]", "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "I", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"g\[Omega]\[Nu]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"R\[Omega]\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], 
        RowBox[{
         RowBox[{"g\[Omega]\[Nu]", "''"}], "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "I", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"gs\[Nu]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"R\[Nu]\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], 
        RowBox[{
         RowBox[{"g\[Nu]\[Nu]", "''"}], "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.652789500178644*^9, 3.652789513894575*^9}, {
  3.652796691966235*^9, 3.652796911681994*^9}, {3.6527969435514183`*^9, 
  3.6527971638404293`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Laplace-Fourier transformation of Constraint EoMs", "Text",
 CellChangeTimes->{{3.652786069544407*^9, 3.652786074066617*^9}, {
  3.673230489409606*^9, 3.673230490025672*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConstraintEoMs", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"\[Theta]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"c7", " ", 
        RowBox[{"H", "[", "x", "]"}]}], "+", 
       RowBox[{"c8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Zs", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"Z\[Omega]", "[", "x", "]"}]}]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Zs", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Zs", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"c9", " ", 
        RowBox[{"Ms", "[", "x", "]"}]}], "+", 
       RowBox[{"c10", " ", 
        RowBox[{
         RowBox[{"\[Theta]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Z\[Omega]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Z\[Omega]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"c9", " ", 
        RowBox[{"M\[Omega]", "[", "x", "]"}]}], "+", 
       RowBox[{"c10", " ", "I", " ", "\[Omega]", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Z\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Z\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{"c9", " ", 
       RowBox[{"M\[Nu]", "[", "x", "]"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6527860902648087`*^9, 3.652786124854333*^9}, {
   3.652786166190013*^9, 3.652786166837224*^9}, {3.6527862000930853`*^9, 
   3.652786308577427*^9}, 3.6527868383044577`*^9, {3.6527870621279097`*^9, 
   3.6527870860251503`*^9}, {3.652787662126279*^9, 3.652787668565598*^9}, {
   3.652813155892021*^9, 3.65281317525696*^9}, {3.652813946943898*^9, 
   3.6528139613744507`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Extrinsic curvature EoMs", "Text",
 CellChangeTimes->{{3.6527890307429533`*^9, 3.652789037882169*^9}, {
  3.65281318905935*^9, 3.652813189737925*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"KEoMs", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Kss", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Kss", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"\[Alpha]", "''"}], "[", "x", "]"}]}], "+", 
       RowBox[{"Rss", "[", "x", "]"}], "+", 
       RowBox[{"2", "c4", " ", 
        RowBox[{
         RowBox[{"Zs", "'"}], "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "3"}], "c5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Zs", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"Z\[Omega]", "[", "x", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", "3"}], "c6", " ", 
        RowBox[{"H", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Kqq", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Kqq", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"+", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}], "+", 
       RowBox[{"Rqq", "[", "x", "]"}], "+", 
       RowBox[{"2", "c4", " ", "I", " ", "\[Omega]", " ", 
        RowBox[{"Z\[Omega]", "[", "x", "]"}]}], "+", 
       RowBox[{
        RowBox[{"2", "/", "3"}], "c5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Zs", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"Z\[Omega]", "[", "x", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"2", "/", "3"}], "c6", " ", 
        RowBox[{"H", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Ks\[Omega]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Ks\[Omega]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"\[Alpha]", "'"}], "[", "x", "]"}]}], "+", 
       RowBox[{"Rs\[Omega]", "[", "x", "]"}], "+", 
       RowBox[{"c4", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Z\[Omega]", "'"}], "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]", " ", 
           RowBox[{"Zs", "[", "x", "]"}]}]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"Ks\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"Ks\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"Rs\[Nu]", "[", "x", "]"}], "+", 
       RowBox[{"c4", " ", 
        RowBox[{
         RowBox[{"Z\[Nu]", "'"}], "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"K\[Omega]\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"K\[Omega]\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"R\[Omega]\[Nu]", "[", "x", "]"}], "+", 
       RowBox[{"c4", " ", "I", " ", "\[Omega]", " ", 
        RowBox[{"Z\[Nu]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"s", " ", 
        RowBox[{"K\[Nu]\[Nu]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{
         RowBox[{"K\[Nu]\[Nu]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{"R\[Nu]\[Nu]", "[", "x", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652789026255311*^9, 3.65278921802382*^9}, {
   3.652789248030675*^9, 3.652789476715047*^9}, {3.6528137031495943`*^9, 
   3.652813727727191*^9}, 3.65281536492871*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListEMRaw", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"KEoMs", ",", "ConstraintEoMs"}], "]"}], "//", "Flatten"}],
          ")"}], "/.", "HamMomRules"}], "/.", "DRemoveKContraintRules"}], "/.",
       "RemoveKContraintRules"}], "/.", "RicciRules"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.652789560252726*^9, 3.6527896415918207`*^9}, {
  3.652789747367648*^9, 3.652789749829278*^9}, {3.6527972056001*^9, 
  3.652797207378607*^9}, {3.652797294666622*^9, 3.6527973270301247`*^9}, {
  3.652797569243013*^9, 3.6527975769441957`*^9}, {3.652799344101552*^9, 
  3.6527993445239162`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Fix a few parameters to ensure strong hyperbolicity   of  the  constraint  \
subsystem  
with vanishing gauge-constraint coupling\
\>", "Text",
 CellChangeTimes->{{3.673230543706362*^9, 3.67323054918359*^9}, {
  3.6732306767830973`*^9, 3.67323070473006*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c1", "=", "g1"}], ";", 
  RowBox[{"c2", "=", "g3"}], ";", 
  RowBox[{"c3", "=", "0"}], ";", 
  RowBox[{"c4", "=", "1"}], ";", 
  RowBox[{"c5", "=", "0"}], ";", 
  RowBox[{"c6", "=", "0"}], ";", 
  RowBox[{"c7", "=", 
   RowBox[{"1", "/", "2"}]}], ";", 
  RowBox[{"c8", "=", "1"}], ";", 
  RowBox[{"c9", "=", "1"}], ";", 
  RowBox[{"c10", "=", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"g4", "/", "g3"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652799328461409*^9, 3.6527993323030577`*^9}, {
  3.652814136600006*^9, 3.652814141968618*^9}, {3.653040680143187*^9, 
  3.6530406995257893`*^9}, {3.653040731425549*^9, 3.653040755831924*^9}, {
  3.65304108063342*^9, 3.6530410832088757`*^9}, {3.653041573065987*^9, 
  3.653041574680408*^9}, {3.6530419667451973`*^9, 3.653041979202304*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Puncture gauge rule", "Text",
 CellChangeTimes->{{3.67323080075383*^9, 3.673230816348571*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToPunctureNotationRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g1", "\[Rule]", "\[Mu]L"}], ",", 
     RowBox[{"g2", "\[Rule]", "0"}], ",", 
     RowBox[{"g3", "\[Rule]", "\[Mu]S"}], ",", 
     RowBox[{"g4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "3"}], "\[Mu]S", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "\[Eta]\[Chi]"}]}], ")"}]}]}], ",", 
     RowBox[{"g5", "\[Rule]", "\[Eta]L"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6527990263606586`*^9, 3.652799043439228*^9}, {
  3.6527991488330603`*^9, 3.6527991580280647`*^9}, {3.652799197125218*^9, 
  3.652799244870364*^9}, {3.6528127891131697`*^9, 3.652812792340077*^9}}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListEM", "=", 
   RowBox[{
    RowBox[{"ListEMRaw", "//.", "ToPunctureNotationRule"}], "//", 
    "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652798746857162*^9, 3.652798851889595*^9}, 
   3.6527988838682127`*^9, {3.652799257645728*^9, 3.652799280601584*^9}, 
   3.6527993112306128`*^9, {3.652799348650259*^9, 3.6527993521032763`*^9}, {
   3.652802343712431*^9, 3.652802344778008*^9}, {3.6528124187646017`*^9, 
   3.6528124371439877`*^9}, {3.652812540944372*^9, 3.652812551666832*^9}, {
   3.652813533835705*^9, 3.652813541160252*^9}, 3.6530415514374943`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup first order LF system", "Subsection",
 CellChangeTimes->{{3.547058194716805*^9, 3.547058205203157*^9}, {
   3.54719962648418*^9, 3.5471996319637003`*^9}, 3.547208702887014*^9, {
   3.5482061480053577`*^9, 3.5482061523135157`*^9}, {3.652985419628213*^9, 
   3.652985423414968*^9}}],

Cell[CellGroupData[{

Cell["Define various State vectors", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.530344990406041*^9, 3.530345003322054*^9}, 
   3.547206936092039*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"uold", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "x", "]"}], ",", 
     RowBox[{"d\[Alpha]", "[", "x", "]"}], ",", 
     RowBox[{"\[Beta]s", "[", "x", "]"}], ",", 
     RowBox[{"d\[Beta]s", "[", "x", "]"}], ",", 
     RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"d\[Beta]\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"gss", "[", "x", "]"}], ",", 
     RowBox[{"gqq", "[", "x", "]"}], ",", 
     RowBox[{"gs\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"dgss", "[", "x", "]"}], ",", 
     RowBox[{"dgqq", "[", "x", "]"}], ",", 
     RowBox[{"dgs\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"gs\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"dgs\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"dg\[Omega]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"dg\[Nu]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"d\[Beta]\[Nu]", "[", "x", "]"}]}], "}"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5301720081765747`*^9, 3.530172197902275*^9}, {
   3.530172371961339*^9, 3.530172389682527*^9}, {3.530172534032537*^9, 
   3.530172564184395*^9}, {3.530247343993697*^9, 3.530247350813449*^9}, {
   3.530264652376114*^9, 3.5302646555978203`*^9}, {3.53030000605732*^9, 
   3.5303000068699923`*^9}, 3.5303002685166607`*^9, 3.530341696979515*^9, 
   3.530345003322336*^9, {3.530345179932502*^9, 3.5303451816330137`*^9}, {
   3.530345269522511*^9, 3.5303453820123777`*^9}, {3.530345453279357*^9, 
   3.530345462952424*^9}, {3.5303488242014227`*^9, 3.530348841533942*^9}, {
   3.53034895863966*^9, 3.530348963573598*^9}, {3.535031358163735*^9, 
   3.5350313827536488`*^9}, {3.5352935528514843`*^9, 3.535293557092828*^9}, {
   3.535293805975095*^9, 3.535293828211422*^9}, {3.535294620249815*^9, 
   3.5352946225193644`*^9}, {3.535295426330598*^9, 3.535295441245957*^9}, 
   3.547206936093845*^9, {3.653061962662615*^9, 3.653061983911384*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usim", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "x", "]"}], ",", 
     RowBox[{"D\[Alpha]", "[", "x", "]"}], ",", 
     RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], ",", 
     RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}], ",", 
     RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}], ",", " ", 
     RowBox[{"g\[Omega]\[Omega]", "[", "x", "]"}], ",", " ", 
     RowBox[{"Dg\[Omega]\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "x", "]"}], ",", 
     RowBox[{"D\[Theta]", "[", "x", "]"}], ",", 
     RowBox[{"Zs", "[", "x", "]"}], ",", 
     RowBox[{"DZs", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"DZ\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"DZ\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}], ",", 
     RowBox[{"Dg\[Omega]\[Nu]", "[", "x", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.652878383082911*^9, 3.6528784095093737`*^9}, {
  3.6530422278675547`*^9, 3.653042229500402*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ucons", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "x", "]"}], ",", 
     RowBox[{"Zs", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Omega]", "[", "x", "]"}], ",", 
     RowBox[{"Z\[Nu]", "[", "x", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.5471930694809093`*^9, 3.547206936106153*^9, {3.547373985288199*^9, 
   3.5473739858767*^9}, {3.547459992627472*^9, 3.547459994839159*^9}, {
   3.547465249479124*^9, 3.547465250166882*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]Vec", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Sigma]\[Alpha]", ",", "\[Sigma]\[Beta]s", ",", 
     "\[Sigma]\[Beta]\[Omega]", ",", "\[Sigma]\[Beta]\[Nu]", ",", 
     "\[Sigma]\[Theta]", ",", "\[Sigma]Zs", ",", "\[Sigma]Z\[Omega]", ",", 
     "\[Sigma]Z\[Nu]", ",", "\[Sigma]RePsi", ",", "\[Sigma]ImPsi"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547276401581093*^9, 3.547276466176759*^9}, {
   3.5474600771027308`*^9, 3.54746008672812*^9}, {3.5474652629494677`*^9, 
   3.547465268182375*^9}, 3.547530460600471*^9, {3.5481622408454237`*^9, 
   3.548162241024476*^9}, {3.6512300981391706`*^9, 3.651230098535857*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bcVec", "=", 
   RowBox[{"{", 
    RowBox[{
    "g\[Alpha]", ",", "g\[Beta]s", ",", "g\[Beta]\[Omega]", ",", 
     "g\[Beta]\[Nu]", ",", "g\[Theta]", ",", "gZs", ",", "gZ\[Omega]", ",", 
     "gZ\[Nu]", ",", "gRePsi", ",", "gImPsi"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaugebcVec", "=", 
   RowBox[{"{", 
    RowBox[{
    "g\[Alpha]", ",", "g\[Beta]s", ",", "g\[Beta]\[Omega]", ",", 
     "g\[Beta]\[Nu]"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547276401581093*^9, 3.547276527235094*^9}, {
  3.547361519788253*^9, 3.547361521721767*^9}, {3.547460097541943*^9, 
  3.547460106643688*^9}, {3.547465272949617*^9, 3.54746528105492*^9}, {
  3.5481622483148937`*^9, 3.548162248393743*^9}, {3.651230102858667*^9, 
  3.651230105184733*^9}, {3.652604057306201*^9, 3.652604063602404*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define some Rules to keep things clean", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.530345012032325*^9, 3.5303450231074743`*^9}, 
   3.547206936112529*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"LambdaRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Gamma]", "2"]]}], "\[Rule]", " ", 
      SuperscriptBox["\[Lambda]", "2"]}], " ", ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}], "\[Rule]", " ", 
      SuperscriptBox["\[Lambda]\[Mu]L", "2"]}], " ", ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}], "\[Rule]", " ", 
      SuperscriptBox["\[Lambda]\[Mu]S", "2"]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]]}], "\[Rule]", " ", 
      SuperscriptBox["\[Lambda]\[Mu]Ss", "2"]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"]]}], "\[Rule]", " ", 
      SuperscriptBox["\[Lambda]\[Mu]C", "2"]}]}], "}"}]}], ";", 
  RowBox[{"UnLambdaRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Gamma]", "2"]]}], "]"}]}], ",", 
     RowBox[{"\[Lambda]\[Mu]L", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}], "]"}]}], ",", 
     RowBox[{"\[Lambda]\[Mu]S", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}], "]"}]}], ",", 
     RowBox[{"\[Lambda]\[Mu]Ss", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]]}], "]"}]}], ",", 
     RowBox[{"\[Lambda]\[Mu]C", "\[Rule]", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Gamma]\[Mu]C", "2"]]}]]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6530649913656063`*^9, {3.655921138680641*^9, 3.655921145366601*^9}, {
   3.6559214605543957`*^9, 3.655921466832595*^9}, 3.655963529692801*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UnTauRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Tau]\[Mu]Cm", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "+", 
         RowBox[{"\[Lambda]\[Mu]C", " ", 
          SqrtBox["\[Mu]C"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Lm", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "+", 
         RowBox[{"\[Lambda]\[Mu]L", " ", 
          SqrtBox["\[Mu]L"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Ssm", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "+", 
         RowBox[{"\[Lambda]\[Mu]Ss", " ", 
          SqrtBox["\[Mu]Ss"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Sm", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "+", 
         RowBox[{"\[Lambda]\[Mu]S", " ", 
          SqrtBox["\[Mu]S"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]m", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "s"}], " ", "\[Beta]", " ", 
        SuperscriptBox["\[Gamma]", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Cp", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "-", 
         RowBox[{"\[Lambda]\[Mu]C", " ", 
          SqrtBox["\[Mu]C"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Lp", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "-", 
         RowBox[{"\[Lambda]\[Mu]L", " ", 
          SqrtBox["\[Mu]L"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Ssp", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "-", 
         RowBox[{"\[Lambda]\[Mu]Ss", " ", 
          SqrtBox["\[Mu]Ss"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]\[Mu]Sp", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]"}], "-", 
         RowBox[{"\[Lambda]\[Mu]S", " ", 
          SqrtBox["\[Mu]S"]}]}], ")"}]}]}], ",", 
     RowBox[{"\[Tau]p", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "s"}], " ", "\[Beta]", " ", 
        SuperscriptBox["\[Gamma]", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.655921881628676*^9, {3.655956809565991*^9, 3.655956844232441*^9}, {
   3.664305354017014*^9, 3.6643054137780123`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TauRules", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"\[Mu]L", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]\[Mu]Lp", " ", "\[Tau]\[Mu]Lm", " "}], 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       SuperscriptBox["\[Omega]", "2"]}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]p", " ", "\[Tau]m", " "}], 
        SuperscriptBox["\[Gamma]", "2"]]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"\[Mu]Ss", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]\[Mu]Ssp", " ", "\[Tau]\[Mu]Ssm", " "}], 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"\[Mu]S", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Tau]\[Mu]Sp", " ", "\[Tau]\[Mu]Sm", " "}], 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}]}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", "\[Lambda]"}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]p", 
        SuperscriptBox["\[Gamma]", "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", "\[Lambda]"}], ")"}], 
      "\[Rule]", 
      FractionBox["\[Tau]p", 
       SuperscriptBox["\[Gamma]", "2"]]}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", "\[Lambda]"}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]m", 
        SuperscriptBox["\[Gamma]", "2"]]}]}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", 
        RowBox[{"\[Lambda]\[Mu]L", " ", 
         SqrtBox["\[Mu]L"]}]}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]\[Mu]Lp", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]L", " ", 
         SqrtBox["\[Mu]L"]}]}], ")"}], "\[Rule]", 
      FractionBox["\[Tau]\[Mu]Lp", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]L", " ", 
         SqrtBox["\[Mu]L"]}]}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]\[Mu]Lm", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}]}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", 
        RowBox[{"\[Lambda]\[Mu]S", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]\[Mu]Sp", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]S", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      FractionBox["\[Tau]\[Mu]Sp", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]S", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Tau]\[Mu]Sm", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", "s", " ", "\[Beta]"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       FractionBox["3", 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]], "\[Tau]\[Mu]Ssp"}]}],
      ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "s", " ", "\[Beta]"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]]}], 
       "\[Tau]\[Mu]Ssp"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "s", " ", "\[Beta]"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]]}], 
       "\[Tau]\[Mu]Ssm"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
        RowBox[{
         FractionBox["2", 
          RowBox[{" ", 
           SqrtBox["3"]}]], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]], "\[Tau]\[Mu]Ssp"}]}],
      ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", 
        RowBox[{
         FractionBox["2", 
          RowBox[{" ", 
           SqrtBox["3"]}]], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]]}], 
       "\[Tau]\[Mu]Ssp"}]}], ",", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", 
        RowBox[{
         FractionBox["2", 
          RowBox[{" ", 
           SqrtBox["3"]}]], " ", "\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " "}]]}], 
       "\[Tau]\[Mu]Ssm"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]Ss"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", 
         RowBox[{"-", "2"}]]}], " ", "\[Tau]\[Mu]Ssm"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]Ss"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]Ss", 
        RowBox[{"-", "2"}]], " ", "\[Tau]\[Mu]Ssp"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", 
        RowBox[{"\[Lambda]\[Mu]Ss", " ", 
         SqrtBox["\[Mu]Ss"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", 
         RowBox[{"-", "2"}]]}], " ", "\[Tau]\[Mu]Ssp"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Lambda]\[Mu]C", " ", 
         SqrtBox["\[Mu]C"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]C", 
         RowBox[{"-", "2"}]]}], " ", "\[Tau]\[Mu]Cm"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "\[Beta]"}], "-", 
        RowBox[{"\[Lambda]\[Mu]C", " ", 
         SqrtBox["\[Mu]C"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Gamma]\[Mu]C", 
         RowBox[{"-", "2"}]]}], " ", "\[Tau]\[Mu]Cp"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], "s", " ", "\[Beta]"}], "+", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], "\[Lambda]\[Mu]L", " ", 
        SqrtBox["\[Mu]L"]}]}], "\[Rule]", 
      RowBox[{"-", "\[Tau]\[Mu]Lm"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.655920940151704*^9, 3.655920985083902*^9}, {
  3.6559215128818197`*^9, 3.65592151326254*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GammaRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Gamma]", "\[Rule]", " ", 
      FractionBox["1", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[Beta]", "2"]}], "]"}]]}], ",", 
     RowBox[{"\[Gamma]\[Mu]S", "\[Rule]", " ", 
      FractionBox["1", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Mu]S", "-", 
         SuperscriptBox["\[Beta]", "2"]}], "]"}]]}], ",", 
     RowBox[{"\[Gamma]\[Mu]Ss", "\[Rule]", " ", 
      FractionBox["1", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Mu]Ss", "-", 
         SuperscriptBox["\[Beta]", "2"]}], "]"}]]}], ",", 
     RowBox[{"\[Gamma]\[Mu]L", "\[Rule]", " ", 
      FractionBox["1", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Mu]L", "-", 
         SuperscriptBox["\[Beta]", "2"]}], "]"}]]}], ",", 
     RowBox[{"\[Gamma]\[Mu]C", "\[Rule]", " ", 
      FractionBox["1", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Mu]C", "-", 
         SuperscriptBox["\[Beta]", "2"]}], "]"}]]}]}], "}"}]}], 
  ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.530264947962474*^9, 3.530264971893289*^9}, 
   3.530345023107559*^9, {3.531123818340559*^9, 3.531123993424532*^9}, {
   3.531124174634965*^9, 3.531124175759836*^9}, 3.547206936113461*^9, {
   3.65304257373425*^9, 3.65304258240657*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UseGammaRules", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "-", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      SuperscriptBox["\[Gamma]", 
       RowBox[{"-", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", 
      RowBox[{"-", " ", 
       SuperscriptBox["\[Gamma]", 
        RowBox[{"-", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{"\[Mu]S", "-", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      SuperscriptBox["\[Gamma]\[Mu]S", 
       RowBox[{"-", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]S"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]S", 
        RowBox[{"-", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{"\[Mu]Ss", "-", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      SuperscriptBox["\[Gamma]\[Mu]Ss", 
       RowBox[{"-", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]Ss"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]Ss", 
        RowBox[{"-", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{"\[Mu]L", "-", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      SuperscriptBox["\[Gamma]\[Mu]L", 
       RowBox[{"-", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]L"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]L", 
        RowBox[{"-", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       SuperscriptBox["\[Omega]", "2"], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}]}]}]}], ",", 
     RowBox[{"\[Eta]\[Chi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "\[Mu]S"}], "-", 
        RowBox[{"3", " ", "\[Mu]Ss"}]}], "\[Mu]S"]}], " ", ",", 
     RowBox[{
      RowBox[{"\[Mu]C", "-", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", " ", 
      SuperscriptBox["\[Gamma]\[Mu]C", 
       RowBox[{"-", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]C"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], "\[Rule]", 
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]C", 
        RowBox[{"-", "2"}]]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.531124279349491*^9, 3.531124281527525*^9}, {
   3.531125046583099*^9, 3.5311250502862787`*^9}, {3.531129882932065*^9, 
   3.531129913950431*^9}, {3.532795283338214*^9, 3.532795297627232*^9}, {
   3.532795411371622*^9, 3.532795426005645*^9}, 3.54720693611651*^9, {
   3.550739153205868*^9, 3.5507391536872*^9}, {3.6530425878956833`*^9, 
   3.653042648254966*^9}, {3.653042683254444*^9, 3.6530426901534367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Use\[Mu]SsRules", "=", 
   RowBox[{"{", " ", 
    RowBox[{"\[Eta]\[Chi]", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"4", " ", "\[Mu]S"}], "-", 
       RowBox[{"3", " ", "\[Mu]Ss"}]}], "\[Mu]S"]}], " ", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.531124279349491*^9, 3.531124281527525*^9}, {
   3.531125046583099*^9, 3.5311250502862787`*^9}, {3.531129882932065*^9, 
   3.531129913950431*^9}, {3.532795283338214*^9, 3.532795297627232*^9}, {
   3.532795411371622*^9, 3.532795426005645*^9}, 3.54720693611651*^9, {
   3.550739153205868*^9, 3.5507391536872*^9}, {3.651214796502509*^9, 
   3.6512148024853897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChiRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Chi]", "\[Rule]", 
      RowBox[{
       RowBox[{"\[Gamma]", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}]}]}], ",", 
     RowBox[{"\[Chi]\[Mu]L", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]L"]}]}], ")"}], 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], 
       RowBox[{"Sqrt", "[", "\[Mu]L", "]"}]}]}], ",", 
     RowBox[{"\[Chi]\[Mu]Ss", "->", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]Ss"]}]}], ")"}], 
       SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], 
       RowBox[{"Sqrt", "[", "\[Mu]Ss", "]"}]}]}], ",", 
     RowBox[{"\[Chi]\[Mu]S", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]S"]}]}], ")"}], 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], 
       RowBox[{"Sqrt", "[", "\[Mu]S", "]"}]}]}], ",", 
     RowBox[{"\[Chi]\[Mu]C", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]C"]}]}], ")"}], 
       SuperscriptBox["\[Gamma]\[Mu]C", "2"], 
       RowBox[{"Sqrt", "[", "\[Mu]C", "]"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664620788777557*^9, 3.664620903892782*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UseChiRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"s", "+", 
        RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "\[Rule]", 
      RowBox[{"\[Chi]", "/", 
       RowBox[{"\[Gamma]", "^", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
        RowBox[{"s", " ", 
         SqrtBox["\[Mu]L"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Chi]\[Mu]L", "/", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], "/", 
       RowBox[{"Sqrt", "[", "\[Mu]L", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
        RowBox[{"s", " ", 
         SqrtBox["\[Mu]Ss"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Chi]\[Mu]Ss", "/", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], "/", 
       RowBox[{"Sqrt", "[", "\[Mu]Ss", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
        RowBox[{"s", " ", 
         SqrtBox["\[Mu]S"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Chi]\[Mu]S", "/", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], "/", 
       RowBox[{"Sqrt", "[", "\[Mu]S", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
        RowBox[{"s", " ", 
         SqrtBox["\[Mu]C"]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Chi]\[Mu]C", "/", 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"]}], "/", 
       RowBox[{"Sqrt", "[", "\[Mu]C", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]", " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Lambda]\[Mu]S", " ", 
        SqrtBox["\[Mu]S"]}], "+", 
       RowBox[{"s", " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Mu]S"}]}], "\[Rule]", 
      "\[Chi]\[Mu]S"}]}], "}"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Define Rules and equations for first order reduction", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.5303450629914494`*^9, 3.530345098525598*^9}, 
   3.547206936151906*^9},
 FontSize->14],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Alpha]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"d\[Alpha]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]s", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"d\[Beta]s", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"d\[Beta]\[Omega]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"d\[Beta]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gss", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dgss", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gqq", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dgqq", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gs\[Omega]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dgs\[Omega]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gs\[Nu]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dgs\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dg\[Omega]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstOrderRule", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstOrderRule", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], "\[Rule]", " ", 
      RowBox[{"dg\[Nu]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.5302474265806026`*^9, 3.5302476796008053`*^9}, {
   3.530247710191208*^9, 3.530247763712022*^9}, {3.530247814100389*^9, 
   3.530247855079142*^9}, {3.530249130389386*^9, 3.530249133574627*^9}, {
   3.5302543875720663`*^9, 3.5302543935315857`*^9}, {3.530264697760817*^9, 
   3.530264702387138*^9}, {3.530266370620912*^9, 3.5302663779034567`*^9}, {
   3.530269465127914*^9, 3.530269473171736*^9}, {3.5302872525799513`*^9, 
   3.530287254014162*^9}, {3.530291415369923*^9, 3.530291426654337*^9}, {
   3.530293033233342*^9, 3.530293040258341*^9}, {3.5302972172652903`*^9, 
   3.530297225981155*^9}, {3.530297927908642*^9, 3.5302979369318237`*^9}, {
   3.530300236849388*^9, 3.530300245379388*^9}, {3.5303021094177217`*^9, 
   3.530302116411375*^9}, {3.530340315151968*^9, 3.5303403218248158`*^9}, 
   3.530341714816245*^9, 3.53034509852569*^9, {3.530348205631606*^9, 
   3.530348213783983*^9}, {3.530349092016548*^9, 3.530349097221483*^9}, {
   3.5311213108621902`*^9, 3.531121317206554*^9}, {3.532068809965425*^9, 
   3.532068822902671*^9}, {3.532069022398518*^9, 3.532069037565769*^9}, {
   3.5320716637122993`*^9, 3.532071676109915*^9}, {3.532072247212975*^9, 
   3.532072253419416*^9}, {3.532180103243885*^9, 3.532180112059511*^9}, {
   3.534326505788772*^9, 3.534326534646813*^9}, {3.539076973876287*^9, 
   3.539076987771624*^9}, {3.539077258454446*^9, 3.539077328042698*^9}, {
   3.539077579811636*^9, 3.539077594384849*^9}, {3.539341341293804*^9, 
   3.539341347803842*^9}, {3.539341814832204*^9, 3.539341822133787*^9}, 
   3.539351400602227*^9, {3.539351449619824*^9, 3.5393514606041822`*^9}, {
   3.539351606355834*^9, 3.539351607978468*^9}, 3.539351682574147*^9, {
   3.539351828008547*^9, 3.539351830067569*^9}, {3.539359791086154*^9, 
   3.5393597964105883`*^9}, {3.542968432420957*^9, 3.542968445173922*^9}, {
   3.5429691649728622`*^9, 3.5429691701647778`*^9}, {3.5429699478177032`*^9, 
   3.542969953435837*^9}, {3.543122419857826*^9, 3.543122424941843*^9}, {
   3.543729831621521*^9, 3.543729835984755*^9}, {3.54427261381778*^9, 
   3.544272619642281*^9}, {3.547193973588904*^9, 3.547194007145289*^9}, 
   3.547206936154269*^9, {3.653062015598678*^9, 3.653062022744681*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Alpha]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"d\[Alpha]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]s", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"d\[Beta]s", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"d\[Beta]\[Omega]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"d\[Beta]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gss", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dgss", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gqq", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dgqq", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gs\[Omega]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dgs\[Omega]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"gs\[Nu]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dgs\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dg\[Omega]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FirstEqn", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"FirstEqn", ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"dg\[Nu]\[Nu]", "[", "x", "]"}]}]}], "]"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.530247988406879*^9, 3.5302481255636463`*^9}, {
   3.530249475886003*^9, 3.530249488990003*^9}, {3.5302544038837957`*^9, 
   3.530254406243308*^9}, {3.530264712942143*^9, 3.530264718006071*^9}, {
   3.530266380761738*^9, 3.530266388842992*^9}, {3.530269477525956*^9, 
   3.530269484207884*^9}, {3.530283561998287*^9, 3.530283564105056*^9}, {
   3.530291430312748*^9, 3.530291439964919*^9}, {3.530293045310071*^9, 
   3.530293051816696*^9}, {3.530297232497725*^9, 3.5302972429227448`*^9}, {
   3.530297942342248*^9, 3.53029795103473*^9}, {3.530300286966674*^9, 
   3.5303002925378304`*^9}, {3.530302119886397*^9, 3.5303021305703497`*^9}, {
   3.530340325799293*^9, 3.530340332218403*^9}, 3.5303416036999483`*^9, 
   3.5303450985257597`*^9, {3.5303482170118647`*^9, 3.530348223763152*^9}, {
   3.530349100627479*^9, 3.530349105683344*^9}, {3.53112132114349*^9, 
   3.531121329982985*^9}, {3.532068827974917*^9, 3.5320688408388767`*^9}, {
   3.532069040041189*^9, 3.532069053278216*^9}, {3.532071679486787*^9, 
   3.532071691438512*^9}, {3.532072260018928*^9, 3.532072265747666*^9}, {
   3.5321801158182783`*^9, 3.532180124400508*^9}, {3.5343265388055058`*^9, 
   3.534326546024432*^9}, {3.539076993355792*^9, 3.539077000267344*^9}, {
   3.5390772883563147`*^9, 3.5390772968381243`*^9}, {3.539077598659915*^9, 
   3.539077605036441*^9}, {3.539341355052073*^9, 3.539341360139666*^9}, {
   3.539341828752082*^9, 3.539341834200035*^9}, 3.539351407242177*^9, 
   3.539351464979731*^9, {3.5393516143230124`*^9, 3.5393516157873907`*^9}, 
   3.5393516851101522`*^9, {3.53935183457347*^9, 3.539351837806364*^9}, {
   3.539361048095888*^9, 3.539361060148535*^9}, {3.5429684515484877`*^9, 
   3.542968456314095*^9}, {3.542969176388811*^9, 3.542969182101468*^9}, {
   3.542969956282497*^9, 3.542969963383567*^9}, {3.543122427915457*^9, 
   3.5431224335047827`*^9}, {3.5437298429293957`*^9, 3.543729847362315*^9}, {
   3.544272623705966*^9, 3.544272629274547*^9}, {3.5471940128813057`*^9, 
   3.547194068192369*^9}, 3.5471986923026943`*^9, 3.5472069361579523`*^9, {
   3.6530620263226833`*^9, 3.653062036596056*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SecEqn", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"ListEM", "//.", "FirstOrderRule"}], "//.", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], "FirstOrderRule"}]}], "//.", 
    "FirstOrderRule"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.530247861203053*^9, 3.530247913300679*^9}, {
   3.530247966288114*^9, 3.530247967440112*^9}, {3.530248133306673*^9, 
   3.5302481385628033`*^9}, {3.532071694917983*^9, 3.532071703318285*^9}, 
   3.537876542191009*^9, 3.5390770118033667`*^9, {3.539077340509533*^9, 
   3.539077346181746*^9}, 3.5391941867120123`*^9, 3.539341849762012*^9, {
   3.5393421044116364`*^9, 3.539342109380135*^9}, {3.540104537641123*^9, 
   3.5401045430567837`*^9}, {3.5402408448780107`*^9, 
   3.5402408520211554`*^9}, {3.545732819826997*^9, 3.545732825515069*^9}, 
   3.547206936159872*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Make first order reduction", "Text",
 CellChangeTimes->{{3.530345757999241*^9, 3.53034576227227*^9}, 
   3.547206936161471*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullEqn", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{"FirstEqn", ",", "SecEqn"}], "]"}], "//", "Flatten"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.530248140277876*^9, 3.530248179259117*^9}, {
   3.5302482875510273`*^9, 3.530248292527464*^9}, {3.530248364594668*^9, 
   3.530248386394988*^9}, {3.530249263093444*^9, 3.5302492888687983`*^9}, 
   3.530279156804134*^9, 3.530279198043104*^9, {3.532072035813283*^9, 
   3.532072039086028*^9}, 3.547206936161965*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RHSOrgRule", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{"FullEqn", ",", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], "uold"}]}], "]"}], "//", 
       "Flatten"}], ")"}], ",", "uold"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.53024818714671*^9, 3.53024821393189*^9}, {
   3.5302482525774193`*^9, 3.53024825447257*^9}, {3.530249900290649*^9, 
   3.530249908875306*^9}, {3.530249938913062*^9, 3.530249951864129*^9}, {
   3.530279203696662*^9, 3.530279205549505*^9}, {3.530279258767394*^9, 
   3.530279348986649*^9}, 3.530279794968791*^9, 3.53029453497202*^9, {
   3.530295272316372*^9, 3.530295283082232*^9}, {3.530349316676524*^9, 
   3.530349332582526*^9}, {3.53207204094252*^9, 3.532072043863865*^9}, 
   3.534326566974462*^9, 3.537210164754033*^9, {3.537210873549361*^9, 
   3.537210878549732*^9}, 3.547206936163897*^9, {3.548078919119816*^9, 
   3.548078934696638*^9}, {3.6527979507760477`*^9, 3.652797958755965*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Derive principal symbol", "Text",
 CellChangeTimes->{{3.530345757999241*^9, 3.53034576227227*^9}, {
   3.547199562648673*^9, 3.547199567459133*^9}, 3.547206936165491*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullEqnsOld", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ListEM", "//.", "FirstOrderRule"}], "//.", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], " ", "FirstOrderRule"}]}], "//.", 
        "FirstOrderRule"}], ")"}], ",", "FirstEqn"}], "]"}], "//", 
    "Flatten"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.530298386179887*^9, 3.530298399046866*^9}, {
   3.5302984486880903`*^9, 3.530298497511113*^9}, {3.5302985474869633`*^9, 
   3.5302985718447227`*^9}, {3.530298602853127*^9, 3.5302986100309896`*^9}, {
   3.530298850638938*^9, 3.530298851957321*^9}, 3.530343443288423*^9, {
   3.5303449165483627`*^9, 3.5303449214177933`*^9}, {3.532065665090712*^9, 
   3.532065668538219*^9}, {3.5320720519423447`*^9, 3.53207205490355*^9}, 
   3.54720693616614*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullRulesOld", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"FullEqnsOld", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], "uold"}]}], "]"}], "//", 
    "Flatten"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.530298615137289*^9, 3.5302987540793667`*^9}, {
   3.530298844518961*^9, 3.5302988460614567`*^9}, 3.530341230412383*^9, 
   3.5303432994113894`*^9, 3.530343443288494*^9, {3.530344916548403*^9, 
   3.530344921417823*^9}, {3.530349171055997*^9, 3.530349179690503*^9}, {
   3.532065671658496*^9, 3.532065676730715*^9}, {3.532072056863505*^9, 
   3.532072059216337*^9}, 3.5472069361680613`*^9, {3.651218444455422*^9, 
   3.651218446268993*^9}, 3.6527981141800623`*^9, {3.652799625511396*^9, 
   3.652799630194264*^9}, {3.652799719561328*^9, 3.652799721047593*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RHSFullold", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], "uold"}], ")"}], "/.", 
    "FullRulesOld"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.53029875788246*^9, 3.530298778866983*^9}, 
   3.530343443288558*^9, {3.530344916548441*^9, 3.5303449214178534`*^9}, {
   3.530349189743965*^9, 3.530349189813641*^9}, 3.530349474405703*^9, 
   3.5304254616362543`*^9, {3.532065680689432*^9, 3.532065683665371*^9}, {
   3.5320720616305428`*^9, 3.5320720653587513`*^9}, 3.547206936169815*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"RHSFullold", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"uold", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}], "//", "Simplify"}]}], ";", 
  RowBox[{"M", "//", "MatrixForm"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5302987801861267`*^9, 3.5302988288941183`*^9}, {
   3.5302988623123817`*^9, 3.530298919667416*^9}, 3.530343443288623*^9, {
   3.530344916548479*^9, 3.530344921417881*^9}, {3.53034914370837*^9, 
   3.530349144947448*^9}, {3.530349195775571*^9, 3.5303491959357452`*^9}, {
   3.532072067175438*^9, 3.5320720721911716`*^9}, {3.539077360070733*^9, 
   3.539077369552458*^9}, 3.547206936171864*^9, {3.547207213799554*^9, 
   3.547207220231032*^9}, {3.547465803866297*^9, 3.547465818211978*^9}, {
   3.550652636334132*^9, 3.550652646340991*^9}, 3.652798136267329*^9, {
   3.652855877097484*^9, 3.652855878666205*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Change of variables", "Subsection",
 CellChangeTimes->{{3.547058194716805*^9, 3.547058205203157*^9}, {
   3.54719962648418*^9, 3.5471996319637003`*^9}, 3.547208702887014*^9}],

Cell[CellGroupData[{

Cell["Equations for change of variables", "Text",
 CellChangeTimes->{{3.54719970548287*^9, 3.547199726195203*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"ContraintRules", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"RemoveKContraintRules", "[", 
          RowBox[{"[", 
           RowBox[{"7", ";;", "10"}], "]"}], "]"}], "/.", "FirstOrderRule"}], 
        "/.", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], "FirstOrderRule"}]}], "/.", 
       "RHSOrgRule"}], "/.", "ToPunctureNotationRule"}], "//.", 
     "GammaRules"}], "//", "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.653063738099478*^9, 3.6530637649121*^9}, {
  3.653064544045014*^9, 3.6530645609496307`*^9}, {3.653064717219647*^9, 
  3.653064737371407*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DConstraintRules", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"D\[Theta]", "[", "x", "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Theta]", "'"}], "[", "x", "]"}], "+", 
               RowBox[{"\[Beta]", " ", "s", " ", 
                SuperscriptBox["\[Gamma]\[Mu]C", "2"], 
                RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ",", 
             RowBox[{
              RowBox[{"DZs", "[", "x", "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{
                RowBox[{"Zs", "'"}], "[", "x", "]"}], "+", 
               RowBox[{"\[Beta]", " ", "s", " ", 
                SuperscriptBox["\[Gamma]", "2"], 
                RowBox[{"Zs", "[", "x", "]"}]}]}]}], ",", 
             RowBox[{
              RowBox[{"DZ\[Omega]", "[", "x", "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{
                RowBox[{"Z\[Omega]", "'"}], "[", "x", "]"}], "+", 
               RowBox[{"\[Beta]", " ", "s", " ", 
                SuperscriptBox["\[Gamma]", "2"], 
                RowBox[{"Z\[Omega]", "[", "x", "]"}]}]}]}], ",", 
             RowBox[{
              RowBox[{"DZ\[Nu]", "[", "x", "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{
                RowBox[{"Z\[Nu]", "'"}], "[", "x", "]"}], "+", 
               RowBox[{"\[Beta]", " ", "s", " ", 
                SuperscriptBox["\[Gamma]", "2"], 
                RowBox[{"Z\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}], "/.", 
           "DRemoveKContraintRules"}], "/.", "RemoveKContraintRules"}], "/.", 
         "FirstOrderRule"}], "/.", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], "FirstOrderRule"}]}], "/.", 
       "RHSOrgRule"}], "/.", "ToPunctureNotationRule"}], "//.", 
     "GammaRules"}], "//", "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.653063379972974*^9, 3.6530634066661797`*^9}, {
  3.6530641554393263`*^9, 3.653064213466799*^9}, {3.653064335015293*^9, 
  3.653064339130094*^9}, {3.653066414354653*^9, 3.653066431151354*^9}, {
  3.653066542509922*^9, 3.653066552521096*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaugeRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"gqq", "[", "x", "]"}], "+", 
      RowBox[{"gss", "[", "x", "]"}], "+", 
      FractionBox[
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}], 
       RowBox[{
        RowBox[{"3", " ", "\[Mu]L"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "\[Eta]\[Chi]"}], ")"}], " ", 
         "\[Mu]S"}]}]]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.653063821563614*^9, 3.653063841522716*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DGaugeRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"D\[Alpha]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"d\[Alpha]", "[", "x", "]"}], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"dgqq", "[", "x", "]"}], "+", 
       RowBox[{"dgss", "[", "x", "]"}], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
         RowBox[{"d\[Alpha]", "[", "x", "]"}]}], 
        RowBox[{
         RowBox[{"3", " ", "\[Mu]L"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "\[Eta]\[Chi]"}], ")"}], " ", 
          "\[Mu]S"}]}]], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gqq", "[", "x", "]"}], "+", 
          RowBox[{"gss", "[", "x", "]"}], "+", 
          FractionBox[
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
            RowBox[{"\[Alpha]", "[", "x", "]"}]}], 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]L"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "+", "\[Eta]\[Chi]"}], ")"}], " ", 
             "\[Mu]S"}]}]]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"d\[Beta]\[Omega]", "[", "x", "]"}], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], 
        RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"d\[Beta]\[Nu]", "[", "x", "]"}], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], 
        RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.653063689223028*^9, 3.6530637055553083`*^9}, {
  3.653063785677197*^9, 3.6530637952369204`*^9}, {3.653063846540557*^9, 
  3.653063887338073*^9}, {3.653063929164948*^9, 3.6530639716139307`*^9}, {
  3.653064401035812*^9, 3.6530644016626787`*^9}, {3.653066443061058*^9, 
  3.653066452503763*^9}, {3.6530665600828743`*^9, 3.6530665743223667`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PhysicalRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g\[Omega]\[Omega]", "[", "x", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"gqq", "[", "x", "]"}], "-", 
      RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.653064001313768*^9, 3.6530640069854593`*^9}, 
   3.653064077914875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DPhysicalRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dg\[Omega]\[Omega]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dgqq", "[", "x", "]"}], "-", 
         RowBox[{"dg\[Nu]\[Nu]", "[", "x", "]"}]}], ")"}], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gqq", "[", "x", "]"}], "-", 
          RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"Dg\[Omega]\[Nu]", "[", "x", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"dg\[Omega]\[Nu]", "[", "x", "]"}], "+", 
       RowBox[{"\[Beta]", " ", "s", " ", 
        SuperscriptBox["\[Gamma]", "2"], 
        RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.653064011886153*^9, 3.653064061734026*^9}, {
  3.6530643834890623`*^9, 3.653064383616201*^9}, {3.653066456437215*^9, 
  3.6530664589664593`*^9}, {3.6530667205192137`*^9, 3.6530667236014433`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChangeofVarRuleNewToOld", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
       "GaugeRules", ",", "DGaugeRules", ",", "ContraintRules", ",", 
        "DConstraintRules", ",", "PhysicalRules", ",", "DPhysicalRules"}], 
       "]"}], "/.", "GammaRules"}], "//", "Simplify"}], "//", "Flatten"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6528784629846087`*^9, 3.652878488634594*^9}, {
   3.652878830862414*^9, 3.652878835484511*^9}, {3.653042188638097*^9, 
   3.6530422008588877`*^9}, {3.653060379968701*^9, 3.6530603827067347`*^9}, {
   3.653062073853518*^9, 3.653062077712487*^9}, {3.6530621120033607`*^9, 
   3.6530622248513937`*^9}, {3.65306242624006*^9, 3.6530624342837687`*^9}, {
   3.6530631943761787`*^9, 3.6530633378750877`*^9}, {3.6530634215759363`*^9, 
   3.6530634270787992`*^9}, 3.6530637187706213`*^9, 3.653063769196612*^9, {
   3.653063834885509*^9, 3.653063835836953*^9}, {3.653063900854508*^9, 
   3.653063902810626*^9}, {3.6530640869210253`*^9, 3.65306408796574*^9}, {
   3.653064144200939*^9, 3.653064147663169*^9}, {3.653064242901203*^9, 
   3.6530642670847597`*^9}, {3.653064467039776*^9, 3.653064475278708*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Similarity transformation; regular", "Text",
 CellChangeTimes->{{3.547200241828013*^9, 3.5472002558029327`*^9}, {
  3.547814938579824*^9, 3.547814940829965*^9}, {3.548134845568275*^9, 
  3.548134846598678*^9}, {3.5481368026991177`*^9, 3.548136803442957*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"usim", "//.", "ChangeofVarRuleNewToOld"}], "//.", 
     "ToPunctureNotationRule"}], ",", "uold"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.652810584440111*^9, {3.6528107663169947`*^9, 3.65281080797532*^9}, {
   3.6528110504673233`*^9, 3.65281105952144*^9}, {3.652811129251849*^9, 
   3.652811131103359*^9}, {3.65281118478162*^9, 3.652811194974799*^9}, 
   3.65281210038713*^9, {3.652812151895385*^9, 3.652812179382964*^9}, 
   3.652812594961957*^9, {3.652814916285618*^9, 3.652814927634831*^9}, {
   3.652854190057168*^9, 3.6528541951317043`*^9}, 3.652856230003484*^9, 
   3.6528566844626207`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SCoV", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"usim", "//.", "ChangeofVarRuleNewToOld"}], "//.", 
           "ToPunctureNotationRule"}], ")"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"uold", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SCoV", "//", "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{{3.530426363988531*^9, 3.5304263823594646`*^9}, {
   3.530430153843556*^9, 3.530430153997694*^9}, 3.530432096470646*^9, 
   3.531121274333042*^9, {3.53112259869379*^9, 3.5311226042360563`*^9}, 
   3.531123664728901*^9, {3.5320274602741137`*^9, 3.532027487266341*^9}, {
   3.532068358516803*^9, 3.5320683846530647`*^9}, {3.53206967435572*^9, 
   3.532069678771268*^9}, {3.532071837737769*^9, 3.532071845530311*^9}, {
   3.5320719191265583`*^9, 3.53207193608643*^9}, {3.5320726864914217`*^9, 
   3.532072687244276*^9}, {3.534769794402945*^9, 3.534769798142008*^9}, {
   3.534770774451868*^9, 3.5347707896344833`*^9}, 3.534770939095787*^9, {
   3.537212825195676*^9, 3.5372128301187963`*^9}, {3.5376830440074778`*^9, 
   3.53768305254312*^9}, 3.53935294138348*^9, 3.539353441959281*^9, {
   3.543730083838881*^9, 3.543730094761176*^9}, 3.543740724805479*^9, 
   3.543741903071578*^9, {3.544337463299555*^9, 3.544337469700235*^9}, {
   3.54720015883095*^9, 3.547200165440744*^9}, {3.547202837987062*^9, 
   3.547202840037487*^9}, {3.5472033368388643`*^9, 3.5472033493997297`*^9}, {
   3.547208107041915*^9, 3.547208113673073*^9}, {3.547208238838088*^9, 
   3.547208259476503*^9}, {3.5474604014574957`*^9, 3.5474604029756413`*^9}, {
   3.547460995712687*^9, 3.5474609972358217`*^9}, {3.547465730422677*^9, 
   3.5474657350200663`*^9}, 3.547722129644681*^9, 3.547741553466226*^9, {
   3.5480751992606564`*^9, 3.548075209699881*^9}, {3.548075707292338*^9, 
   3.548075707471663*^9}, {3.5480789762314568`*^9, 3.5480789893920727`*^9}, {
   3.548089912834155*^9, 3.548089947138977*^9}, 3.548138003834423*^9, {
   3.5481595718042307`*^9, 3.548159571989277*^9}, 3.54893135173342*^9, {
   3.5506567693952847`*^9, 3.550656769593981*^9}, 3.5507386775864143`*^9, {
   3.550810170143523*^9, 3.5508101703859262`*^9}, {3.651230410768271*^9, 
   3.651230424562365*^9}, {3.6512305695987463`*^9, 3.6512305697750072`*^9}, 
   3.6528066783397923`*^9, 3.652810608218948*^9, {3.652814937824926*^9, 
   3.65281494599586*^9}, {3.652853840629773*^9, 3.652853843468012*^9}, 
   3.652856247308449*^9, {3.652856289840164*^9, 3.652856291924762*^9}, {
   3.652957084466864*^9, 3.65295709345781*^9}, 3.6530680946009808`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SCoVinv", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "SCoV", "]"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5327933748428*^9, 3.532793401593585*^9}, {
   3.534326378178841*^9, 3.534326388680828*^9}, {3.534769801519698*^9, 
   3.5347698084326563`*^9}, {3.543730374251733*^9, 3.543730377951295*^9}, {
   3.543735808051981*^9, 3.5437358274453497`*^9}, 3.543739921344488*^9, {
   3.5437403698945932`*^9, 3.543740370277524*^9}, {3.544272789596596*^9, 
   3.544272799772822*^9}, {3.547198928669134*^9, 3.5471989359947357`*^9}, {
   3.547202849560259*^9, 3.547202852608185*^9}, {3.547208267530223*^9, 
   3.547208271014958*^9}, {3.5474612150340967`*^9, 3.547461228476371*^9}, {
   3.5474657386499023`*^9, 3.547465749164918*^9}, {3.5480789910179253`*^9, 
   3.548078993809836*^9}, {3.652858537915505*^9, 3.6528585383733807`*^9}, 
   3.65285883722432*^9, {3.652957097661457*^9, 3.652957098120767*^9}}],

Cell["The transformation is regular ", "Text",
 CellChangeTimes->{{3.530426618875182*^9, 3.530426634549214*^9}, {
   3.532027490624528*^9, 3.53202749132749*^9}, {3.547199850857273*^9, 
   3.547199876531013*^9}, 3.547208015848537*^9, {3.547722142390748*^9, 
   3.547722145668997*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"SCoV", "//", "Det"}], "//", "FullSimplify"}], "//", 
               "Factor"}], "//", "FullSimplify"}], ")"}], "/.", 
            "Use\[Mu]SsRules"}], "//", "FullSimplify"}], ")"}], "/.", 
         "TauRules"}], "/.", 
        RowBox[{"\[Mu]Ss", "\[Rule]", 
         RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "//", "FullSimplify"}], ")"}],
      "/.", "UseGammaRules"}], "//", "Factor"}], ")"}], "/.", 
  "UseGammaRules"}]], "Input",
 CellChangeTimes->{{3.530426390472766*^9, 3.530426395554627*^9}, {
   3.532068347355324*^9, 3.532068349674892*^9}, {3.532068391564231*^9, 
   3.532068396491879*^9}, {3.532068921087401*^9, 3.5320689296389008`*^9}, {
   3.53206915584934*^9, 3.53206916095161*^9}, {3.532069553594211*^9, 
   3.5320695572014627`*^9}, {3.532069698057251*^9, 3.5320696987681303`*^9}, 
   3.533214740213573*^9, 3.534326394989079*^9, 3.535020373725909*^9, 
   3.537259680416028*^9, 3.5372597533962173`*^9, 3.537683060494166*^9, 
   3.547203190320236*^9, 3.547208280609438*^9, {3.547461241204019*^9, 
   3.5474612422254744`*^9}, 3.547470525084073*^9, 3.5489314944810343`*^9, {
   3.549022879493359*^9, 3.549022896362781*^9}, {3.550656880454583*^9, 
   3.550656883826591*^9}, {3.552918922957016*^9, 3.552918930991832*^9}, {
   3.651138974585634*^9, 3.651138992153987*^9}, 3.651230405756459*^9, {
   3.652856849716392*^9, 3.652856850247094*^9}, 3.652858852809894*^9, 
   3.652878792482615*^9, 3.6530410004170523`*^9, {3.653042018775312*^9, 
   3.653042036587861*^9}, {3.653042265426134*^9, 3.653042269418401*^9}, {
   3.6530423197565603`*^9, 3.653042342433611*^9}, {3.653042540013863*^9, 
   3.653042547142535*^9}, {3.6530428306910667`*^9, 3.653042850172505*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
   SuperscriptBox["\[Tau]m", "3"], " ", 
   SuperscriptBox["\[Tau]p", "3"], " ", "\[Tau]\[Mu]Sm", " ", 
   "\[Tau]\[Mu]Sp"}], 
  RowBox[{"256", " ", 
   SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Mu]S"}]]], "Output",
 CellChangeTimes->{
  3.65287879283036*^9, 3.6528791140944357`*^9, 3.652879150125404*^9, 
   3.652957616196731*^9, {3.653042004909006*^9, 3.653042037107522*^9}, {
   3.6530422139584007`*^9, 3.653042269778124*^9}, {3.6530423291120033`*^9, 
   3.653042332802926*^9}, 3.6530425474253273`*^9, 3.653042621242536*^9, 
   3.653042653486361*^9, 3.653042696108276*^9, {3.653042818458109*^9, 
   3.653042850468019*^9}, {3.653043697463797*^9, 3.6530437066361847`*^9}, {
   3.6530437616495323`*^9, 3.65304377240296*^9}, 3.6530618721731253`*^9, 
   3.6530645169953613`*^9, {3.653064782636837*^9, 3.653064807691922*^9}, 
   3.653066472494258*^9, 3.653066585385169*^9, 3.6530667380948257`*^9, 
   3.653066859461233*^9, 3.6530680986685534`*^9, 3.654940575688301*^9, 
   3.654941348586825*^9, 3.65494181440065*^9, 3.654952819678611*^9, 
   3.655833913668067*^9, 3.655838254698556*^9, 3.6558882596878433`*^9, 
   3.65591481857233*^9, 3.655914878706777*^9, 3.6559565633629427`*^9, 
   3.655964215565939*^9, 3.664304499254442*^9, 3.6643078054834433`*^9, 
   3.6643577541211843`*^9, 3.664361213002452*^9, 3.6643875760679407`*^9, 
   3.664458202413884*^9, 3.6644734393691883`*^9, 3.6645230214848843`*^9, 
   3.664535579820417*^9, 3.6645639647701597`*^9, 3.6645650459123917`*^9, 
   3.664568027228796*^9, 3.66460340204315*^9, 3.6646178616918707`*^9, 
   3.664641074391758*^9, 3.664654355258102*^9, 3.664654427014615*^9, 
   3.664690982427752*^9, 3.664693745072575*^9, 3.664693991832605*^9, 
   3.6647007278883343`*^9, 3.6647333042817383`*^9, 3.664815314217142*^9, 
   3.664818505558131*^9, 3.671592856060495*^9, 3.6732311311037197`*^9}]
}, Open  ]],

Cell["Rule to go to new variables", "Text",
 CellChangeTimes->{{3.548386657408092*^9, 3.548386677904351*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChangeofVarRuleOldToNew", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"uold", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"SCoVinv", ".", "usim"}], ")"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5483502304486322`*^9, 3.548350249289974*^9}, {
  3.54835029434229*^9, 3.548350415335991*^9}, {3.548386009841257*^9, 
  3.5483860149633636`*^9}, {3.548931467001977*^9, 3.548931470097991*^9}, {
  3.651230489782181*^9, 3.651230489954883*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Principal symbol after rotation", "Text",
 CellChangeTimes->{{3.530425472596621*^9, 3.530425473882598*^9}, {
   3.530435920427431*^9, 3.5304359420438538`*^9}, 3.547199762482212*^9, 
   3.664360684535136*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"Msim", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"SCoV", ".", "M", ".", "SCoVinv"}], "/.", 
         "Use\[Mu]SsRules"}], "//", "Simplify"}], ")"}], "/.", 
      "UseGammaRules"}], "/.", "LambdaRules"}], "//", "FullSimplify"}]}], ";", 
  RowBox[{"Msim", "//", "MatrixForm"}], ";"}]], "Input",
 CellChangeTimes->{{3.530426563982806*^9, 3.53042660577474*^9}, {
   3.530426642557097*^9, 3.530426644960182*^9}, {3.530426963202936*^9, 
   3.5304269717253733`*^9}, 3.531121284140505*^9, 3.532069587798566*^9, {
   3.532069683449882*^9, 3.532069684466428*^9}, 3.532069754826047*^9, {
   3.5320700139839067`*^9, 3.532070024135215*^9}, {3.532070230399769*^9, 
   3.5320702352718563`*^9}, {3.532071893020979*^9, 3.532071898915234*^9}, {
   3.532072125871909*^9, 3.53207212859925*^9}, {3.5327934084543343`*^9, 
   3.532793431250925*^9}, 3.532793928803261*^9, {3.532794167322324*^9, 
   3.5327941744850883`*^9}, {3.532794323702692*^9, 3.532794340036571*^9}, 
   3.5327973451724167`*^9, {3.533213619810577*^9, 3.533213623857984*^9}, {
   3.534769912262968*^9, 3.534769925570471*^9}, 3.534770035918343*^9, 
   3.5350203789628057`*^9, {3.544272807005186*^9, 3.544272812101532*^9}, {
   3.544962994579906*^9, 3.544962999636153*^9}, 3.547095064540415*^9, 
   3.547199033992106*^9, {3.547202827247828*^9, 3.54720283017489*^9}, {
   3.547202875821933*^9, 3.547202893103745*^9}, {3.5472033693274918`*^9, 
   3.54720337368543*^9}, {3.5472084693254013`*^9, 3.54720848250921*^9}, 
   3.54746204690515*^9, 3.547462083376083*^9, 3.547477475972416*^9, 
   3.547724351792191*^9, {3.548075643979086*^9, 3.548075650112368*^9}, 
   3.5480790024041452`*^9, 3.5480790985889387`*^9, 3.548090149960308*^9, 
   3.548090496471425*^9, 3.548134815685246*^9, 3.548931491442697*^9, 
   3.5490203673492193`*^9, {3.550655345036336*^9, 3.5506553704559307`*^9}, 
   3.5506573568962107`*^9, {3.55065740303014*^9, 3.5506574032260323`*^9}, 
   3.5507387113248587`*^9, {3.651215106683147*^9, 3.65121510937418*^9}, {
   3.651218597553584*^9, 3.6512185977832937`*^9}, {3.6516761703551598`*^9, 
   3.651676172972665*^9}, {3.652852931626306*^9, 3.652852937626087*^9}, {
   3.6528588627932377`*^9, 3.652858875540537*^9}, 3.6529571369762983`*^9, {
   3.653064825159389*^9, 3.653064857403758*^9}, {3.653064998156534*^9, 
   3.6530650273597193`*^9}, {3.653066585287405*^9, 3.653066586376157*^9}, 
   3.673231225035029*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Equation of motion after the rotation", "Text",
 CellChangeTimes->{{3.547725872758978*^9, 3.547725886110214*^9}, {
  3.65306427096424*^9, 3.6530642721617937`*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"RHSrotRule", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"(", 
        RowBox[{"usim", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ")"}]}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Msim", ".", "usim"}], ")"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477257299669247`*^9, 3.547725735772737*^9}, 
   3.547725845777048*^9, 3.547725897375905*^9, {3.547726139618638*^9, 
   3.547726142493857*^9}, {3.547741565426207*^9, 3.547741570028102*^9}, {
   3.548075227263894*^9, 3.548075235521802*^9}, {3.548075719868626*^9, 
   3.5480757333222723`*^9}, {3.5480761178240013`*^9, 3.54807611799188*^9}, {
   3.5480804943159523`*^9, 3.548080500721636*^9}, {3.548090352870843*^9, 
   3.548090369354343*^9}, {3.5481379557730017`*^9, 3.548137958977882*^9}, {
   3.548147122944543*^9, 3.548147123144457*^9}, {3.6512185894776363`*^9, 
   3.651218589642769*^9}, {3.651254227149732*^9, 3.6512542308077517`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperbolicity analysis", "Subsection",
 CellChangeTimes->{{3.547058194716805*^9, 3.547058205203157*^9}, {
  3.5470582393700438`*^9, 3.547058247176804*^9}, {3.547724289267255*^9, 
  3.5477242905840883`*^9}}],

Cell[CellGroupData[{

Cell["Identify special cases", "Text",
 CellChangeTimes->{{3.547208864878004*^9, 3.547208875291933*^9}, {
  3.547793613287134*^9, 3.547793616423315*^9}},
 FontSize->14],

Cell["The following line is really slow", "Text",
 CellChangeTimes->{{3.54807575160476*^9, 3.548075758776381*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Msim", "//", "Eigenvectors"}], "//", "Det"}], "*)"}]], "Input",
 CellChangeTimes->{{3.547208683124262*^9, 3.547208687338776*^9}, {
   3.5472087687964363`*^9, 3.5472087695921297`*^9}, {3.547208822792984*^9, 
   3.547208824688349*^9}, {3.547212590407762*^9, 3.547212592344726*^9}, {
   3.547789891695236*^9, 3.547789894806172*^9}, {3.547814812287468*^9, 
   3.547814813692985*^9}, {3.5479939703793*^9, 3.547993971466915*^9}, {
   3.54807525208969*^9, 3.548075254378983*^9}, {3.548075744810708*^9, 
   3.5480757639454393`*^9}, {3.548138088670142*^9, 3.548138095362981*^9}, 
   3.548138148365786*^9, {3.5481587956404943`*^9, 3.5481587972355347`*^9}, {
   3.655914851066485*^9, 3.655914851235064*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperbolicity analysis for generic case", "Text",
 CellChangeTimes->{{3.547199918022839*^9, 3.547199936941071*^9}, {
  3.5472083814673853`*^9, 3.547208400151346*^9}},
 FontSize->14],

Cell[CellGroupData[{

Cell["Speeds and characteristic variables", "Text",
 CellChangeTimes->{{3.547202161047031*^9, 3.547202175142025*^9}, 
   3.5472078001336813`*^9, {3.547793998265483*^9, 3.547793999850561*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"evalssim", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Msim", "//", "Eigenvalues"}], "//", 
                    "FullSimplify"}], ")"}], "/.", "UseGammaRules"}], "//", 
                    "Simplify"}], ")"}], "//.", "UseGammaRules"}], "//", 
                    "PowerExpand"}], ")"}], "/.", "LambdaRules"}], "//", 
                  "PowerExpand"}], ")"}], "/.", "TauRules"}], ")"}], "/.", 
              RowBox[{"\[Mu]Ss", "\[Rule]", 
               RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "/.", "UseGammaRules"}],
             "/.", "TauRules"}], "//", "FullSimplify"}], "//", 
          "PowerExpand"}], ")"}], "/.", "UseGammaRules"}], "/.", 
       "LambdaRules"}], "//", "FullSimplify"}], "//", "PowerExpand"}], ")"}], 
   "/.", "TauRules"}]}]], "Input",
 CellChangeTimes->{{3.530426975525567*^9, 3.530426995795273*^9}, 
   3.531121292988615*^9, {3.531468777780774*^9, 3.531468797677039*^9}, {
   3.531468839455475*^9, 3.531469022481968*^9}, {3.531469135537056*^9, 
   3.5314692376889887`*^9}, 3.531470025219775*^9, {3.531482610659986*^9, 
   3.531482621428328*^9}, {3.53148278075075*^9, 3.531482784317589*^9}, 
   3.531486360340416*^9, {3.532793561889612*^9, 3.532793610216693*^9}, {
   3.532794410697782*^9, 3.532794420898583*^9}, {3.5332136264269667`*^9, 
   3.533213658691854*^9}, {3.533213796773774*^9, 3.5332139166789637`*^9}, {
   3.533214300927072*^9, 3.5332143184763527`*^9}, 3.534767379492297*^9, {
   3.5347699279923487`*^9, 3.5347699370596943`*^9}, {3.534838359588194*^9, 
   3.534838367718177*^9}, {3.5472020837299023`*^9, 3.547202130097238*^9}, {
   3.5472022540522327`*^9, 3.547202255451749*^9}, {3.547202721644278*^9, 
   3.5472027232683*^9}, {3.5472030322834797`*^9, 3.547203034433797*^9}, {
   3.5472084888178596`*^9, 3.547208494307727*^9}, 3.5474735107282953`*^9, 
   3.547473543696335*^9, {3.5480792578643713`*^9, 3.548079258040022*^9}, {
   3.548080643019318*^9, 3.548080913666436*^9}, {3.550739345325881*^9, 
   3.550739358206911*^9}, {3.655914895395158*^9, 3.6559148996419287`*^9}, {
   3.6643066011597967`*^9, 3.6643067355438023`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Tau]p", ",", "\[Tau]p", ",", "\[Tau]p", ",", "\[Tau]p", ",", "\[Tau]p", 
   ",", "\[Tau]m", ",", "\[Tau]m", ",", "\[Tau]m", ",", "\[Tau]m", ",", 
   "\[Tau]m", ",", "\[Tau]\[Mu]Lm", ",", "\[Tau]\[Mu]Lp", ",", 
   "\[Tau]\[Mu]Sm", ",", "\[Tau]\[Mu]Sm", ",", "\[Tau]\[Mu]Sp", ",", 
   "\[Tau]\[Mu]Sp", ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Lambda]\[Mu]Ss", " ", 
       SqrtBox["\[Mu]C"], " ", 
       SqrtBox["\[Mu]S"]}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
      RowBox[{"\[Lambda]\[Mu]Ss", " ", 
       SqrtBox["\[Mu]C"], " ", 
       SqrtBox["\[Mu]S"]}]}], ")"}]}], ",", "\[Tau]\[Mu]Cm", ",", 
   RowBox[{
    SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "s"}], " ", "\[Beta]"}], "+", 
      RowBox[{"\[Lambda]\[Mu]C", " ", 
       SqrtBox["\[Mu]C"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.548080729310049*^9, 3.548080914753974*^9}, 
   3.548089409561676*^9, 3.548138332193954*^9, 3.5481588050855427`*^9, 
   3.548159522172099*^9, 3.5481674838213587`*^9, 3.548206196715006*^9, 
   3.548214670147317*^9, 3.548228087986301*^9, 3.548228936770379*^9, 
   3.548240994419323*^9, 3.548247747191296*^9, 3.54825162627079*^9, 
   3.5483017210417747`*^9, 3.548308734089346*^9, 3.548345010056836*^9, {
   3.548384983249879*^9, 3.5483850018073263`*^9}, 3.5483936351011868`*^9, 
   3.548410235541562*^9, 3.548416630314796*^9, 3.548436000447463*^9, 
   3.548495716394957*^9, 3.5484968999130898`*^9, 3.548498733524948*^9, 
   3.5485003230283947`*^9, 3.548564476420952*^9, 3.548564697569559*^9, 
   3.5485660363520393`*^9, 3.548566522946538*^9, 3.548567158140787*^9, 
   3.5485678812950277`*^9, 3.5486569757825603`*^9, 3.548736250714768*^9, 
   3.5487457495918703`*^9, 3.54875430256067*^9, 3.548756562130988*^9, {
   3.5489311101890783`*^9, 3.548931138453727*^9}, 3.548931524030589*^9, 
   3.548935149547526*^9, 3.548941130121965*^9, 3.5490235623807592`*^9, 
   3.5490282347016993`*^9, 3.549072859137869*^9, 3.549072898441717*^9, 
   3.549110339898252*^9, 3.549200961738389*^9, 3.549250489613563*^9, 
   3.549288671423964*^9, 3.549346003076744*^9, 3.549449790392906*^9, 
   3.549523459399531*^9, 3.5495434513884573`*^9, 3.5496021541506166`*^9, 
   3.54963403016101*^9, 3.549700670585412*^9, 3.54978765100626*^9, {
   3.550739345633822*^9, 3.550739359201974*^9}, 3.5507544242274437`*^9, 
   3.5508100846966963`*^9, 3.550810202693123*^9, 3.551446475707324*^9, 
   3.551455588644787*^9, 3.552920460087408*^9, 3.5532568820183907`*^9, 
   3.553330527526228*^9, 3.5534045660295773`*^9, 3.5534245404592037`*^9, 
   3.5534392956484528`*^9, 3.553493686718914*^9, 3.553520832498619*^9, 
   3.5535892580636063`*^9, 3.5535999354290657`*^9, {3.6559148908224792`*^9, 
   3.655914908624694*^9}, 3.655956574617394*^9, 3.664304546809209*^9, 
   3.66430659764334*^9, {3.66430662849695*^9, 3.664306739602674*^9}, 
   3.664307818886347*^9, 3.6643578961448803`*^9, 3.6643612259272413`*^9, 
   3.664387587826548*^9, 3.664458221812244*^9, 3.664473451074974*^9, 
   3.664523032628583*^9, 3.66453559156065*^9, 3.664563977112658*^9, 
   3.6645650620603113`*^9, 3.6645680417564373`*^9, 3.66460341341336*^9, 
   3.664617872872591*^9, 3.664641086038965*^9, 3.664654367067672*^9, 
   3.664654438124753*^9, 3.6646909935804567`*^9, 3.664693756002945*^9, 
   3.6646940028402853`*^9, 3.6647007387437162`*^9, 3.664733316712714*^9, 
   3.6648153266832933`*^9, 3.6648185196399927`*^9, 3.6715928873805637`*^9, 
   3.673231257495373*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"S", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Mrot", "//", "Transpose"}], "//", "Eigenvectors"}], "//", 
       "FullSimplify"}], "//", "PowerExpand"}], "//", "FullSimplify"}]}], ";", 
   RowBox[{"S", "//", "MatrixForm"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.550739371266403*^9, 3.550739372103588*^9}, {
  3.5507394257200937`*^9, 3.550739437456414*^9}, {3.550740406842597*^9, 
  3.5507404086126757`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define generic simplified incoming characteristic variables", "Text",
 CellChangeTimes->{{3.547741088746664*^9, 3.547741100590172*^9}, {
  3.547746948041939*^9, 3.547746952235895*^9}, {3.5477485006764317`*^9, 
  3.547748509662521*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evalIn", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Tau]\[Mu]Lm", ",", "\[Tau]\[Mu]Ssm", ",", "\[Tau]\[Mu]Sm", ",", 
     "\[Tau]\[Mu]Sm", ",", "\[Tau]\[Mu]Cm", ",", "\[Tau]m", ",", "\[Tau]m", 
     ",", "\[Tau]m", ",", "\[Tau]m", ",", "\[Tau]m"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5477404294407043`*^9, 3.5477404921676197`*^9}, 
   3.547794125668778*^9, {3.655920797966563*^9, 3.655920799004507*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CharVarIn", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547734830179928*^9, 3.547734842551586*^9}, 
   3.547794128608263*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Alpha]", "[", "x", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", "\[Lambda]\[Mu]L", " ", 
     SqrtBox["\[Mu]L"], " ", 
     RowBox[{"\[Alpha]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.54773935137568*^9, 3.547739366288591*^9}, 
   3.547739795879011*^9, 3.547794131638342*^9, {3.65591503703891*^9, 
   3.655915037160413*^9}, 3.6559153082591677`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
       RowBox[{"s", " ", 
        SqrtBox["\[Mu]Ss"]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", "\[Lambda]\[Mu]Ss", " ", 
        
        SqrtBox["\[Mu]Ss"], " ", 
        RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"4", " ", "\[Mu]S", " ", 
      RowBox[{"D\[Theta]", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
      SqrtBox["\[Mu]Ss"]}]], "-", 
    RowBox[{"4", " ", "\[Lambda]\[Mu]Ss", " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477398788026533`*^9, 3.547739884537043*^9}, 
   3.5477466057734957`*^9, {3.547746861335986*^9, 3.5477469126761436`*^9}, 
   3.547794134832165*^9, {3.5480758128386517`*^9, 3.548075814725444*^9}, 
   3.548140746726053*^9, {3.548344728222674*^9, 3.5483447460730343`*^9}, {
   3.548931533409639*^9, 3.5489315401540833`*^9}, {3.655958936902017*^9, 
   3.655958943520434*^9}, {3.655959058053114*^9, 3.655959083953466*^9}, 
   3.6559591141993923`*^9, {3.655959271235446*^9, 3.655959294527701*^9}, {
   3.6559594109656687`*^9, 3.655959411343833*^9}, 3.655959610501055*^9, {
   3.655959660524659*^9, 3.655959666016389*^9}, {3.65595983681514*^9, 
   3.655959837559136*^9}, {3.655959905397211*^9, 3.655959905960911*^9}, {
   3.65596026804381*^9, 3.6559602701931353`*^9}, {3.655960300738765*^9, 
   3.655960301372283*^9}, {3.6559603775791807`*^9, 3.655960441591482*^9}, 
   3.655960612396699*^9, {3.655963563935227*^9, 3.655963637234273*^9}, {
   3.65596368074745*^9, 3.6559636839916677`*^9}, {3.655963813821308*^9, 
   3.6559638180573673`*^9}, 3.6559641072833633`*^9, {3.655964166622951*^9, 
   3.655964177351461*^9}, 3.65596423715*^9, {3.65596440703797*^9, 
   3.655964438842895*^9}, {3.664307605408619*^9, 3.6643076137331333`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}], "-", 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Lambda]\[Mu]S", " ", 
       SqrtBox["\[Mu]S"], " ", 
       RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}]}], ")"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], "I", 
       " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], "\[Mu]L", " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], 
     FractionBox["1", 
      RowBox[{
       RowBox[{"s", " ", 
        SqrtBox["\[Mu]S"]}], "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}]}]], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        SqrtBox["\[Mu]S"], " ", 
        RowBox[{"D\[Alpha]", "[", "x", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], "\[Mu]L", " ", 
        "\[Lambda]\[Mu]S", " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"I", " ", "\[Omega]"}], 
      RowBox[{"2", 
       SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["\[Mu]S"], 
        RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}], 
        FractionBox["1", 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]S"]}]}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], 
        RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], 
        FractionBox[
         RowBox[{"\[Lambda]\[Mu]S", " ", "\[Mu]Ss"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]S"]}]}]]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "I", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["\[Gamma]", "2"], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]S"]}]}], ")"}], "2"]}]], "\[Mu]S", " ", 
        RowBox[{"D\[Theta]", "[", "x", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], " ", 
        SqrtBox["\[Mu]S"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["\[Lambda]\[Mu]S", 
             SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]], "+", 
            FractionBox[
             RowBox[{"s", " ", "\[Beta]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}], ")"}]}], 
             SqrtBox["\[Mu]S"]]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], "2"]], 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.664305643897237*^9, 3.664305669100581*^9}, 
   3.664305778897835*^9, 3.664305926102952*^9, {3.664306925772627*^9, 
   3.664306935399601*^9}, {3.664306971982154*^9, 3.664307000058341*^9}, {
   3.66430736740189*^9, 3.664307372886842*^9}, {3.664307423837615*^9, 
   3.664307430107513*^9}, {3.664307565951601*^9, 3.6643075789888897`*^9}, {
   3.6643076191462383`*^9, 3.6643076422531357`*^9}, {3.664308047567137*^9, 
   3.664308055281107*^9}, {3.6643081322396812`*^9, 3.6643081416858683`*^9}, {
   3.664308353828308*^9, 3.664308376997418*^9}, {3.664308448750757*^9, 
   3.664308461446744*^9}, {3.664308511158702*^9, 3.6643085233760757`*^9}, {
   3.664308679104918*^9, 3.6643087051190557`*^9}, {3.664358419679092*^9, 
   3.664358448186306*^9}, {3.664359677098246*^9, 3.664359678445088*^9}, 
   3.6643597858314943`*^9, {3.664359912204157*^9, 3.664359916524472*^9}, 
   3.66436004849926*^9, {3.664360106264515*^9, 3.6643601234501953`*^9}, {
   3.6643601624167747`*^9, 3.664360167765717*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Lambda]\[Mu]S", " ", 
     SqrtBox["\[Mu]S"], " ", 
     RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547739894738953*^9, 3.5477399235220947`*^9}, 
   3.5477941402547417`*^9, {3.65591567170365*^9, 3.655915677238158*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Theta]", "[", "x", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Lambda]\[Mu]C", " ", 
     SqrtBox["\[Mu]C"], " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547734807354042*^9, 3.547734849962345*^9}, {
   3.547734898699058*^9, 3.54773491350173*^9}, {3.54773523376051*^9, 
   3.547735240816495*^9}, {3.547738856844551*^9, 3.547738858075205*^9}, 
   3.547739807049996*^9, 3.547794143961768*^9, {3.548075860412031*^9, 
   3.548075862801688*^9}, {3.655915740947938*^9, 3.655915759536087*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", 
     RowBox[{"DZs", "[", "x", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", 
     RowBox[{"Zs", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", " ", "\[Beta]"}], "+", 
       RowBox[{"\[Lambda]", " ", "\[Mu]C"}]}], ")"}], " ", 
     RowBox[{"D\[Theta]", "[", "x", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", " ", "\[Beta]", " ", "\[Lambda]"}], "+", 
       SuperscriptBox["\[Lambda]\[Mu]C", "2"]}], ")"}], "\[Mu]C", " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477348587390213`*^9, 3.547734914621709*^9}, 
   3.547739810363418*^9, {3.5477399935007057`*^9, 3.5477399950883408`*^9}, 
   3.547794146473363*^9, {3.5480758671132193`*^9, 3.548075867801737*^9}, {
   3.655921583370906*^9, 3.655921593677115*^9}, {3.655921650223235*^9, 
   3.6559216594284887`*^9}, 3.655926624867641*^9, {3.655958779054018*^9, 
   3.655958814085861*^9}, {3.664458869839343*^9, 3.664458875131021*^9}, {
   3.664458977459835*^9, 3.664459012847273*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     RowBox[{"DZ\[Omega]", "[", "x", "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", " ", 
     RowBox[{"Z\[Omega]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " "}], 
      SuperscriptBox["\[Gamma]\[Mu]C", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D\[Theta]", "[", "x", "]"}], "-", 
       RowBox[{"\[Lambda]", " ", 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Mu]C", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.547734861742795*^9, 3.547734915805415*^9}, 
   3.547739813887414*^9, {3.547739997834546*^9, 3.5477399991615458`*^9}, 
   3.547794149382155*^9, {3.5480758729166737`*^9, 3.548075873613791*^9}, {
   3.655921585494083*^9, 3.6559215956770144`*^9}, {3.655926592829467*^9, 
   3.655926593736442*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"DZ\[Nu]", "[", "x", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", "  ", 
     RowBox[{"Z\[Nu]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547734863939808*^9, 3.547734917045865*^9}, 
   3.547739817506589*^9, {3.547740002097764*^9, 3.54774000344309*^9}, 
   3.547794152000374*^9, {3.548075880244541*^9, 3.548075880825048*^9}, {
   3.655915593215423*^9, 3.655915597885145*^9}, {3.664306819941904*^9, 
   3.664306824958024*^9}, {3.6643068576291933`*^9, 3.664306859749971*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Dg\[Omega]\[Nu]", "[", "x", "]"}], "-", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], "\[Lambda]", " ", 
        RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"  ", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], 
      RowBox[{"\[Mu]S", " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}]], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], "-", 
       RowBox[{"\[Lambda]", " ", "\[Mu]S", " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
        RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547740505502129*^9, 3.547740513321698*^9}, {
   3.547744692962556*^9, 3.547744730072625*^9}, 3.547744780639976*^9, {
   3.547786601481249*^9, 3.5477866066809607`*^9}, 3.547794154658332*^9, {
   3.5481390889102573`*^9, 3.548139107655751*^9}, {3.548147183701954*^9, 
   3.548147198558683*^9}, {3.548147366223302*^9, 3.548147486452511*^9}, {
   3.664360234399338*^9, 3.664360248032251*^9}, {3.6643603381255407`*^9, 
   3.664360385770328*^9}, {3.6643608625336246`*^9, 3.664360862976162*^9}, {
   3.664360950022694*^9, 3.6643609632168417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarIn", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Dg\[Omega]\[Omega]", "[", "x", "]"}], "-", 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], "\[Lambda]", " ", " ", 
       RowBox[{"g\[Omega]\[Omega]", "[", "x", "]"}]}]}], ")"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "2"], " ", 
       "\[Mu]L"}]], " ", 
     RowBox[{"D\[Alpha]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"s", " ", "\[Beta]", " ", 
          SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "2"], " ", 
       "\[Mu]L"}]], " ", 
     RowBox[{"\[Alpha]", "[", "x", "]"}]}], "-", 
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", 
        RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", "\[Mu]S"}]], " ",
     "+", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Omega]"}], 
      
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], "  ", 
     RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Beta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}]}], 
         RowBox[{" ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", "\[Mu]L", " ", 
           "\[Mu]S"}]}]], " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}]}], ")"}]}], " ", "+", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{"s", "+", 
            RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]"}], "+", "\[Lambda]"}], ")"}], " ", 
          "\[Mu]C"}]}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "3"]], 
     RowBox[{"\[Theta]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "4"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "3"]}]], " ", 
     RowBox[{"D\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547740507896865*^9, 3.5477405177786217`*^9}, {
   3.547740831777075*^9, 3.547740849426421*^9}, 3.5477941573058157`*^9, 
   3.548140098345954*^9, 3.548157252894655*^9, {3.5483155430096397`*^9, 
   3.5483155781312838`*^9}, {3.548933247177603*^9, 3.548933247852572*^9}, 
   3.550746318288045*^9, 3.664306853827174*^9, 3.664360989353372*^9, {
   3.664361260124887*^9, 3.6643612602625933`*^9}, {3.664361632005423*^9, 
   3.664361674031575*^9}, {3.664387761224978*^9, 3.664387790085498*^9}, {
   3.6643878398576117`*^9, 3.664387844960096*^9}, {3.664387907821617*^9, 
   3.664387908496667*^9}, {3.664387947656196*^9, 3.6643879668622913`*^9}, {
   3.664388026627644*^9, 3.664388044799387*^9}, {3.664388542693873*^9, 
   3.664388568405766*^9}, 3.6643886627439957`*^9, {3.664388816836061*^9, 
   3.664388829401081*^9}, {3.664389278732222*^9, 3.6643893066790037`*^9}, {
   3.664389447181501*^9, 3.664389455332427*^9}, {3.664389504258848*^9, 
   3.66438950646836*^9}, {3.664389725019504*^9, 3.664389727097459*^9}, {
   3.664390010828671*^9, 3.6643900265527287`*^9}, {3.664390286749819*^9, 
   3.6643902881343184`*^9}, {3.664390785381721*^9, 3.664390796290419*^9}, 
   3.664391211742131*^9, {3.66439125703163*^9, 3.6643912737052603`*^9}, {
   3.664391387058861*^9, 3.664391400666637*^9}, {3.664391662525182*^9, 
   3.664391665033918*^9}, {3.664391753210656*^9, 3.664391779274384*^9}}],

Cell[CellGroupData[{

Cell["\<\
Verify that the characteristic variables satisfy advection equations\
\>", "Text",
 CellChangeTimes->{{3.547741201988923*^9, 3.547741222287199*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["\[PartialD]", "x"], 
             RowBox[{"CharVarIn", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"evalIn", "[", 
              RowBox[{"[", "i", "]"}], "]"}], 
             RowBox[{"CharVarIn", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "/.", "RHSrotRule"}], "/.", 
          "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
       RowBox[{"\[Mu]C", "\[Rule]", 
        RowBox[{"\[Mu]Ss", "/", "\[Mu]S"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}], ")"}], ",", "usim",
    ",", "FullSimplify"}], "]"}]], "Input",
 CellChangeTimes->{{3.547739181001676*^9, 3.5477392851220207`*^9}, {
   3.547739324357913*^9, 3.547739335608419*^9}, {3.547739371397852*^9, 
   3.5477394221218443`*^9}, {3.547739559235976*^9, 3.547739571984915*^9}, {
   3.547739802671392*^9, 3.5477398496660767`*^9}, {3.547739960717989*^9, 
   3.5477399691311283`*^9}, {3.547740013376573*^9, 3.547740021453044*^9}, {
   3.547740058046686*^9, 3.547740063987216*^9}, {3.547740149198859*^9, 
   3.547740151486432*^9}, {3.5477402118354673`*^9, 3.547740284241366*^9}, 
   3.547740333757771*^9, {3.54774040094311*^9, 3.5477404192947617`*^9}, {
   3.547740524218218*^9, 3.547740532235875*^9}, {3.547744794632927*^9, 
   3.5477448005478*^9}, 3.54778661171386*^9, {3.547794161992251*^9, 
   3.547794170039495*^9}, {3.548075831893462*^9, 3.548075844042553*^9}, {
   3.5480759057895937`*^9, 3.548075905953964*^9}, {3.548076159340994*^9, 
   3.548076161778326*^9}, {3.5480762031010437`*^9, 3.548076277692625*^9}, {
   3.5480792774486237`*^9, 3.5480793168597727`*^9}, {3.548079386399*^9, 
   3.548079421807321*^9}, {3.548079520062405*^9, 3.548079520261281*^9}, {
   3.5480795506667633`*^9, 3.5480795708624687`*^9}, {3.548080993926857*^9, 
   3.54808106130857*^9}, {3.54808112228624*^9, 3.548081144576043*^9}, {
   3.548146943950736*^9, 3.548146952807744*^9}, {3.5507403791905727`*^9, 
   3.550740388388186*^9}, 3.550740448927245*^9, {3.550741686934469*^9, 
   3.550741694032387*^9}, {3.655914946538336*^9, 3.655914970562237*^9}, {
   3.655915344936853*^9, 3.655915396562389*^9}, {3.655915433949759*^9, 
   3.6559154364252453`*^9}, {3.655915481675454*^9, 3.655915481931182*^9}, 
   3.655915604961031*^9, {3.6559156353705683`*^9, 3.655915655751589*^9}, {
   3.655915793273857*^9, 3.655915801130246*^9}, {3.65592065377316*^9, 
   3.6559206559370117`*^9}, {3.65592102992262*^9, 3.6559210318628073`*^9}, {
   3.655921163370368*^9, 3.655921186993952*^9}, {3.655921415485718*^9, 
   3.655921435134488*^9}, 3.655921501395124*^9, {3.655921536360564*^9, 
   3.655921538994295*^9}, {3.6559266676043653`*^9, 3.655926669865794*^9}, {
   3.655956719956099*^9, 3.6559567825069036`*^9}, {3.655956863104903*^9, 
   3.655956864878119*^9}, {3.6559569108541193`*^9, 3.6559569169150047`*^9}, {
   3.655958968671221*^9, 3.655958969262619*^9}, {3.655959006752228*^9, 
   3.655959018102001*^9}, {3.65595922347806*^9, 3.655959224001101*^9}, {
   3.655959685424151*^9, 3.655959703474039*^9}, {3.655959847578602*^9, 
   3.655959863759417*^9}, {3.655960279622657*^9, 3.655960280820588*^9}, {
   3.6559637341837463`*^9, 3.65596373581472*^9}, 3.6559639481356373`*^9, {
   3.6559644763432703`*^9, 3.655964482926614*^9}, {3.664305007465349*^9, 
   3.664305051394166*^9}, {3.6643055532623367`*^9, 3.664305599985261*^9}, {
   3.6643056825775642`*^9, 3.664305719146482*^9}, {3.664305860374998*^9, 
   3.6643058694877033`*^9}, {3.6643059372041063`*^9, 3.664305958773855*^9}, {
   3.664306802612681*^9, 3.664306809059907*^9}, {3.664306864684778*^9, 
   3.664306871234621*^9}, {3.66430691341685*^9, 3.664306914247932*^9}, {
   3.66430701607498*^9, 3.6643070457111797`*^9}, {3.6643071268649683`*^9, 
   3.66430712785245*^9}, 3.664357936789946*^9, {3.664358076851429*^9, 
   3.664358168509568*^9}, {3.664358459707687*^9, 3.6643584642337418`*^9}, {
   3.66435993398827*^9, 3.664360006915992*^9}, {3.664360072264817*^9, 
   3.664360084589715*^9}, {3.664360182768998*^9, 3.664360220153935*^9}, {
   3.6643607997103786`*^9, 3.664360800257921*^9}, {3.664360970318125*^9, 
   3.664360995792295*^9}, 3.664387636505514*^9, 3.664387722343732*^9, {
   3.66438786876105*^9, 3.6643878985598593`*^9}, {3.6643880090143223`*^9, 
   3.664388011100897*^9}, {3.6643886883567133`*^9, 3.66438878052402*^9}, {
   3.6643888831198807`*^9, 3.664388886540997*^9}, {3.664389797368178*^9, 
   3.6643898243718863`*^9}, {3.664390044993853*^9, 3.664390062238165*^9}, {
   3.6643903274131536`*^9, 3.664390327753158*^9}, 3.6643909805140676`*^9, {
   3.664391017943656*^9, 3.6643910503126497`*^9}, {3.664391089985231*^9, 
   3.6643910904480143`*^9}, 3.664391223277935*^9, {3.6643914668994503`*^9, 
   3.664391472288095*^9}, 3.664391671167576*^9, {3.6644588821836767`*^9, 
   3.664458963704651*^9}, {3.6715929309194098`*^9, 3.6715929564935017`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.671592953054598*^9, 3.671592957232795*^9}, 
   3.6732317484461203`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define generic simplified outgoing characteristic variables", "Text",
 CellChangeTimes->{{3.547741088746664*^9, 3.547741100590172*^9}, {
  3.547746948041939*^9, 3.5477469648428907`*^9}, {3.547748503855381*^9, 
  3.547748507031609*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evalOut", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Tau]\[Mu]Lp", ",", "\[Tau]\[Mu]Ssp", ",", "\[Tau]\[Mu]Sp", ",", 
     "\[Tau]\[Mu]Sp", ",", "\[Tau]\[Mu]Cp", ",", "\[Tau]p", ",", "\[Tau]p", 
     ",", "\[Tau]p", ",", "\[Tau]p", ",", "\[Tau]p"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5477404294407043`*^9, 3.5477404921676197`*^9}, {
   3.5477469782949877`*^9, 3.54774700033917*^9}, 3.547794178380373*^9, {
   3.664392210597364*^9, 3.664392225435211*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CharVarOut", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547734830179928*^9, 3.547734842551586*^9}, {
   3.5477470036689262`*^9, 3.547747004055641*^9}, 3.547794181074942*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Alpha]", "[", "x", "]"}], "+", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", "\[Lambda]\[Mu]L", " ", 
     SqrtBox["\[Mu]L"], 
     RowBox[{"\[Alpha]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.54773935137568*^9, 3.547739366288591*^9}, 
   3.547739795879011*^9, 3.547746973201333*^9, {3.5477470074466057`*^9, 
   3.547747007714676*^9}, 3.5477941836052237`*^9, {3.664392231044429*^9, 
   3.664392247376965*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "-", 
       RowBox[{"s", " ", 
        SqrtBox["\[Mu]Ss"]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}], "+", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", "\[Lambda]\[Mu]Ss", " ", 
        
        SqrtBox["\[Mu]Ss"], " ", 
        RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"4", " ", "\[Mu]S", " ", 
      RowBox[{"D\[Theta]", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
      SqrtBox["\[Mu]Ss"]}]], "-", 
    RowBox[{"4", " ", "\[Lambda]\[Mu]Ss", " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477398788026533`*^9, 3.547739884537043*^9}, 
   3.5477466057734957`*^9, {3.547746861335986*^9, 3.5477469126761436`*^9}, {
   3.547747014010117*^9, 3.5477470143781443`*^9}, {3.547747067031472*^9, 
   3.54774706846014*^9}, {3.547747320076387*^9, 3.547747408116337*^9}, 
   3.547747476220099*^9, {3.5477475253547487`*^9, 3.547747566538857*^9}, {
   3.5477475998666277`*^9, 3.5477476272960873`*^9}, 3.5477941863588*^9, {
   3.548081176162403*^9, 3.5480811765166883`*^9}, {3.548157365663671*^9, 
   3.548157372599675*^9}, 3.5481574444547977`*^9, {3.548344774993483*^9, 
   3.5483448271420507`*^9}, {3.5489336359208803`*^9, 3.548933642009535*^9}, 
   3.6643923286704807`*^9, {3.664460719582347*^9, 3.664460783927292*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Lambda]\[Mu]S", " ", 
       SqrtBox["\[Mu]S"], " ", 
       RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}]}], ")"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], "I", 
       " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], "\[Mu]L", " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], 
     FractionBox["1", 
      RowBox[{
       RowBox[{"s", " ", 
        SqrtBox["\[Mu]S"]}], "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["\[Mu]S"], " ", 
        RowBox[{"D\[Alpha]", "[", "x", "]"}]}], "+", " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], "\[Mu]L", " ", 
        "\[Lambda]\[Mu]S", " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"I", " ", "\[Omega]"}], 
      RowBox[{"2", 
       SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}]], 
     FractionBox["1", 
      RowBox[{
       RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "-", 
       RowBox[{"s", " ", 
        SqrtBox["\[Mu]S"]}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["\[Mu]S"], 
        RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], 
        RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], "\[Lambda]\[Mu]S", " ", 
        "\[Mu]Ss"}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "I", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["\[Gamma]", "2"], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "-", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]S"]}]}], ")"}], "2"]}]], "\[Mu]S", "  ", 
        RowBox[{"D\[Theta]", "[", "x", "]"}]}], "+", " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], " ", 
        SqrtBox["\[Mu]S"], " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["\[Lambda]\[Mu]S", 
             SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]], "-", 
            FractionBox[
             RowBox[{"s", " ", "\[Beta]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}], ")"}]}], 
             SqrtBox["\[Mu]S"]]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "-", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], "2"]], 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.547739891867284*^9, 3.547740050837226*^9, {3.547740083192067*^9, 
   3.547740094651928*^9}, {3.547740306080751*^9, 3.5477403252587337`*^9}, 
   3.54774702073573*^9, {3.5477470787055283`*^9, 3.547747079864604*^9}, 
   3.5477479239877996`*^9, 3.5477941891578903`*^9, 3.548081180919607*^9, 
   3.548158433380715*^9, {3.54821453848664*^9, 3.54821456423135*^9}, {
   3.5483468484690447`*^9, 3.548346868162653*^9}, 3.548933735284499*^9, {
   3.550746375616987*^9, 3.5507464337186537`*^9}, 3.664392332734064*^9, {
   3.664460811741713*^9, 3.664460875195829*^9}, {3.6644609072819633`*^9, 
   3.664460912361206*^9}, {3.664460961742832*^9, 3.664460989841498*^9}, {
   3.664461034564028*^9, 3.664461039550406*^9}, 3.6644611643907223`*^9, {
   3.66446119631641*^9, 3.664461213269392*^9}, {3.664461306617927*^9, 
   3.664461328215929*^9}, {3.664461359888517*^9, 3.6644613618196*^9}, {
   3.664461511198402*^9, 3.664461538647209*^9}, {3.664461577847822*^9, 
   3.664461577987761*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], "+", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Lambda]\[Mu]S", " ", 
     SqrtBox["\[Mu]S"], " ", 
     RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547739894738953*^9, 3.5477399235220947`*^9}, 
   3.5477470230295973`*^9, 3.547747085493204*^9, {3.547794191697357*^9, 
   3.5477941921326847`*^9}, {3.66439234074841*^9, 3.6643923457928867`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"D\[Theta]", "[", "x", "]"}], "+", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Lambda]\[Mu]C", " ", 
     SqrtBox["\[Mu]C"], " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547734807354042*^9, 3.547734849962345*^9}, {
   3.547734898699058*^9, 3.54773491350173*^9}, {3.54773523376051*^9, 
   3.547735240816495*^9}, {3.547738856844551*^9, 3.547738858075205*^9}, 
   3.547739807049996*^9, 3.54774702517424*^9, 3.547747089938973*^9, {
   3.547794194231736*^9, 3.547794194999237*^9}, {3.548081185816514*^9, 
   3.548081186821947*^9}, {3.6643932694588537`*^9, 3.66439327179959*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", 
     RowBox[{"DZs", "[", "x", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", 
     RowBox[{"Zs", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", " ", "\[Beta]"}], "-", 
       RowBox[{"\[Lambda]", " ", "\[Mu]C"}]}], ")"}], " ", 
     RowBox[{"D\[Theta]", "[", "x", "]"}]}], "-", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "s"}], " ", "\[Beta]", " ", "\[Lambda]"}], "+", 
       SuperscriptBox["\[Lambda]\[Mu]C", "2"]}], ")"}], " ", "\[Mu]C", " ", 
     RowBox[{"\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477348587390213`*^9, 3.547734914621709*^9}, 
   3.547739810363418*^9, {3.5477399935007057`*^9, 3.5477399950883408`*^9}, 
   3.5477470274017553`*^9, 3.547747093313067*^9, {3.5477941970522118`*^9, 
   3.5477941975019836`*^9}, {3.5480811911282*^9, 3.548081191785459*^9}, {
   3.6643933004628973`*^9, 3.6643933166101713`*^9}, {3.664393378587699*^9, 
   3.6643934212669973`*^9}, {3.664393544294938*^9, 3.664393546789446*^9}, {
   3.664458439504035*^9, 3.664458441904047*^9}, {3.6644587575951233`*^9, 
   3.66445875824692*^9}, {3.664458840718498*^9, 3.6644588464973783`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     RowBox[{"DZ\[Omega]", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", " ", 
     RowBox[{"Z\[Omega]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " "}], 
      SuperscriptBox["\[Gamma]\[Mu]C", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"s", "+", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], 
         RowBox[{"s", "-", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], 
        RowBox[{"D\[Theta]", "[", "x", "]"}]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "s"}], "-", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], 
         RowBox[{"s", "-", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], " ", "\[Lambda]", " ", 
        SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Mu]C", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.547734861742795*^9, 3.547734915805415*^9}, 
   3.547739813887414*^9, {3.547739997834546*^9, 3.5477399991615458`*^9}, 
   3.547747029804882*^9, 3.547747097140018*^9, {3.547794199332024*^9, 
   3.547794199765479*^9}, {3.548081194362431*^9, 3.548081195049509*^9}, 
   3.6643927184128036`*^9, {3.664392763019021*^9, 3.6643927771966267`*^9}, {
   3.664392830297986*^9, 3.664392944102653*^9}, {3.664393167459203*^9, 
   3.664393184855349*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"DZ\[Nu]", "[", "x", "]"}], "+", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", "  ", 
     RowBox[{"Z\[Nu]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547734863939808*^9, 3.547734917045865*^9}, 
   3.547739817506589*^9, {3.547740002097764*^9, 3.54774000344309*^9}, 
   3.547747032741426*^9, 3.547747102123219*^9, {3.547794202130312*^9, 
   3.54779420254468*^9}, {3.5480811977142477`*^9, 3.548081198382434*^9}, {
   3.664392651221243*^9, 3.664392653566498*^9}, {3.664392691288587*^9, 
   3.664392733081073*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     RowBox[{"Dg\[Omega]\[Nu]", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], 
     SuperscriptBox["\[Gamma]", "2"], " ", "\[Lambda]", " ", " ", 
     RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Gamma]\[Mu]S", "2"], "  ", "\[Mu]S"}]], "-", 
    RowBox[{"\[Lambda]", " ", "\[Mu]S", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", "  ", "\[Omega]", " ", 
       RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], 
      RowBox[{" ", "\[Mu]S"}]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547740505502129*^9, 3.547740513321698*^9}, {
   3.547744692962556*^9, 3.547744730072625*^9}, 3.547744780639976*^9, 
   3.5477470348130074`*^9, 3.547747123969336*^9, {3.547748135385412*^9, 
   3.54774818231565*^9}, {3.547748376288342*^9, 3.547748395532235*^9}, {
   3.547748464130815*^9, 3.547748480870305*^9}, {3.5477865797407217`*^9, 
   3.547786586261333*^9}, {3.5477942050400047`*^9, 3.5477942054718733`*^9}, {
   3.664459094563615*^9, 3.664459095801034*^9}, {3.664459127748865*^9, 
   3.664459201702655*^9}, {3.664459261814638*^9, 3.66445926195641*^9}, {
   3.664459301271223*^9, 3.664459315705315*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarOut", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Dg\[Omega]\[Omega]", "[", "x", "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], "\[Lambda]", " ", " ", 
       RowBox[{"g\[Omega]\[Omega]", "[", "x", "]"}]}]}], ")"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "-", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "2"], " ", 
       "\[Mu]L"}]], " ", 
     RowBox[{"D\[Alpha]", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["\[Lambda]", 
            SuperscriptBox["\[Gamma]\[Mu]L", "2"]]}], "+", 
          RowBox[{"s", " ", "\[Beta]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "-", 
           RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "2"], " ", 
        "\[Mu]L"}]]}], " ", 
     RowBox[{"\[Alpha]", "[", "x", "]"}]}], "-", 
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]", "  ", 
      RowBox[{"D\[Beta]\[Omega]", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", "\[Mu]S"}]], " ",
     "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Omega]"}], 
      
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], "  ", 
     RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Beta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{"s", "-", 
       RowBox[{"\[Beta]", " ", "\[Lambda]"}]}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[CapitalLambda]m", "[", "x", "]"}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}]}], 
         RowBox[{" ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", "\[Mu]L", " ", 
           "\[Mu]S"}]}]], " ", 
        RowBox[{"\[Alpha]", "[", "x", "]"}]}]}], ")"}]}], " ", "+", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{"s", "-", 
            RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]"}], "-", "\[Lambda]"}], ")"}], " ", 
          "\[Mu]C"}]}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "-", 
         RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "3"]], 
     RowBox[{"\[Theta]", "[", "x", "]"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]", "4"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "-", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], "3"]}]], "  ", 
     RowBox[{"D\[Theta]", "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547740507896865*^9, 3.5477405177786217`*^9}, {
   3.547740831777075*^9, 3.547740849426421*^9}, 3.547747037208297*^9, 
   3.54774712896482*^9, {3.54779420721523*^9, 3.547794207624968*^9}, 
   3.548158727368363*^9, {3.548315590392623*^9, 3.548315603576496*^9}, {
   3.548933751190207*^9, 3.548933751808483*^9}, 3.5507445372424498`*^9, 
   3.550744807896328*^9, {3.550745048390089*^9, 3.5507450668607063`*^9}, 
   3.550745163115061*^9, {3.664459350054532*^9, 3.6644593704178553`*^9}, {
   3.664459413756611*^9, 3.6644595808023233`*^9}, {3.6644597061461678`*^9, 
   3.664459720307067*^9}, {3.664459915688788*^9, 3.6644599268475037`*^9}, {
   3.664459969095504*^9, 3.664459969232204*^9}, {3.664460346876944*^9, 
   3.664460348488207*^9}, {3.664460383732016*^9, 3.664460477661509*^9}, {
   3.6644605087224607`*^9, 3.6644605227288637`*^9}, {3.664460656323914*^9, 
   3.664460678584044*^9}}],

Cell[CellGroupData[{

Cell["\<\
Verify that the characteristic variables satisfy advection equations\
\>", "Text",
 CellChangeTimes->{{3.547741201988923*^9, 3.547741222287199*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 SubscriptBox["\[PartialD]", "x"], 
                 RowBox[{"CharVarOut", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "-", 
                RowBox[{
                 RowBox[{"evalOut", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], 
                 RowBox[{"CharVarOut", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}]}], "/.", "RHSrotRule"}], "/.",
               "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}], "/.", 
         "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
      
      RowBox[{"\[Mu]Ss", "\[Rule]", 
       RowBox[{"\[Mu]S", " ", "\[Mu]C"}]}]}], ",", "usim", ",", "Simplify"}], 
    "]"}], ",", "usim"}], "]"}]], "Input",
 CellChangeTimes->{{3.547739181001676*^9, 3.5477392851220207`*^9}, {
   3.547739324357913*^9, 3.547739335608419*^9}, {3.547739371397852*^9, 
   3.5477394221218443`*^9}, {3.547739559235976*^9, 3.547739571984915*^9}, {
   3.547739802671392*^9, 3.5477398496660767`*^9}, {3.547739960717989*^9, 
   3.5477399691311283`*^9}, {3.547740013376573*^9, 3.547740021453044*^9}, {
   3.547740058046686*^9, 3.547740063987216*^9}, {3.547740149198859*^9, 
   3.547740151486432*^9}, {3.5477402118354673`*^9, 3.547740284241366*^9}, 
   3.547740333757771*^9, {3.54774040094311*^9, 3.5477404192947617`*^9}, {
   3.547740524218218*^9, 3.547740532235875*^9}, {3.547744794632927*^9, 
   3.5477448005478*^9}, {3.547747041669159*^9, 3.54774704779011*^9}, 
   3.547786523139814*^9, {3.547794210603648*^9, 3.547794216779029*^9}, {
   3.548081214825818*^9, 3.548081287104808*^9}, {3.5481587452108383`*^9, 
   3.548158755222249*^9}, 3.550744574742097*^9, {3.550744612395671*^9, 
   3.550744612871727*^9}, {3.550744659431231*^9, 3.5507446960040007`*^9}, {
   3.550744813694214*^9, 3.550744814179188*^9}, {3.6643046628613567`*^9, 
   3.664304734336236*^9}, {3.664392296975955*^9, 3.664392320611944*^9}, {
   3.664392353365773*^9, 3.664392373848097*^9}, {3.664392666961226*^9, 
   3.664392667809349*^9}, {3.6643927404154253`*^9, 3.664392741224473*^9}, {
   3.664392791463084*^9, 3.6643928003904877`*^9}, {3.664393211639563*^9, 
   3.664393233512333*^9}, {3.664393277077166*^9, 3.664393281236367*^9}, {
   3.6643933258929453`*^9, 3.664393357874784*^9}, {3.664393433751923*^9, 
   3.664393450757266*^9}, {3.664393565893029*^9, 3.664393567356524*^9}, {
   3.664458270367441*^9, 3.664458271182785*^9}, {3.664458307825492*^9, 
   3.66445833370044*^9}, {3.664459044001257*^9, 3.6644590573640633`*^9}, {
   3.6644593351664047`*^9, 3.664459336354395*^9}, {3.664459736879146*^9, 
   3.6644597731047163`*^9}, {3.6644598096840878`*^9, 3.664459821938154*^9}, 
   3.6644599337556877`*^9, 3.664460666929296*^9, {3.6644607313533688`*^9, 
   3.664460731591716*^9}, {3.664460821937523*^9, 3.664460822081623*^9}, {
   3.66446122584743*^9, 3.664461226269672*^9}, {3.664461385518743*^9, 
   3.66446142322276*^9}, 3.664461487546983*^9, {3.6644615261468163`*^9, 
   3.664461527616003*^9}, {3.664461560650136*^9, 3.664461565507886*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.664459825688291*^9, {3.664459928608305*^9, 3.664459934555356*^9}, 
   3.664459971833383*^9, 3.6644603522277403`*^9, {3.664460393410071*^9, 
   3.66446047948378*^9}, {3.664460510909337*^9, 3.664460524570562*^9}, {
   3.664460671613669*^9, 3.6644606802530823`*^9}, {3.664460731957727*^9, 
   3.6644607882925034`*^9}, {3.664460822851223*^9, 3.664460848375786*^9}, 
   3.66446088183165*^9, 3.664460915214731*^9, {3.664460977825777*^9, 
   3.664460993487446*^9}, 3.664461047506521*^9, {3.664461174350202*^9, 
   3.6644612169912033`*^9}, 3.664461263016119*^9, 3.664461333262721*^9, {
   3.664461383650446*^9, 3.664461423581422*^9}, {3.664461487988361*^9, 
   3.664461583151455*^9}, 3.6644734518919573`*^9, 3.6645230333310432`*^9, 
   3.6645355925369043`*^9, 3.66456397821562*^9, 3.664565062807773*^9, 
   3.664568042705868*^9, 3.6646034142398577`*^9, 3.66461787377776*^9, 
   3.664641086823002*^9, 3.664654367993034*^9, 3.664654438735424*^9, 
   3.66469099417978*^9, 3.6646937565705147`*^9, 3.664694003731533*^9, 
   3.664700739329686*^9, 3.6647333175993023`*^9, 3.664815327573575*^9, 
   3.664818520448461*^9, 3.671592981775181*^9, 3.673231752040145*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Verify that the characteristic variables are the complete solution\
\>", "Text",
 CellChangeTimes->{{3.5477945264631968`*^9, 3.547794544881822*^9}, {
  3.547803593176683*^9, 3.547803593511919*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmpmat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547794549906011*^9, 3.547794637542646*^9}, 
   3.547803025180437*^9, 3.547803134882165*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tmpmat", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"CharVarIn", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], ",", 
       RowBox[{"usim", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "20"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.547794639391502*^9, 3.5477947093758097`*^9}, 
   3.5477947856142883`*^9, {3.547803027161599*^9, 3.547803045441223*^9}, 
   3.547803077118081*^9, {3.5480813501903887`*^9, 3.548081350421939*^9}, {
   3.5481588223610163`*^9, 3.54815882253196*^9}, {3.6559208883537283`*^9, 
   3.655920888520142*^9}, {3.664475053211358*^9, 3.6644750551878843`*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tmpmat", "[", 
      RowBox[{"[", 
       RowBox[{"i", "+", "10"}], "]"}], "]"}], "[", 
     RowBox[{"[", "j", "]"}], "]"}], "=", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CharVarOut", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], ",", 
      RowBox[{"usim", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.547794726991437*^9, 3.547794733043441*^9}, 
   3.5477947844085703`*^9, {3.547803035798532*^9, 3.547803051991312*^9}, {
   3.548081361316319*^9, 3.548081361491704*^9}, {3.548158826122942*^9, 
   3.548158826310622*^9}, 3.5533429530890627`*^9, {3.655920891217371*^9, 
   3.655920905286767*^9}}],

Cell["Following line is slow", "Text",
 CellChangeTimes->{{3.547992746342455*^9, 3.547992753182929*^9}, 
   3.548081365508336*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"tmpexp", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"tmpmat", "/.", "UnTauRules"}], "/.", "UnLambdaRules"}], "/.",
          "GammaRules"}], "//", "Simplify"}], "//", "Det"}], "//", 
      "Simplify"}], ")"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"tmpexp", "/.", "UseGammaRules"}], "/.", "LambdaRules"}], "/.",
          "TauRules"}], "/.", "SimplifyRules"}], "/.", "TauRules"}], "//", 
      "PowerExpand"}], ")"}], "/.", "TauRules"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.5478031023686037`*^9, 3.547803125465789*^9}, {
   3.547803471807173*^9, 3.547803477946486*^9}, {3.5478035483686323`*^9, 
   3.547803550999847*^9}, {3.547809435576112*^9, 3.547809467412407*^9}, {
   3.547809503493034*^9, 3.5478095496850367`*^9}, {3.547992755432353*^9, 
   3.547992759205711*^9}, {3.548158854704351*^9, 3.548158879274618*^9}, {
   3.548159501824977*^9, 3.548159506135363*^9}, 3.550754452686203*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tmpexp", ",", "tmpmat"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.547809415005548*^9, 3.5478094174057293`*^9}, {
   3.547809479048695*^9, 3.5478094833860283`*^9}, 3.547809565114455*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperbolicity analysis for plus special case", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.53034342493967*^9, 3.530343443288319*^9}, {
   3.530344916548101*^9, 3.5303449214177437`*^9}, 3.546689735650865*^9, {
   3.546692606621369*^9, 3.5466926122577333`*^9}, {3.5466930251095448`*^9, 
   3.546693028379394*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mplus", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Msim", "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"\[Beta]", " ", "\[Omega]"}]}]}], "/.", 
     RowBox[{"\[Mu]C", "\[Rule]", 
      RowBox[{"\[Mu]Ss", "/", " ", "\[Mu]S"}]}]}], "//", "FullSimplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.546693040674551*^9, 3.5466930614317713`*^9}, {
   3.5480814004613647`*^9, 3.548081400640923*^9}, {3.6643918086862173`*^9, 
   3.664391808948897*^9}, {3.664391857089549*^9, 3.664391865449503*^9}, {
   3.664391953168048*^9, 3.664391983547043*^9}, {3.664392067459827*^9, 
   3.664392084592602*^9}, {3.6644734812572308`*^9, 3.664473501693301*^9}, 
   3.664523501898123*^9}],

Cell["\<\
This case is not a problem because only the evecs with positive real part \
become singular. In other words the positive \[OpenCurlyQuote]speeds\
\[CloseCurlyQuote] are the ones that clash.\
\>", "Text",
 CellChangeTimes->{{3.546693094268256*^9, 3.546693153532996*^9}, {
  3.6644750954020777`*^9, 3.6644750980441027`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Mplus", "//", "Eigenvalues"}], "//", "Simplify"}], "//",
              "PowerExpand"}], "//", "Simplify"}], ")"}], "/.", 
          "UnLambdaRules"}], "/.", "GammaRules"}], "//", "Simplify"}], ")"}], 
      "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"\[Beta]", " ", "\[Omega]"}]}]}], "/.", 
     RowBox[{"\[Mu]C", "\[Rule]", 
      RowBox[{"\[Mu]Ss", "/", "\[Mu]S"}]}]}], "//", "Simplify"}], "//", 
   "PowerExpand"}], "//", "Simplify"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.530298923618281*^9, 3.5302989607279377`*^9}, {
   3.530302283921208*^9, 3.530302301694949*^9}, 3.530340433274995*^9, 
   3.530343302858993*^9, 3.5303434432886868`*^9, {3.530344916548517*^9, 
   3.53034492141791*^9}, 3.530349339936577*^9, {3.530349596134493*^9, 
   3.530349620826857*^9}, {3.530349712934683*^9, 3.5303497155715113`*^9}, 
   3.531121180749645*^9, {3.539077374214047*^9, 3.539077383502493*^9}, 
   3.546684542977313*^9, {3.546684992480298*^9, 3.5466850616135063`*^9}, 
   3.546686518934844*^9, 3.5466923890936127`*^9, 3.546692479406776*^9, 
   3.546692665022478*^9, {3.546693064413554*^9, 3.546693064801549*^9}, {
   3.5472094080117493`*^9, 3.547209437032261*^9}, {3.664391826002432*^9, 
   3.6643918713800488`*^9}, {3.664391929573263*^9, 3.664391935161248*^9}, {
   3.664523521393119*^9, 3.664523644322961*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Omega]", ",", "\[Omega]", ",", "\[Omega]", ",", "\[Omega]", ",", 
   "\[Omega]", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[Beta]", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[Beta]", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[Beta]", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[Beta]", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[Beta]", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]L"}], ")"}], " ", 
     "\[Omega]"}], 
    RowBox[{
     SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]L"}]], ",", "\[Omega]", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]S"}], ")"}], " ", 
     "\[Omega]"}], 
    RowBox[{
     SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]S"}], ")"}], " ", 
     "\[Omega]"}], 
    RowBox[{
     SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", "\[Omega]", ",", 
   "\[Omega]", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]Ss"}], ")"}], " ", 
     "\[Omega]"}], 
    RowBox[{
     SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}]], ",", "\[Omega]", ",", 
   
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "+", "\[Mu]Ss"}], 
      ")"}], " ", "\[Omega]"}], 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", "\[Mu]Ss"}]], ",",
    "\[Omega]"}], "}"}]], "Output",
 CellChangeTimes->{{3.6645234906935883`*^9, 3.664523549590538*^9}, {
   3.6645235822596188`*^9, 3.664523653086615*^9}, 3.664535603865719*^9, 
   3.664563991507099*^9, 3.664565076086622*^9, 3.6645680575633163`*^9, 
   3.664603425882372*^9, 3.664617885048491*^9, 3.6646410981619883`*^9, 
   3.6646543798095922`*^9, 3.6646544502542963`*^9, 3.6646910052573223`*^9, 
   3.664693767802099*^9, 3.664694014970743*^9, 3.664700750486738*^9, 
   3.6647333299906607`*^9, 3.6648153401830997`*^9, 3.6648185338510942`*^9, 
   3.6715930173440647`*^9, 3.6732317801369343`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperbolicity analysis for the minus special case", "Text",
 CellChangeTimes->{{3.547209617186513*^9, 3.547209629541789*^9}, {
  3.6559213514321127`*^9, 3.655921352909833*^9}},
 FontSize->14],

Cell[CellGroupData[{

Cell["Basic analysis", "Text",
 CellChangeTimes->{{3.547793947507586*^9, 3.547793956526898*^9}}],

Cell[TextData[{
 StyleBox["\t\tIncoming boundary shift: \n\t\t",
  FontSlant->"Italic"],
 "\t \[Beta] >= 0:  Special case:  s  = \[Beta] \[Omega].  Regular ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]]],
 " solution not affected, so no special case must be treated. \n\t\t",
 StyleBox["Outoing boundary shift:\n\t\t",
  FontSlant->"Italic"],
 "\t\[Beta] < 0:    Special case: s  = - \[Beta] \[Omega].  Regular ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]]],
 "solution is altered."
}], "Text",
 CellChangeTimes->{{3.548323977682404*^9, 3.5483240570343657`*^9}, {
   3.5483242349041853`*^9, 3.54832425852782*^9}, {3.548324361388401*^9, 
   3.5483245201801977`*^9}, {3.548324563922245*^9, 3.5483246007927513`*^9}, {
   3.548324750701448*^9, 3.548324814333219*^9}, {3.548325219820758*^9, 
   3.5483252394790783`*^9}, {3.548325342839347*^9, 3.548325344519178*^9}, {
   3.548325411513701*^9, 3.548325443968927*^9}, 3.5483259672876463`*^9, 
   3.548326285973341*^9, {3.548332571818141*^9, 3.548332596141945*^9}, {
   3.548332666531191*^9, 3.5483327037964354`*^9}, {3.548336083665082*^9, 
   3.5483360985159607`*^9}, {3.5483460555665417`*^9, 3.548346062131001*^9}, {
   3.548346149928752*^9, 3.5483461685171757`*^9}, {3.664474046690827*^9, 
   3.664474049189749*^9}, {3.6644745526221867`*^9, 3.66447455951939*^9}, {
   3.6644751125106363`*^9, 3.6644751223666773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mminus", "=", 
   RowBox[{
    RowBox[{"Msim", "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547209630862389*^9, 3.547209648191597*^9}, {
  3.547723552530266*^9, 3.547723553813601*^9}, {3.548081420948269*^9, 
  3.548081421115158*^9}, {3.66447355778344*^9, 3.6644735579789143`*^9}, {
  3.664474584749508*^9, 3.6644746441063423`*^9}, {3.66452367589717*^9, 
  3.664523681047757*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Mminus", "//", "Eigenvalues"}], ")"}], "/.", 
        "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
      RowBox[{"\[Mu]C", "\[Rule]", 
       RowBox[{"\[Mu]Ss", "/", "\[Mu]S"}]}]}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", 
    "FullSimplify"}], "//", "PowerExpand"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.664474784481501*^9, 3.664474789397593*^9}, 
   3.664476498563923*^9, {3.6645236868390217`*^9, 3.664523770537475*^9}, {
   3.664529255318119*^9, 3.66452925573869*^9}, {3.66453039975412*^9, 
   3.664530401496149*^9}, {3.6645304326742077`*^9, 3.664530537791071*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]L"}], ")"}], " ", 
      "\[Omega]"}], 
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]L"}]]}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]S"}], ")"}], " ", 
      "\[Omega]"}], 
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]S"}], ")"}], " ", 
      "\[Omega]"}], 
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]]}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]Ss"}], ")"}], " ", 
      "\[Omega]"}], 
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}]]}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", "\[Omega]"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "+", "\[Mu]Ss"}], 
       ")"}], " ", "\[Omega]"}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", "\[Mu]Ss"}]]}]}],
   "}"}]], "Output",
 CellChangeTimes->{{3.6645236871604147`*^9, 3.664523707138123*^9}, {
   3.664523744767578*^9, 3.664523777171158*^9}, {3.664529248436171*^9, 
   3.6645292608890743`*^9}, 3.664530406483095*^9, {3.664530439319347*^9, 
   3.664530512491675*^9}, 3.664530542799879*^9, 3.664535616760042*^9, 
   3.664564007146469*^9, 3.664565091866825*^9, 3.664568075233478*^9, 
   3.664603439311159*^9, 3.664617898198884*^9, 3.664641111466658*^9, 
   3.664654393123066*^9, 3.664654463649623*^9, 3.6646910181582823`*^9, 
   3.6646937809133043`*^9, 3.664694028098344*^9, 3.664700763975808*^9, 
   3.664733345913361*^9, 3.664815355615415*^9, 3.6648185500471973`*^9, 
   3.67159304054278*^9, 3.673231842927246*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SminusIn", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", "Mminus", "]"}], "/.", "UnLambdaRules"}],
           "/.", "GammaRules"}], "/.", 
         RowBox[{"\[Mu]C", "\[Rule]", 
          RowBox[{"\[Mu]Ss", "/", "\[Mu]S"}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ")"}], "+", 
      RowBox[{"\[Omega]", " ", 
       RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], "//", "NullSpace"}], 
    ")"}]}], ";", 
  RowBox[{"SminusIn", "//", "MatrixForm"}], ";"}]], "Input",
 CellChangeTimes->{{3.664530071042227*^9, 3.664530087938714*^9}, {
   3.664530149427875*^9, 3.664530151058709*^9}, {3.664530274673512*^9, 
   3.664530310235888*^9}, {3.6645305605923023`*^9, 3.664530609149831*^9}, 
   3.6645311680156937`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharVarMinusIn", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"SminusIn", ".", "usim"}], ",", "usim", ",", "FullSimplify"}], 
    "]"}]}], ";", 
  RowBox[{"CharVarMinusIn", "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.547209852277792*^9, 3.5472099217002497`*^9}, {
   3.5472100088585167`*^9, 3.547210016161031*^9}, {3.54747638934138*^9, 
   3.5474764027696457`*^9}, {3.547476678825365*^9, 3.5474766930811377`*^9}, {
   3.547477566526145*^9, 3.547477573042347*^9}, 3.547478313817986*^9, {
   3.547723603886572*^9, 3.547723613169137*^9}, {3.5477237606693163`*^9, 
   3.54772376091584*^9}, 3.547723879500822*^9, {3.5477872409589376`*^9, 
   3.5477872468530283`*^9}, 3.547789773075746*^9, {3.547795035189135*^9, 
   3.547795046588944*^9}, 3.547809034746141*^9, {3.5480814319153557`*^9, 
   3.548081447329583*^9}, 3.548081513705715*^9, {3.66447363124098*^9, 
   3.6644736366796513`*^9}, 3.664530615796379*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"Dg\[Omega]\[Nu]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Omega]", " ", 
          RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Omega]", " ", 
          
          RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Mu]S"}]]}]},
      {
       RowBox[{
        RowBox[{"D\[Beta]\[Nu]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Mu]S", " ", "\[Omega]", " ", 
          RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}]}], 
         RowBox[{
          SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]]}]},
      {
       RowBox[{
        RowBox[{"DZ\[Nu]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Omega]", " ", 
          RowBox[{"Z\[Nu]", "[", "x", "]"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}]]}]},
      {
       RowBox[{
        RowBox[{"DZ\[Omega]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", "\[Omega]", " ", 
          RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]S"}]], "+", 
        FractionBox[
         RowBox[{"\[Omega]", " ", 
          RowBox[{"Z\[Omega]", "[", "x", "]"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", "\[Mu]Ss", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]S"}]]}]},
      {
       RowBox[{
        RowBox[{"DZs", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "+", 
            "\[Mu]Ss"}], ")"}], " ", "\[Omega]", " ", 
          RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", 
            "\[Mu]Ss"}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"\[Omega]", " ", 
          RowBox[{"Zs", "[", "x", "]"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}]], "+", 
        FractionBox[
         RowBox[{"\[Mu]Ss", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "+", 
            "\[Mu]Ss"}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", 
            "\[Mu]Ss"}], ")"}]}]]}]},
      {
       RowBox[{
        RowBox[{"D\[Theta]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Mu]Ss", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]Ss"}], ")"}], " ", 
          "\[Omega]", " ", 
          RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", "\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", 
            "\[Mu]Ss"}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Mu]Ss", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", "\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["\[Beta]", "2"]}], " ", "\[Mu]S"}], "+", 
            "\[Mu]Ss"}], ")"}]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}], ")"}], " ", 
           RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], 
          RowBox[{
           RowBox[{"4", " ", "\[Beta]"}], "-", 
           RowBox[{"4", " ", "\[Beta]", " ", "\[Mu]S"}]}]]}], "+", 
        RowBox[{"\[Theta]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Mu]Ss", " ", "\[Omega]", " ", 
          RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}], 
         RowBox[{"4", " ", "\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}]]}]},
      {
       RowBox[{
        RowBox[{"D\[Alpha]", "[", "x", "]"}], "+", 
        FractionBox[
         RowBox[{"\[Mu]L", " ", "\[Omega]", " ", 
          RowBox[{"\[Alpha]", "[", "x", "]"}]}], 
         RowBox[{
          SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]L"}]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6645306163033657`*^9, 3.664535617141048*^9, 
  3.664564007458568*^9, 3.664565092190096*^9, 3.6645680756183043`*^9, 
  3.664603439642321*^9, 3.664617898647717*^9, 3.6646411117993193`*^9, 
  3.664654393380526*^9, 3.6646544639653463`*^9, 3.6646910184388123`*^9, 
  3.664693781166773*^9, 3.664694028506572*^9, 3.664700764205611*^9, 
  3.664733346239809*^9, 3.664815355970377*^9, 3.6648185504301243`*^9, 
  3.671593040738646*^9, 3.673231843145755*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Derive generalized eigenvector(s) for the minus special case.\
\>", "Text",
 CellChangeTimes->{{3.546694138377799*^9, 3.54669416874546*^9}, {
  3.6645311828067217`*^9, 3.6645311834379883`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SminusIn", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Mminus", "+", 
             RowBox[{"\[Omega]", " ", 
              RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}], ".", 
           RowBox[{"(", 
            RowBox[{"Mminus", "+", 
             RowBox[{"\[Omega]", " ", 
              RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}]}], "/.", 
          "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
        RowBox[{"\[Mu]C", "\[Rule]", 
         RowBox[{"\[Mu]Ss", "/", "\[Mu]S"}]}]}], "/.", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", "Transpose"}],
      "//", "FullSimplify"}], "//", "NullSpace"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664530919395496*^9, 3.664530937496108*^9}, {
   3.664530972163267*^9, 3.6645310299853373`*^9}, 3.664533046564556*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CharVarMinusIn", "=", 
   RowBox[{
    RowBox[{"SminusIn", ".", "usim"}], "//", "FullSimplify"}]}], ";", 
  RowBox[{"CharVarMinusIn", "//", "MatrixForm"}], ";"}]], "Input",
 CellChangeTimes->{{3.664531076004993*^9, 3.664531094882896*^9}, {
  3.664531250456318*^9, 3.664531265077757*^9}, {3.664533038993272*^9, 
  3.664533050825177*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define special case incoming solution", "Text",
 CellChangeTimes->{{3.547741088746664*^9, 3.547741100590172*^9}, {
  3.547746948041939*^9, 3.547746952235895*^9}, {3.5477485006764317`*^9, 
  3.547748509662521*^9}, {3.547786296192204*^9, 3.547786298096567*^9}, {
  3.547808994282506*^9, 3.547809000737508*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "x"], 
              RowBox[{"CharVarMinusIn", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "+", 
             RowBox[{"\[Omega]", " ", 
              RowBox[{"CharVarMinusIn", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}]}], "/.", "RHSrotRule"}], "/.",
            "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
        RowBox[{"\[Mu]Ss", "\[Rule]", 
         RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "/.", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ",", "urot", ",", 
      RowBox[{
       RowBox[{"PowerExpand", "@", 
        RowBox[{"Simplify", "@", "#"}]}], "&"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5477901657784843`*^9, 3.54779029725251*^9}, {
   3.5477903323459272`*^9, 3.5477903377645483`*^9}, {3.547794275829315*^9, 
   3.547794279660616*^9}, {3.5477944470190687`*^9, 3.547794454734289*^9}, {
   3.547795240719904*^9, 3.547795252953512*^9}, {3.547796354091816*^9, 
   3.5477963641036243`*^9}, {3.54780912538905*^9, 3.5478091433922453`*^9}, 
   3.547809197255952*^9, {3.548081761401751*^9, 3.548081804515066*^9}, {
   3.548159976011335*^9, 3.548159976075569*^9}, {3.548160211783629*^9, 
   3.548160243479295*^9}, 3.548160280362686*^9, {3.548160505754849*^9, 
   3.548160517274535*^9}, {3.664531303514216*^9, 3.664531322297523*^9}, 
   3.6645314420180264`*^9, 3.664533065117296*^9, 3.6645330962637043`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define simplified version of the characteristic variables", "Text",
 CellChangeTimes->{{3.547813318866084*^9, 3.54781333185907*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CharVarMinusInSimp", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547810269469735*^9, 3.54781027546327*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "10", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547810279578496*^9, 3.547810293827505*^9}, {
   3.548160577673069*^9, 3.548160579504033*^9}, 3.548161139543848*^9, 
   3.548161295282916*^9, {3.6645331214566097`*^9, 3.6645331215586977`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547810299265911*^9, 3.547810301250951*^9}, {
   3.547811203882833*^9, 3.547811213251224*^9}, 3.548160582605138*^9, {
   3.548161240451185*^9, 3.54816129248207*^9}, {3.54824317658101*^9, 
   3.548243209688389*^9}, {3.548243406798017*^9, 3.548243407072133*^9}, {
   3.548243447307416*^9, 3.548243452324008*^9}, {3.5482435374816513`*^9, 
   3.548243556757505*^9}, {3.5482436201605988`*^9, 3.548243623158737*^9}, 
   3.548243796780051*^9, {3.664533307591037*^9, 3.664533387126898*^9}, {
   3.664533543758047*^9, 3.664533576852912*^9}, {3.664533859062847*^9, 
   3.6645338616648893`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"Collect", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"CharVarMinusIn", "[", 
       RowBox[{"[", "9", "]"}], "]"}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["\[Beta]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "+", "\[Mu]Ss"}],
           ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}], " ", 
         "\[Mu]Ss"}]], " ", 
       RowBox[{"CharVarMinusIn", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}]}], ",", "usim", ",", "Simplify"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547811216447784*^9, 3.547811228572878*^9}, 
   3.5481611269815893`*^9, 3.548161312075399*^9, 3.664534218386297*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547810331841131*^9, 3.547810331970626*^9}, {
   3.547810363163727*^9, 3.547810465333871*^9}, {3.548160631148155*^9, 
   3.5481606556556797`*^9}, 3.548161143248508*^9, 3.5481613171734657`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S", " ", 
        RowBox[{"D\[Theta]", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Mu]Ss", " ", 
        RowBox[{"D\[Theta]", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Mu]Ss", " ", "\[Omega]", " ", 
        RowBox[{"\[Theta]", "[", "x", "]"}]}]}], 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], " ", "\[Mu]S"}], "-", "\[Mu]Ss"}]], "/.", 
     RowBox[{"\[Mu]Ss", "\[Rule]", 
      RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547829524152624*^9, 3.547829535153809*^9}, {
   3.547829990057822*^9, 3.547829991286736*^9}, {3.5478302256864367`*^9, 
   3.547830229282146*^9}, {3.548089535898267*^9, 3.548089536126506*^9}, {
   3.5481606693713703`*^9, 3.548160719784684*^9}, {3.548160751622822*^9, 
   3.54816085684301*^9}, 3.548161144589847*^9, 3.5481613188407393`*^9, {
   3.664533412529346*^9, 3.66453351424195*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}], ")"}], " ", 
      RowBox[{"DZs", "[", "x", "]"}]}], "+", 
     RowBox[{"\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}], ")"}], " ", 
         RowBox[{"Zs", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Beta]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], "+", "\[Mu]C"}], ")"}], " ", 
         RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}], ")"}]}]]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547829919675498*^9, 3.547829928141961*^9}, {
   3.548089546833346*^9, 3.5480895470958233`*^9}, {3.5481608623810263`*^9, 
   3.548160883559366*^9}, 3.548161146052264*^9, {3.5481613204020557`*^9, 
   3.548161325709032*^9}, 3.664534650991352*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"DZ\[Omega]", "[", "x", "]"}], "+", 
    FractionBox[
     RowBox[{"\[Omega]", " ", 
      RowBox[{"Z\[Omega]", "[", "x", "]"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Beta]", "2"]}]], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Beta]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", "\[Omega]", " ", 
      RowBox[{"\[Theta]", "[", "x", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Mu]S"}]]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.547830093847012*^9, 3.54783009894271*^9}, {
   3.5478302162003393`*^9, 3.5478302221071653`*^9}, {3.547830473377688*^9, 
   3.547830475491571*^9}, {3.5478320732012453`*^9, 3.547832075219007*^9}, {
   3.548089553936583*^9, 3.5480895541045303`*^9}, {3.548160888394779*^9, 
   3.54816089675583*^9}, 3.5481611472918262`*^9, 3.548161322255753*^9, 
   3.664534806265624*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547830139106894*^9, 3.547830151368278*^9}, 
   3.547830203517161*^9, 3.547830491523142*^9, {3.548089559373581*^9, 
   3.548089559538509*^9}, {3.5481609059059887`*^9, 3.548160911262261*^9}, 
   3.548161148585359*^9, 3.5481613280945177`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5478109360686417`*^9, 3.547810944777137*^9}, {
   3.547830188930284*^9, 3.547830200072764*^9}, {3.548161149854789*^9, 
   3.548161184420615*^9}, {3.548161217177142*^9, 3.548161224175096*^9}, 
   3.54816132985603*^9, {3.664533639340029*^9, 3.664533661154458*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CharVarMinusInSimp", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{"CharVarMinusIn", "[", 
    RowBox[{"[", "8", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547832128042528*^9, 3.5478321365042543`*^9}, 
   3.548161188341481*^9, 3.548161332751219*^9, {3.6645336568683033`*^9, 
   3.66453366009795*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"CharVarMinusInSimp", "/.", "UseGammaRules"}], "/.", 
     "GammaRules"}], "//", "Simplify"}], "//", "MatrixForm"}], ";"}]], "Input",\

 CellChangeTimes->{
  3.547810496601708*^9, 3.5478110505871487`*^9, {3.547811490506369*^9, 
   3.547811494556576*^9}, 3.547813700358852*^9, 3.548161334574067*^9, {
   3.5508450677848*^9, 3.550845074946602*^9}, 3.6645353247934523`*^9, 
   3.664535377456819*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Verify that the characteristic variables are the complete solution\
\>", "Text",
 CellChangeTimes->{{3.5477945264631968`*^9, 3.547794544881822*^9}, {
  3.547803593176683*^9, 3.547803593511919*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SubscriptBox["\[PartialD]", "x"], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"CharVarMinusInSimp", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], 
                 ")"}]}], "+", 
               RowBox[{"\[Omega]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"CharVarMinusInSimp", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], 
                 ")"}]}]}], "/.", "GammaRules"}], "/.", "RHSrotRule"}], "/.", 
            "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
         RowBox[{"\[Mu]Ss", "\[Rule]", 
          RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ",", "uconstraint",
        ",", 
       RowBox[{
        RowBox[{"PowerExpand", "@", 
         RowBox[{"Simplify", "@", "#"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5477901657784843`*^9, 3.54779029725251*^9}, {
   3.5477903323459272`*^9, 3.5477903377645483`*^9}, {3.547794275829315*^9, 
   3.547794279660616*^9}, {3.5477944470190687`*^9, 3.547794454734289*^9}, {
   3.547795240719904*^9, 3.547795252953512*^9}, {3.547796354091816*^9, 
   3.5477963641036243`*^9}, {3.54780912538905*^9, 3.5478091433922453`*^9}, 
   3.547809197255952*^9, {3.547813716153531*^9, 3.547813737732847*^9}, {
   3.547829340386742*^9, 3.5478293451925087`*^9}, {3.548089567344562*^9, 
   3.5480895825723543`*^9}, {3.548161341421179*^9, 3.548161350773356*^9}, 
   3.548243832097768*^9, 3.548243879026473*^9, {3.6645331473487873`*^9, 
   3.664533153653055*^9}, {3.664535043251639*^9, 3.664535043846964*^9}, 
   3.6645353307370157`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "x"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"tmp", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], 
               ")"}]}], "+", 
             RowBox[{"\[Omega]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"tmp", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "/.", "RHSrotRule"}], 
               ")"}]}]}], "/.", "GammaRules"}], "/.", "RHSrotRule"}], "/.", 
          "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
       RowBox[{"\[Mu]Ss", "\[Rule]", 
        RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}]}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ",", "uconstraint", 
     ",", 
     RowBox[{
      RowBox[{"PowerExpand", "@", 
       RowBox[{"Simplify", "@", "#"}]}], "&"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6645350594727287`*^9, 3.664535069068808*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.664535069728795*^9, 3.664535625123189*^9, 
  3.664564017194725*^9, 3.6645651018023243`*^9, 3.664568086572316*^9, 
  3.664603447880374*^9, 3.664617906896428*^9, 3.6646411203936977`*^9, 
  3.664654472438632*^9, 3.664691026284217*^9, 3.664693790741105*^9, 
  3.664694036375758*^9, 3.664700772063118*^9, 3.66473335607507*^9, 
  3.6648153654996023`*^9, 3.6648185603596983`*^9, 3.6715930633580103`*^9, 
  3.6732318753887167`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"CharVarMinusInSimp", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"usim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}], "/.", 
    RowBox[{"\[Mu]Ss", "\[Rule]", 
     RowBox[{"\[Mu]S", " ", "\[Mu]C"}]}]}], "//", "MatrixRank"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664535347442637*^9, 3.664535348546274*^9}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["L2 solution (general gauge)", "Subsection",
 CellChangeTimes->{{3.547058194716805*^9, 3.547058205203157*^9}, {
   3.5470582393700438`*^9, 3.547058247176804*^9}, {3.547724289267255*^9, 
   3.5477242905840883`*^9}, {3.664476112393877*^9, 3.664476115472515*^9}, 
   3.664535436873125*^9, {3.664622400362667*^9, 3.664622408905747*^9}, {
   3.664622906819804*^9, 3.664622908292259*^9}, 3.664693790032962*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evals", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Msim", "//", "Eigenvalues"}], "//", 
                  "FullSimplify"}], "//", "PowerExpand"}], "//", "Simplify"}],
                ")"}], "/.", "UseGammaRules"}], "/.", "TauRules"}], "/.", 
            RowBox[{"\[Mu]Ss", "\[Rule]", 
             RowBox[{"\[Mu]S", " ", "\[Mu]C"}]}]}], "//", "FullSimplify"}], "//",
           "PowerExpand"}], ")"}], "/.", "UseGammaRules"}], "/.", 
       "LambdaRules"}], "//", "PowerExpand"}], ")"}], "/.", "TauRules"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664477369127178*^9, 3.664477388179379*^9}, {
   3.6645356582286177`*^9, 3.6645357709326773`*^9}, {3.664535801261257*^9, 
   3.664535802114882*^9}, 3.66453887643652*^9}],

Cell[CellGroupData[{

Cell["Simplified right evecs of Msim", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evecsIn", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", "\[Lambda]\[Mu]L", " ", 
        SqrtBox["\[Mu]L"]}], ",", "0", ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
          "\[Omega]"}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]L"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]\[Mu]L", " ", 
            SqrtBox["\[Mu]L"]}], "+", 
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
         "\[Omega]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]L"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], ",", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]L", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], ",", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}]}], "-", 
           RowBox[{"\[Lambda]\[Mu]L", " ", 
            SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], ",", "0", ",", "0", 
       ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], " ", "\[Lambda]\[Mu]Ss", 
        " ", 
        SqrtBox["\[Mu]Ss"]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["\[Mu]Ss"], " ", "\[Omega]"}], 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]Ss"]}]}], ")"}]}]], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}]}], "+", 
            RowBox[{"\[Lambda]\[Mu]Ss", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]Ss"], " ", "\[Omega]"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}]}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]Ss"]}]}], ")"}], "2"]}]]}], ",", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "s"}], " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]Ss"}], ")"}]}], "+", 
           RowBox[{"\[Lambda]\[Mu]Ss", " ", 
            SqrtBox["\[Mu]Ss"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}], "2"]}]], ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
        SqrtBox["\[Mu]S"]}], ",", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]S"]}]], ",", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
           RowBox[{"\[Lambda]\[Mu]S", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Omega]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]S"]}]], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
        SqrtBox["\[Mu]S"]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]S"]}]], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
           RowBox[{"\[Lambda]\[Mu]S", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Omega]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]S"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", 
        FractionBox["4", 
         RowBox[{
          RowBox[{"\[Beta]", " ", 
           SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Lambda]\[Mu]C", " ", 
           SqrtBox["\[Mu]C"]}], "+", 
          RowBox[{"s", " ", 
           SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Mu]C"}]}]]}], ",", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]\[Mu]C", "+", 
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
            SqrtBox["\[Mu]C"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]C"]}]}]], ",", "0", ",", "0", ",", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]C", "6"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], "3"], " ", 
         SqrtBox["\[Mu]C"]}]], ",", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
           RowBox[{"\[Lambda]\[Mu]C", " ", 
            SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]C", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], "3"], " ", 
         SqrtBox["\[Mu]C"]}]], ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]C", "2"]}], " ", "\[Lambda]\[Mu]C", " ", 
        SqrtBox["\[Mu]C"]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"s", " ", "\[Beta]", " ", 
           SqrtBox["\[Mu]C"]}], "+", 
          RowBox[{"\[Lambda]\[Mu]C", " ", "\[Mu]C"}]}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]"}], "+", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]C"]}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["\[Mu]C"], " ", "\[Omega]"}], 
        RowBox[{
         SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
           RowBox[{"s", " ", 
            SqrtBox["\[Mu]C"]}]}], ")"}]}]], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Beta]", " ", 
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
           RowBox[{"\[Lambda]\[Mu]C", " ", 
            SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
         SqrtBox["\[Mu]C"], " ", "\[Omega]"}], 
        RowBox[{
         RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]C"]}]}]], ",", "0", ",", "0", ",", "0", ",", "0", ",",
        "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",",
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",",
        "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",",
        "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",",
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664566220021119*^9, 3.664566270817877*^9}, {
  3.6645669249265223`*^9, 3.664566943894629*^9}, {3.664567172587944*^9, 
  3.664567199729597*^9}, {3.6646095365718803`*^9, 3.664609538271543*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"usimsoln", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"evecsIn", "//", "Transpose"}], ")"}], ".", "\[Sigma]Vec"}]}], 
  ";", 
  RowBox[{"usimsoln", "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.6645662865894833`*^9, 3.6645663200639763`*^9}, {
  3.664566980157877*^9, 3.664566982391398*^9}, {3.66456704220875*^9, 
  3.664567060863463*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\[Sigma]\[Alpha]"},
      {
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", "\[Lambda]\[Mu]L", " ", 
        SqrtBox["\[Mu]L"], " ", "\[Sigma]\[Alpha]"}]},
      {
       RowBox[{"\[Sigma]\[Beta]s", "-", 
        FractionBox[
         RowBox[{"4", " ", "\[Sigma]\[Theta]"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", 
           SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Lambda]\[Mu]C", " ", 
           SqrtBox["\[Mu]C"]}], "+", 
          RowBox[{"s", " ", 
           SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Mu]C"}]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"]}], " ", "\[Lambda]\[Mu]Ss", 
         " ", 
         SqrtBox["\[Mu]Ss"], " ", "\[Sigma]\[Beta]s"}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]\[Mu]C", "+", 
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
             SqrtBox["\[Mu]C"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}]}], ")"}], " ", 
          "\[Sigma]\[Theta]"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}]},
      {
       RowBox[{"\[Sigma]\[Beta]\[Omega]", "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
          "\[Sigma]\[Alpha]", " ", "\[Omega]"}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]L"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["\[Mu]Ss"], " ", "\[Sigma]\[Beta]s", " ", "\[Omega]"}], 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", 
         " ", 
         SqrtBox["\[Mu]S"], " ", "\[Sigma]\[Beta]\[Omega]"}], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]\[Mu]L", " ", 
             SqrtBox["\[Mu]L"]}], "+", 
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}]}], ")"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
          "\[Sigma]\[Alpha]", " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]L"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}]}], "+", 
            RowBox[{"\[Lambda]\[Mu]Ss", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]Ss"], " ", "\[Sigma]\[Beta]s", " ", "\[Omega]"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}]}]]}]},
      {
       RowBox[{"\[Sigma]RePsi", "+", 
        FractionBox[
         RowBox[{
         "2", " ", "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", 
          "\[Omega]"}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]S"]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
          "\[Sigma]\[Alpha]", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]L", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]L"]}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"\[Sigma]\[Beta]s", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]Ss"]}]}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"4", " ", "\[Sigma]\[Theta]", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]C"]}]}], ")"}], "3"], " ", 
          SqrtBox["\[Mu]C"]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]", " ", 
         "\[Sigma]RePsi"}], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]S", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Sigma]\[Beta]\[Omega]", 
          " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]S"]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]L", " ", 
             SqrtBox["\[Mu]L"]}]}], ")"}], " ", "\[Sigma]\[Alpha]", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]L"]}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "s"}], " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]Ss"}], ")"}]}], "+", 
            RowBox[{"\[Lambda]\[Mu]Ss", " ", 
             SqrtBox["\[Mu]Ss"]}]}], ")"}], " ", "\[Sigma]\[Beta]s", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]Ss"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]Ss"]}]}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", "\[Sigma]\[Theta]", " ", 
          SuperscriptBox["\[Omega]", "2"]}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
             RowBox[{"s", " ", 
              SqrtBox["\[Mu]C"]}]}], ")"}], "3"], " ", 
          SqrtBox["\[Mu]C"]}]]}]},
      {"\[Sigma]\[Theta]"},
      {
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]C", "2"]}], " ", "\[Lambda]\[Mu]C", " ", 
        SqrtBox["\[Mu]C"], " ", "\[Sigma]\[Theta]"}]},
      {
       RowBox[{"\[Sigma]Zs", "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SqrtBox["\[Mu]C"]}], "+", 
            RowBox[{"\[Lambda]\[Mu]C", " ", "\[Mu]C"}]}], ")"}], " ", 
          "\[Sigma]\[Theta]"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]", " ", 
         "\[Sigma]Zs"}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]"}], "+", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]C"], " ", "\[Sigma]\[Theta]"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}]},
      {
       RowBox[{"\[Sigma]Z\[Omega]", "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["\[Mu]C"], " ", "\[Sigma]\[Theta]", " ", "\[Omega]"}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]", " ", 
         "\[Sigma]Z\[Omega]"}], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]C", " ", 
             SqrtBox["\[Mu]C"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]C"], " ", "\[Sigma]\[Theta]", " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]C"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]C"]}]}]]}]},
      {"\[Sigma]Z\[Nu]"},
      {
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]", " ", 
        "\[Sigma]Z\[Nu]"}]},
      {"\[Sigma]\[Beta]\[Nu]"},
      {
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
        SqrtBox["\[Mu]S"], " ", "\[Sigma]\[Beta]\[Nu]"}]},
      {
       RowBox[{"\[Sigma]ImPsi", "+", 
        FractionBox[
         RowBox[{
         "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Nu]", " ", "\[Omega]"}], 
         RowBox[{
          SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]S"]}]]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]", " ", 
         "\[Sigma]ImPsi"}], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", " ", "\[Beta]", " ", 
             SuperscriptBox["\[Gamma]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
            RowBox[{"\[Lambda]\[Mu]S", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Sigma]\[Beta]\[Nu]", " ", 
          "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]S"}], "+", 
            RowBox[{"s", " ", 
             SqrtBox["\[Mu]S"]}]}], ")"}], " ", 
          SqrtBox["\[Mu]S"]}]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.66456628824089*^9, 3.664566320462977*^9}, 
   3.664566951908964*^9, 3.664567061943416*^9, 3.6645672057310057`*^9, 
   3.664568154916485*^9, 3.664603503742572*^9, 3.664609546505926*^9, 
   3.6646179615137377`*^9, 3.664641127956748*^9, 3.664654480036963*^9, 
   3.6646910337698507`*^9, 3.6646937983944483`*^9, 3.6646940438480597`*^9, 
   3.664700780145812*^9, 3.6647333663396177`*^9, 3.664815374143132*^9, 
   3.6648185690935173`*^9, 3.671593079294701*^9, 3.673231893396057*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution at generic frequencies", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
  3.664622466713491*^9, 3.6646224785522833`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usoln", "=", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]\[Alpha]", ",", 
     RowBox[{"\[Sigma]\[Alpha]", " ", "\[Tau]\[Mu]Lm"}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[Eta]L"}], " ", "\[Mu]L"}], "+", "\[Mu]Ss"}], ")"}],
         " ", "\[Sigma]\[Alpha]", " ", "\[Tau]\[Mu]Lm"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", "\[Chi]\[Mu]L"}]], 
      "+", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", "\[Tau]\[Mu]Ssm"}], 
       RowBox[{"2", " ", "\[Chi]\[Mu]Ss"}]], "-", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", "\[Omega]"}], 
       "\[Tau]\[Mu]Sm"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[Eta]L"}], " ", "\[Mu]L"}], "+", "\[Mu]Ss"}], ")"}],
         " ", "\[Sigma]\[Alpha]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Lm", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", "\[Chi]\[Mu]L"}]], 
      "+", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        SuperscriptBox["\[Tau]\[Mu]Ssm", "2"]}], 
       RowBox[{"2", " ", "\[Chi]\[Mu]Ss"}]], "-", 
      RowBox[{
      "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", "\[Omega]"}]}], 
     ",", 
     RowBox[{"\[Sigma]\[Beta]\[Omega]", "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
        "\[Sigma]\[Alpha]", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", "\[Chi]\[Mu]L"}]], 
      "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        "\[Omega]"}], 
       RowBox[{"2", " ", "\[Chi]\[Mu]Ss"}]]}], ",", 
     RowBox[{
      RowBox[{"\[Sigma]\[Beta]\[Omega]", " ", "\[Tau]\[Mu]Sm"}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", "\[Mu]Ss"}], ")"}], " ", 
        "\[Sigma]\[Alpha]", " ", "\[Tau]\[Mu]Lm", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", "\[Chi]\[Mu]L"}]], 
      "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        "\[Tau]\[Mu]Ssm", " ", "\[Omega]"}], 
       RowBox[{"2", " ", "\[Chi]\[Mu]Ss"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[Sigma]Zs"}], "\[Tau]m"]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Cm", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Lm", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        SuperscriptBox["\[Tau]\[Mu]Ssm", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]], "+", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}], 
       SuperscriptBox["\[Tau]m", "2"]], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", 
        "\[Omega]"}], "\[Chi]\[Mu]S"], "-", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Tau]m", "2"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Sigma]Zs"}], "\[Tau]m"], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}], 
       SuperscriptBox["\[Tau]m", "2"]], "+", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", 
        "\[Omega]"}], "\[Chi]\[Mu]S"], "+", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Tau]m", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[Sigma]Z\[Omega]"}], "\[Tau]m"]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Sigma]RePsi", " ", "\[Omega]"}], 
       "\[Tau]m"], "-", 
      FractionBox[
       RowBox[{
       "4", " ", "\[ImaginaryI]", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ",
         "\[Tau]\[Mu]Cm", " ", "\[Omega]"}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", "\[Tau]\[Mu]Lm", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        "\[Tau]\[Mu]Ssm", " ", "\[Omega]"}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]], "+", 
      FractionBox[
       RowBox[{"\[Sigma]\[Beta]\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["\[Chi]\[Mu]S", "2"], "\[Mu]S"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], 
       RowBox[{"\[Tau]\[Mu]Sm", " ", "\[Chi]\[Mu]S"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Sigma]Zs"}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Cm", "3"]}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Lm", "3"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        SuperscriptBox["\[Tau]\[Mu]Ssm", "3"]}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]], "+", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}],
        "\[Tau]m"], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", 
        "\[Tau]\[Mu]Sm", " ", "\[Omega]"}], "\[Chi]\[Mu]S"], "-", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Omega]", "2"]}], "\[Tau]m"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "\[Sigma]Zs"}], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}],
        "\[Tau]m"], "+", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Omega]", " ", 
        "\[Tau]\[Mu]Sm", " ", "\[Omega]"}], "\[Chi]\[Mu]S"], "+", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Omega]", "2"]}], "\[Tau]m"], "+", 
      FractionBox[
       RowBox[{
       "4", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ", "\[Tau]\[Mu]Cm", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", "\[Tau]\[Mu]Lm", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", "\[Tau]\[Mu]Ssm", " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Sigma]Z\[Omega]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Sigma]RePsi", " ", "\[Omega]"}], "-", 
      FractionBox[
       RowBox[{
       "4", " ", "\[ImaginaryI]", " ", "\[Mu]C", " ", "\[Sigma]\[Theta]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Cm", "2"], " ", "\[Omega]"}], 
       SuperscriptBox["\[Chi]\[Mu]C", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], " ", "\[Mu]L", " ", 
        "\[Sigma]\[Alpha]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Lm", "2"], " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Mu]Ss", " ", "\[Sigma]\[Beta]s", " ", 
        SuperscriptBox["\[Tau]\[Mu]Ssm", "2"], " ", "\[Omega]"}], 
       SuperscriptBox["\[Chi]\[Mu]Ss", "2"]], "+", 
      FractionBox[
       RowBox[{"\[Sigma]\[Beta]\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["\[Chi]\[Mu]S", "2"], "\[Mu]S"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "\[Chi]\[Mu]S"]}], 
     ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[Sigma]Z\[Nu]"}], "\[Tau]m"]}], "+", 
      FractionBox[
       RowBox[{"\[Sigma]\[Beta]\[Nu]", " ", "\[Tau]\[Mu]Sm"}], 
       "\[Chi]\[Mu]S"], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Sigma]ImPsi", " ", "\[Omega]"}], 
       "\[Tau]m"]}], ",", 
     RowBox[{"\[Sigma]ImPsi", "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Nu]", " ", "\[Omega]"}], 
       "\[Chi]\[Mu]S"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Sigma]Zs"}], "\[Tau]m"], "-", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Chi]", "2"]}], 
       SuperscriptBox["\[Tau]m", "2"]], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}], 
       SuperscriptBox["\[Tau]m", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Sigma]Z\[Nu]"}], "+", 
      FractionBox[
       RowBox[{"\[Sigma]\[Beta]\[Nu]", " ", 
        SuperscriptBox["\[Tau]\[Mu]Sm", "2"]}], "\[Chi]\[Mu]S"], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Sigma]ImPsi", " ", "\[Omega]"}]}], ",", 
     RowBox[{
      RowBox[{"\[Sigma]ImPsi", " ", "\[Tau]m"}], "+", 
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "\[Sigma]\[Beta]\[Nu]", " ", "\[Tau]\[Mu]Sm", 
        " ", "\[Omega]"}], "\[Chi]\[Mu]S"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "\[Sigma]Zs"}], "-", 
      FractionBox[
       RowBox[{"\[Sigma]RePsi", " ", 
        SuperscriptBox["\[Chi]", "2"]}], "\[Tau]m"], "-", 
      FractionBox[
       RowBox[{
       "2", " ", "\[ImaginaryI]", " ", "\[Sigma]Z\[Omega]", " ", "\[Omega]"}],
        "\[Tau]m"]}], ",", "\[Sigma]\[Beta]\[Nu]", ",", 
     RowBox[{"\[Sigma]\[Beta]\[Nu]", " ", "\[Tau]\[Mu]Sm"}]}], "}"}]}], 
  ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution at s = - \[Beta] \[Omega]", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
  3.664622466713491*^9, 3.6646224785522833`*^9}, {3.6646225467074547`*^9, 
  3.664622553639851*^9}}],

Cell["Build solution in this case :", "Text",
 CellChangeTimes->{{3.664626217282942*^9, 3.664626229328376*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"evecsIn", "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", "Simplify"}], "//",
   "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.664622949119013*^9, 3.6646229673754377`*^9}, {
   3.6646230085507812`*^9, 3.664623040162157*^9}, 3.6646262378307867`*^9, 
   3.664702605219358*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6646411285600147`*^9, 3.664654480594563*^9, 
  3.664691034284841*^9, 3.6646937989384527`*^9, 3.6646940443643208`*^9, 
  3.664700780676119*^9, 3.664702606047407*^9, 3.664733367133816*^9, 
  3.664815374816544*^9, 3.664818569720612*^9, 3.6715930869918003`*^9, 
  3.673231906818206*^9, 3.673231943305293*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6646411285600147`*^9, 3.664654480594563*^9, 
  3.664691034284841*^9, 3.6646937989384527`*^9, 3.6646940443643208`*^9, 
  3.664700780676119*^9, 3.664702606047407*^9, 3.664733367133816*^9, 
  3.664815374816544*^9, 3.664818569720612*^9, 3.6715930869918003`*^9, 
  3.673231906818206*^9, 3.6732319433516083`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\^2\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6646411285600147`*^9, 3.664654480594563*^9, 
  3.664691034284841*^9, 3.6646937989384527`*^9, 3.6646940443643208`*^9, 
  3.664700780676119*^9, 3.664702606047407*^9, 3.664733367133816*^9, 
  3.664815374816544*^9, 3.664818569720612*^9, 3.6715930869918003`*^9, 
  3.673231906818206*^9, 3.673231943359243*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Power :: \
infy\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6646411285600147`*^9, 3.664654480594563*^9, 
  3.664691034284841*^9, 3.6646937989384527`*^9, 3.6646940443643208`*^9, 
  3.664700780676119*^9, 3.664702606047407*^9, 3.664733367133816*^9, 
  3.664815374816544*^9, 3.664818569720612*^9, 3.6715930869918003`*^9, 
  3.673231906818206*^9, 3.67323194340788*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"\[Mu]L", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]L"}]], ",", "0", ",", "0", 
     ",", "ComplexInfinity", ",", "ComplexInfinity", ",", "ComplexInfinity", 
     ",", "ComplexInfinity", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", 
     FractionBox[
      RowBox[{"\[Mu]Ss", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]Ss"}]], ",", 
     "ComplexInfinity", ",", "ComplexInfinity", ",", "ComplexInfinity", ",", 
     "ComplexInfinity", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox[
      RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", 
     "ComplexInfinity", ",", "ComplexInfinity", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "1", ",", 
     FractionBox[
      RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", 
     "ComplexInfinity", ",", "ComplexInfinity"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "ComplexInfinity", ",", "ComplexInfinity", ",", "0", 
     ",", "0", ",", "ComplexInfinity", ",", "ComplexInfinity", ",", "1", ",", 
     
     FractionBox[
      RowBox[{"\[Mu]C", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}]], ",", 
     "ComplexInfinity", ",", "ComplexInfinity", ",", "ComplexInfinity", ",", 
     "ComplexInfinity", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", 
     ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.664702606199565*^9, 3.664733367344584*^9, 
  3.664815374990704*^9, 3.66481856989958*^9, 3.67159308712673*^9, 
  3.673231906938764*^9, 3.673231943416629*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"evecsInMinus", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664623701509705*^9, 3.664623708046578*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", "\[Mu]L", " ", 
      "\[Omega]"}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}]}], 
       RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Eta]L", "-", "\[Mu]S"}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}]]}], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Gamma]\[Mu]Ss", "2"], " ", "\[Mu]Ss", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}], "+", 
         RowBox[{"\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], "+",
          "\[Mu]Ss"}], ")"}], " ", "\[Omega]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Mu]S"}], "+", "\[Mu]Ss"}], ")"}]}]], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623989915859*^9, 3.664623997548058*^9}, {
  3.6646240924070587`*^9, 3.664624093728381*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Gen", " ", "Evec"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Beta]", "3"], "-", 
         RowBox[{"\[Beta]", " ", "\[Mu]C"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]Ss"}], ")"}]}], 
      RowBox[{"\[Mu]C", " ", "\[Mu]S", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}], "+", 
         RowBox[{"\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], "+",
          "\[Mu]Ss"}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Beta]", "3"], "-", 
         RowBox[{"\[Beta]", " ", "\[Mu]C"}]}], ")"}], " ", "\[Mu]L", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}]}], 
      RowBox[{"\[Mu]C", " ", "\[Mu]S", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}], "+", 
         RowBox[{"\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], "+",
          "\[Mu]Ss"}], ")"}], " ", "\[Omega]"}]], ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}]}], 
      RowBox[{
       SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", "\[Mu]C", " ", 
       SuperscriptBox["\[Mu]S", "2"], " ", 
       SuperscriptBox["\[Omega]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["\[Gamma]\[Mu]C", "2"], " ", "\[Mu]C", " ", 
        "\[Omega]"}]]}], ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664623992330789*^9, 3.6646239993959627`*^9}, {
  3.6646255644475803`*^9, 3.664625577467683*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox[
      RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664623913879936*^9, 3.664623918296742*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "1", ",", 
     FractionBox[
      RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], ",", "0", ",", "0"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623830038748*^9, 3.664623859305335*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Gen", " ", "Evec"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.664626012457654*^9, 3.6646260189157553`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "\[Mu]S", " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}]}], "-", "\[Mu]Ss", "+", 
         RowBox[{"\[Mu]S", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Mu]L", "+", "\[Mu]Ss"}], ")"}]}]}], ")"}], 
       " ", "\[Omega]"}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", "\[Mu]L", " ", "\[Mu]S", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], 
      RowBox[{
       RowBox[{"\[Eta]L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Mu]L"}], "+", "\[Mu]S"}], ")"}]}], "+", 
       RowBox[{"\[Mu]S", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}], "+", 
       "\[Mu]Ss"}]], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], " ", "\[Omega]"}]], ",", "1", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623800886671*^9, 3.664623801133498*^9}, {
  3.66462557287566*^9, 3.664625575127407*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623712333426*^9, 3.664623743026703*^9}, 
   3.6646237827874393`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623746377685*^9, 3.664623784579145*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", 
     ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646237493306503`*^9, 3.664623786308687*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664623752161687*^9, 3.664623788116312*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInMinus", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     FractionBox["\[Omega]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Beta]", "2"]}]]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646237584721203`*^9, 3.664623789668421*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Msim", ".", 
          RowBox[{"evecsInMinus", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{"\[Omega]", " ", 
          RowBox[{"evecsInMinus", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "10"}], "}"}]}], "]"}], "/.", "UnLambdaRules"}], "/.",
      "GammaRules"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", "Simplify"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664625927485647*^9, 3.664625994345066*^9}, 
   3.664691383007807*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Msim", "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}], ".", 
         RowBox[{"(", 
          RowBox[{"Msim", "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}], ".", 
         RowBox[{"evecsInMinus", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "10"}], "}"}]}], "]"}], "/.", "UnLambdaRules"}], "/.",
      "GammaRules"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", "Simplify"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6646260693366413`*^9, 3.6646260877553062`*^9}, {
   3.6646261498276243`*^9, 3.6646262010880327`*^9}, 3.673231920454517*^9}],

Cell[CellGroupData[{

Cell["Examine how the 3 troubled vectors should be coupled", "Text",
 CellChangeTimes->{{3.664703389497274*^9, 3.664703406167018*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TroubledMinusTerms", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"evecsInMinus", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"evecsInMinus", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"evecsInMinus", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "/.", "GammaRules"}], "//", 
     "RowReduce"}], "//", "FullSimplify"}]}], ";", 
  RowBox[{"tmp", "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.664702847322806*^9, 3.6647028669170837`*^9}, {
  3.664702976989875*^9, 3.664703040780554*^9}, {3.6647033443468313`*^9, 
  3.664703352495829*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"0"},
      {"0"},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", "\[Mu]S", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}], ")"}], " ", 
            RowBox[{"D\[Theta]", "[", "x", "]"}]}], "+", 
           RowBox[{"\[Mu]C", " ", "\[Omega]", " ", 
            RowBox[{"\[Theta]", "[", "x", "]"}]}]}], ")"}]}], 
        RowBox[{"\[Mu]C", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}]}]]},
      {"0"},
      {"0"},
      {"0"},
      {"0"},
      {"0"},
      {"0"},
      {
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["\[Mu]C", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]L"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Eta]L", " ", 
             RowBox[{"(", 
              RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}]}], "-", 
            RowBox[{"\[Mu]S", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C", "+", "\[Mu]L", "-", 
               RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]}], ")"}], " ", 
          "\[Omega]", " ", 
          RowBox[{"D\[Alpha]", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Mu]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Beta]", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]C"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[Mu]L"}], "+", 
               RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], " ", 
             RowBox[{"D\[Theta]", "[", "x", "]"}]}], "+", 
            RowBox[{"\[Mu]C", " ", "\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Beta]", "2"], "-", 
                  RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Mu]L", "-", 
                  RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], " ", 
                RowBox[{"D\[CapitalLambda]m", "[", "x", "]"}]}], "-", 
               RowBox[{"2", " ", "\[Mu]C", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Eta]L", " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}]}], "-", 
                  RowBox[{"\[Mu]S", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Mu]C", "+", "\[Mu]L", "-", 
                    RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]}], ")"}], 
                " ", "\[Omega]", " ", 
                RowBox[{"\[Alpha]", "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "\[Mu]C"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Mu]L", "-", 
                  RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Beta]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
                   RowBox[{"\[Theta]", "[", "x", "]"}]}], "+", 
                  RowBox[{"\[Mu]C", " ", "\[Mu]S", " ", "\[Omega]", " ", 
                   RowBox[{"\[CapitalLambda]m", "[", "x", "]"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
         SuperscriptBox["\[Mu]C", "2"], " ", "\[Mu]L", " ", "\[Mu]S", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Mu]L"}], "+", 
           RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.664702862776855*^9, {3.664702979361621*^9, 3.664703041178878*^9}, 
   3.664703363540217*^9, 3.664733368193265*^9, 3.664815375777536*^9, 
   3.664818570637847*^9, {3.671593087733169*^9, 3.671593103226109*^9}, 
   3.673231907523939*^9, {3.673231943879465*^9, 3.673231951816596*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Msim", ".", 
           RowBox[{"TroubledMinusTerms", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "+", 
         RowBox[{"\[Omega]", " ", 
          RowBox[{"TroubledMinusTerms", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], "//.", "UnLambdaRules"}], "/.",
        "GammaRules"}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", 
     "FullSimplify"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6647030448003683`*^9, 3.66470304796131*^9}, {
  3.664703094675746*^9, 3.66470319489117*^9}, {3.664703260428802*^9, 
  3.6647032907713327`*^9}, {3.664703357740015*^9, 3.664703361604533*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "+", "\[Mu]S", "-", 
          RowBox[{"\[Eta]L", " ", "\[Mu]S"}], "-", 
          RowBox[{"\[Mu]L", " ", "\[Mu]S"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]Ss"}]}], 
         ")"}], " ", "\[Omega]"}], 
       RowBox[{"\[Mu]S", " ", 
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "+", "\[Mu]S", "-", 
          RowBox[{"\[Eta]L", " ", "\[Mu]S"}], "-", 
          RowBox[{"\[Mu]L", " ", "\[Mu]S"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Mu]Ss"}]}], 
         ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Mu]S", " ", 
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]Ss"}], ")"}]}]], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", "\[Omega]"}], 
       RowBox[{"2", " ", "\[Mu]S"}]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]S", "-", "\[Mu]Ss"}], ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Mu]S"}]], "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
        RowBox[{
         SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Mu]S", "2"], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}], "2"]]}], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Beta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Omega]"}], 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}]], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Beta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}]}]], "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.664703045189735*^9, 3.664703048327959*^9}, 
   3.6647030978081703`*^9, {3.664703148434976*^9, 3.664703195268786*^9}, {
   3.664703269777392*^9, 3.6647032910932198`*^9}, 3.664703364802991*^9, 
   3.664733368337915*^9, 3.664815375900509*^9, 3.664818570814533*^9, {
   3.6715930878312807`*^9, 3.671593103332782*^9}, 3.673231907619285*^9, {
   3.673231943970153*^9, 3.673231951901621*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Msim", "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}], ".", 
         RowBox[{"(", 
          RowBox[{"Msim", "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], ")"}], ".", 
         RowBox[{"TroubledMinusTerms", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "//.", "UnLambdaRules"}], "/.", 
       "GammaRules"}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", 
     "FullSimplify"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.664703303838608*^9, 3.66470332869132*^9}, 
   3.6647033685004683`*^9, 3.67323195493062*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["L2 solution (restricted gauge)", "Subsection",
 CellChangeTimes->{{3.547058194716805*^9, 3.547058205203157*^9}, {
   3.5470582393700438`*^9, 3.547058247176804*^9}, {3.547724289267255*^9, 
   3.5477242905840883`*^9}, {3.664476112393877*^9, 3.664476115472515*^9}, 
   3.664535436873125*^9, {3.664622400362667*^9, 3.664622408905747*^9}, {
   3.664622906819804*^9, 3.664622908292259*^9}, {3.664626274047022*^9, 
   3.6646262821592083`*^9}, {3.664630889620042*^9, 3.664630889779883*^9}, {
   3.6646330030591183`*^9, 3.6646330031945877`*^9}, 3.6646937939143744`*^9}],

Cell[CellGroupData[{

Cell["Define symbol", "Text",
 CellChangeTimes->{{3.664653234683989*^9, 3.6646532410541773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MRestricted", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"M", "/.", "Use\[Mu]SsRules"}], "/.", 
              RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", 
             RowBox[{"\[Lambda]\[Mu]Ss", "\[Rule]", "\[Lambda]\[Mu]S"}]}], "/.", 
            RowBox[{"\[Gamma]\[Mu]Ss", "\[Rule]", "\[Gamma]\[Mu]S"}]}], "/.", 
           
           RowBox[{"\[Mu]C", "\[Rule]", "1"}]}], "/.", 
          RowBox[{"\[Gamma]\[Mu]C", "\[Rule]", "\[Gamma]"}]}], "/.", 
         RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "//", "FullSimplify"}], 
       ")"}], "/.", "UseGammaRules"}], "/.", "TauRules"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664651708425252*^9, 3.664651741778697*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MsimRestricted", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Msim", "/.", 
            RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", 
           RowBox[{"\[Lambda]\[Mu]Ss", "\[Rule]", "\[Lambda]\[Mu]S"}]}], "/.", 
          RowBox[{"\[Gamma]\[Mu]Ss", "\[Rule]", "\[Gamma]\[Mu]S"}]}], "/.", 
         RowBox[{"\[Mu]C", "\[Rule]", "1"}]}], "/.", 
        RowBox[{"\[Gamma]\[Mu]C", "\[Rule]", "\[Gamma]"}]}], "/.", 
       RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "//", "FullSimplify"}], 
     ")"}], "/.", "UseGammaRules"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664626550146161*^9, 3.6646265616290073`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define symbol in special case", "Text",
 CellChangeTimes->{{3.6646532560041027`*^9, 3.664653262521781*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MRestrictedMinus", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MRestricted", "/.", "UnTauRules"}], "/.", "UnLambdaRules"}], "/.",
       "GammaRules"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.66465305662142*^9, 3.664653130993875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MsimRestrictedMinus", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MsimRestricted", "/.", "UnTauRules"}], "/.", 
       "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664653168206805*^9, 3.6646531811975403`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplified right evecs of Msim ", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
   3.664632542514098*^9, 3.664632550281972*^9}, 3.664632727487318*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evecsInRestricted", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664566220021119*^9, 3.664566270817877*^9}, {
  3.6645669249265223`*^9, 3.664566943894629*^9}, {3.664567172587944*^9, 
  3.664567199729597*^9}, {3.6646095365718803`*^9, 3.664609538271543*^9}, {
  3.664627034331801*^9, 3.664627036350967*^9}, {3.664627170018071*^9, 
  3.664627172648386*^9}, {3.6646273922869*^9, 3.664627401528821*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"]}], " ", "\[Lambda]\[Mu]L", " ", 
      SqrtBox["\[Mu]L"]}], ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]L"}], ")"}], " ", 
        "\[Mu]S", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Beta]", " ", "\[Lambda]\[Mu]L"}], "+", 
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]L"]}]}], ")"}], " ", 
        SqrtBox["\[Mu]L"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
        SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[Lambda]\[Mu]L", " ", 
             SqrtBox["\[Mu]L"]}], 
            SuperscriptBox["\[Gamma]\[Mu]S", "2"]]}], "+", 
          RowBox[{"s", " ", "\[Beta]", " ", 
           RowBox[{"(", 
            RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}]}]}], ")"}], " ", 
        "\[Mu]S", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", "\[Chi]\[Mu]L"}]]}], 
     ",", 
     FractionBox[
      RowBox[{"2", " ", "\[Mu]L", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
       SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Gamma]", "2"], " ", 
       SuperscriptBox["\[Gamma]\[Mu]L", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}]}], "-", 
         FractionBox[
          RowBox[{"\[Lambda]\[Mu]L", " ", 
           SqrtBox["\[Mu]L"]}], 
          SuperscriptBox["\[Gamma]", "2"]]}], ")"}], " ", "\[Mu]L", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
       SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646274061016197`*^9, 3.664627429654195*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
      SqrtBox["\[Mu]S"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664628983665291*^9, 3.664628986417151*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
      SqrtBox["\[Mu]S"]}], ",", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Chi]\[Mu]S"], 
     ",", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]", " ", 
          SuperscriptBox["\[Gamma]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
         RowBox[{"\[Lambda]\[Mu]S", " ", 
          SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Omega]"}], "\[Chi]\[Mu]S"], 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664629143514254*^9, 3.664629146314645*^9}, 
   3.6646306042936296`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"]}], " ", "\[Lambda]\[Mu]S", " ", 
      SqrtBox["\[Mu]S"]}], ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "\[Chi]\[Mu]S"], ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "\[Beta]", " ", 
          SuperscriptBox["\[Gamma]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], "-", 
         RowBox[{"\[Lambda]\[Mu]S", " ", 
          SqrtBox["\[Mu]S"]}]}], ")"}], " ", "\[Omega]"}], "\[Chi]\[Mu]S"]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664629318616652*^9, 3.664629323225622*^9}, {
  3.664629458544219*^9, 3.664629467152918*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["4", 
       RowBox[{
        SuperscriptBox["\[Gamma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"s", "+", 
          RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}]}]]}], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
       SuperscriptBox["\[Gamma]\[Mu]S", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Beta]", " ", 
          SuperscriptBox["\[Lambda]\[Mu]S", "2"]}], "-", 
         RowBox[{"s", " ", "\[Lambda]", " ", "\[Mu]S"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"s", "-", 
         RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", "\[Lambda]"}]}], ")"}]}]], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664630451172876*^9, 3.664630455317827*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], "\[Lambda]"}], ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664629653002543*^9, 3.664629655154071*^9}, 
   3.664630465345059*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664629702344678*^9, 3.6646297045766487`*^9}, 
   3.6646304669994707`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", 
     ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",", 
     "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664629794127569*^9, 3.6646298033475513`*^9}, 
   3.664630468152136*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664629453163596*^9, 3.6646294640414658`*^9}, 
   3.664630469288*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestricted", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Gamma]", "2"]}], " ", "\[Lambda]"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6646295009501123`*^9, 3.664629513666387*^9}, 
   3.664630470406981*^9}],

Cell["Check what happens in the special case :", "Text",
 CellChangeTimes->{{3.664631496380356*^9, 3.664631514211933*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"evecsInRestricted", "/.", "UnLambdaRules"}], "/.", 
         "GammaRules"}], "/.", "ChiRules"}], "//", "FullSimplify"}], ")"}], "//",
      "FullSimplify"}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], "]"}], ";"}]], "Input",\

 CellChangeTimes->{{3.664630478611442*^9, 3.664630578133033*^9}, 
   3.6646308625001097`*^9}],

Cell["\<\
Since come components blowup we probably have to compute the evecs again.\
\>", "Text",
 CellChangeTimes->{{3.664631516330241*^9, 3.664631535500588*^9}, {
  3.664631640131535*^9, 3.664631641682658*^9}}],

Cell["Check to see how much regularity we gain here", "Text",
 CellChangeTimes->{{3.664632728248658*^9, 3.664632750528091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"evecsInRestricted", "-", "evecsIn"}], "/.", "ChiRules"}], "/.",
        "UnLambdaRules"}], "/.", "GammaRules"}], "/.", 
     RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", 
    RowBox[{"\[Mu]C", "\[Rule]", "1"}]}], "/.", 
   RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "//", 
  "FullSimplify"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}], " ", 
       SqrtBox["\[Mu]S"], " ", "\[Omega]"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]S"]}], "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Mu]S", " ", "\[Omega]", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}]]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]S"]}], "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Beta]", "2"], "-", "\[Mu]S"}], ")"}], "2"], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", 
          SqrtBox["\[Mu]S"]}], "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}], "2"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"s", " ", "\[Beta]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}]], "+", 
          RowBox[{
           SqrtBox["\[Mu]S"], " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["s", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], 
              " ", 
              SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", 
           SqrtBox["\[Mu]S"]}], "+", 
          RowBox[{"\[Beta]", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["s", "2"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}], ")"}], 
              " ", 
              SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}], "2"]]}], ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], "3"], " ", 
       SuperscriptBox["\[Omega]", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}], "3"]], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox["\[Omega]", "2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["s", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}], "3"]], ",", "0",
      ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Beta]"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{"s", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["s", "2"], "+", 
          SuperscriptBox["\[Omega]", "2"], "-", 
          RowBox[{
           SuperscriptBox["\[Beta]", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}]]}]}], 
      RowBox[{
       SuperscriptBox["s", "2"], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "2"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
        SuperscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{"s", " ", "\[Beta]", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["s", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}]]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"s", "+", 
         RowBox[{"\[Beta]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["s", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}]]}]}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", "\[Omega]"}], 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["s", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}]]}]}]], ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["s", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}]]}], 
      RowBox[{"s", "+", 
       RowBox[{"\[Beta]", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["s", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[Beta]", "2"]}], ")"}], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}]]}]}]], ",", "0", ",", "0", ",",
      "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.664641136453751*^9, 3.664654489581811*^9, 
  3.664691042397106*^9, 3.664694052687242*^9, 3.6647007888687057`*^9, 
  3.664733378737543*^9, 3.664815384953102*^9, 3.664818579978835*^9, 
  3.671593163598949*^9, 3.673231978442006*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution at generic frequencies", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
  3.664622466713491*^9, 3.6646224785522833`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"solnMatrixRestricted", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Tau]\[Mu]Lm", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", "\[Mu]S", " ", 
          "\[Tau]\[Mu]Lm"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", "\[Chi]\[Mu]L"}]]}],
        ",", 
       FractionBox["\[Chi]\[Mu]S", 
        RowBox[{"2", " ", "\[Tau]\[Mu]Sm"}]], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]\[Mu]Sm"]}], ",", 
       "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", "\[Mu]S", " ", 
          SuperscriptBox["\[Tau]\[Mu]Lm", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", "\[Chi]\[Mu]L"}]]}],
        ",", 
       FractionBox["\[Chi]\[Mu]S", "2"], ",", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], ",", "0", ",", "0",
        ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", "\[Mu]S", " ", 
          "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", "\[Chi]\[Mu]L"}]]}],
        ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]L"}], ")"}], " ", "\[Mu]S", " ", 
          "\[Tau]\[Mu]Lm", " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", "\[Chi]\[Mu]L"}]]}],
        ",", "0", ",", "\[Tau]\[Mu]Sm", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Mu]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Tau]\[Mu]Lm", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Chi]\[Mu]L", "2"]}]]}], ",", "1", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
         "\[Chi]\[Mu]S"]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Tau]m", "2"], "+", 
            SuperscriptBox["\[Omega]", "2"]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[Tau]m", "2"], " ", "\[Chi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox["2", "\[Tau]m"]}], ",", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
        SuperscriptBox["\[Tau]m", "2"]], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]L", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
         SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], ",", "0", ",", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Chi]\[Mu]S"],
        ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Chi]"}], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", 
       FractionBox["2", "\[Tau]m"], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", "0", ",", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        SuperscriptBox["\[Tau]m", "2"]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Mu]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Tau]\[Mu]Lm", 
          " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Chi]\[Mu]L", "2"]}]]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], 
        RowBox[{"2", " ", "\[Tau]\[Mu]Sm"}]], ",", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", "\[Mu]S", " ", 
          SuperscriptBox["\[Tau]\[Mu]Sm", "2"]}], "-", 
         SuperscriptBox["\[Chi]\[Mu]S", "2"]}], 
        RowBox[{"\[Mu]S", " ", "\[Tau]\[Mu]Sm", " ", "\[Chi]\[Mu]S"}]], ",", 
       "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
         RowBox[{"\[Tau]m", " ", "\[Chi]"}]]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox["2", "\[Tau]m"]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]m"]}], ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Mu]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Tau]\[Mu]Lm", "3"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Chi]\[Mu]L", "2"]}]]}], ",", "\[Tau]\[Mu]Sm", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
         "2", " ", "\[ImaginaryI]", " ", "\[Tau]\[Mu]Sm", " ", "\[Omega]"}], 
         "\[Chi]\[Mu]S"]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["\[Tau]m", "2"]}], "-", 
            SuperscriptBox["\[Chi]", "2"]}], ")"}]}], 
         RowBox[{"\[Tau]m", " ", "\[Chi]"}]]}], ",", 
       RowBox[{"-", "2"}], ",", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]m"], ",",
        "0", ",", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], "\[Tau]m"]}], ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]L", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", "\[Tau]\[Mu]Lm", 
         " ", 
         SuperscriptBox["\[Omega]", "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
         SuperscriptBox["\[Chi]\[Mu]L", "2"]}]], ",", "0", ",", 
       FractionBox[
        RowBox[{
        "2", " ", "\[ImaginaryI]", " ", "\[Tau]\[Mu]Sm", " ", "\[Omega]"}], 
        "\[Chi]\[Mu]S"], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Chi]"}], "\[Tau]m"]}], ",", "2", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]m"]}], 
       ",", "0", ",", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], "\[Tau]m"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Mu]L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Tau]\[Mu]Lm", "2"], " ", "\[Omega]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]L", "-", "\[Mu]S"}], ")"}], " ", 
          SuperscriptBox["\[Chi]\[Mu]L", "2"]}]]}], ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "2"], ",", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Chi]\[Mu]S", "2"], "+", 
         RowBox[{"2", " ", "\[Mu]S", " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], 
        RowBox[{"\[Mu]S", " ", "\[Chi]\[Mu]S"}]], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Chi]"]}], 
       ",", "0", ",", 
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       FractionBox["\[Tau]\[Mu]Sm", "\[Chi]\[Mu]S"], ",", "0", ",", "0", ",", 
       "0", ",", 
       RowBox[{"-", 
        FractionBox["2", "\[Tau]m"]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]m"]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "\[Chi]\[Mu]S"], ",", "0",
        ",", "0", ",", "0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Chi]"}], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", 
       FractionBox["2", "\[Tau]m"], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Chi]", "2"], 
         SuperscriptBox["\[Tau]m", "2"]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       FractionBox[
        SuperscriptBox["\[Tau]\[Mu]Sm", "2"], "\[Chi]\[Mu]S"], ",", "0", ",", 
       "0", ",", "0", ",", 
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Tau]\[Mu]Sm", " ", "\[Omega]"}], 
        "\[Chi]\[Mu]S"], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", "\[Tau]m"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[Chi]"}], "\[Tau]m"]}], ",", "2", ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "\[Tau]m"]}], 
       ",", "0", ",", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Chi]", "2"], "\[Tau]m"]}], ",", "0"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "\[Tau]\[Mu]Sm", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.664652218034836*^9, 3.664652232151771*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "=", 
   RowBox[{"solnMatrixRestricted", ".", "\[Sigma]Vec"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664652062160942*^9, 3.6646520671009617`*^9}, {
   3.664652175454179*^9, 3.6646522024303427`*^9}, 3.664652887769774*^9}],

Cell[CellGroupData[{

Cell["Check that the solution is correct", "Text",
 CellChangeTimes->{{3.6646528386611757`*^9, 3.66465284624511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", "MRestricted", ")"}], ".", 
                    "usolnRestricted"}], ")"}], "-", 
                    RowBox[{
                    RowBox[{"evalIn", "[", 
                    RowBox[{"[", "6", "]"}], "]"}], "usolnRestricted"}]}], 
                   ")"}], "/.", 
                  RowBox[{"\[Sigma]\[Alpha]", "\[Rule]", "0"}]}], "/.", 
                 RowBox[{"\[Sigma]\[Beta]s", "\[Rule]", "0"}]}], "/.", 
                RowBox[{"\[Sigma]\[Beta]\[Omega]", "\[Rule]", "0"}]}], "/.", 
               RowBox[{"\[Sigma]\[Beta]\[Nu]", "\[Rule]", "0"}]}], "/.", 
              RowBox[{"\[Sigma]\[Theta]", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"\[Sigma]Zs", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"\[Sigma]Z\[Omega]", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"\[Sigma]Z\[Nu]", "\[Rule]", "0"}]}], "/.", 
          RowBox[{"\[Sigma]RePsi", "\[Rule]", "0"}]}], "/.", 
         RowBox[{"\[Sigma]ImPsi", "\[Rule]", "0"}]}], "//", "Simplify"}], 
       ")"}], "/.", "ChiRules"}], "/.", "UnTauRules"}], "/.", 
    "UnLambdaRules"}], "/.", "GammaRules"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6646522729499073`*^9, 3.66465268093219*^9}, {
  3.6646527167648706`*^9, 3.66465283655884*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.664652590582355*^9, 3.664652681769112*^9}, {
   3.664652717886095*^9, 3.664652833189487*^9}, 3.664652895847455*^9, 
   3.6646544897386436`*^9, 3.664691042489094*^9, 3.664694052793004*^9, 
   3.664700788987116*^9, 3.6647333788309593`*^9, 3.664815385054378*^9, 
   3.6648185800890837`*^9, 3.671593172330638*^9, {3.67323198585182*^9, 
   3.673232000964364*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution at frequencies s = - \[Beta] \[Omega]", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
  3.664622466713491*^9, 3.6646224785522833`*^9}, {3.6646530083604727`*^9, 
  3.66465301843132*^9}}],

Cell[CellGroupData[{

Cell["Simplified right evecs of MsimRestrictedMinus", "Text",
 CellChangeTimes->{{3.664566991832514*^9, 3.664567016817181*^9}, {
   3.664632542514098*^9, 3.664632550281972*^9}, 3.664632727487318*^9, {
   3.664653323639179*^9, 3.664653335468171*^9}, 3.664654322038663*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"MsimRestrictedMinus", "+", 
     RowBox[{"\[Omega]", " ", 
      RowBox[{"IdentityMatrix", "[", "20", "]"}]}]}], "//", "NullSpace"}], 
   ")"}], ";"}]], "Input",
 CellChangeTimes->{{3.6646531853582087`*^9, 3.664653217947124*^9}, {
   3.664653625854332*^9, 3.664653630734517*^9}, {3.664653976599642*^9, 
   3.6646539797084093`*^9}, 3.6646543220393057`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evecsInRestrictedMinus", "=", 
   RowBox[{"{", 
    RowBox[{",", ",", ",", ",", ",", ",", ",", ",", ","}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664653365839375*^9, 3.664653366553439*^9}, 
   3.66465432203976*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Mu]L", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]L"}]]}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646533706713333`*^9, 3.664653396515225*^9}, 
   3.664654322040494*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}]]}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646534079851027`*^9, 3.664653436275304*^9}, 
   3.664654322041243*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}]]}], ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664653445018465*^9, 3.6646534571634293`*^9}, 
   3.664653526629293*^9, 3.664654322041918*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Mu]S", " ", "\[Omega]"}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Beta]", "2"]}], "+", "\[Mu]S"}]]}], ",", "0", ",", 
     "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664653464769312*^9, 3.664653464818918*^9}, 
   3.664653553412725*^9, 3.664654322042574*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}], ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664653466849428*^9, 3.664653468610808*^9}, 
   3.664653674855608*^9, 3.664653779962884*^9, 3.664653902078123*^9, 
   3.664654322043171*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}], ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.664653470700448*^9, 3.664653471675729*^9}, 
   3.664653698048147*^9, 3.664653782376511*^9, 3.664653937247344*^9, 
   3.664654322043762*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}], ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664653474917612*^9, 3.664653475001925*^9}, 
   3.664653863355399*^9, 3.6646543220443573`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", 
     ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}], ",", "0", ",", "0", ",", "0", 
     ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646534780752287`*^9, 3.6646534781640377`*^9}, 
   3.664653817859769*^9, 3.6646543220449467`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}], ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.664653480351386*^9, 3.664653480451976*^9}, 
   3.664653773878407*^9, 3.664654322045528*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evecsInRestrictedMinus", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["\[Omega]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Beta]", "2"]}]]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646534825297127`*^9, 3.664653482914979*^9}, 
   3.664653753835559*^9, 3.664654322046052*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestrictedMinus", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"SCoVinv", ".", 
            RowBox[{"(", 
             RowBox[{"evecsInRestrictedMinus", "//", "Transpose"}], ")"}], 
            ".", "\[Sigma]Vec"}], "/.", "Use\[Mu]SsRules"}], "/.", 
          RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", "UnTauRules"}], "/.", 
        RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "/.", 
       RowBox[{"\[Mu]C", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ",", "\[Sigma]Vec", 
     ",", "FullSimplify"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6646543705038843`*^9, 3.664654374139901*^9}, {
  3.664654497405284*^9, 3.664654608801819*^9}, {3.6646546609040003`*^9, 
  3.6646546669614973`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison for writeup", "Text",
 CellChangeTimes->{{3.664818288851022*^9, 3.6648183043188343`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Check that the general gauge also gives a solution in the restricted case\
\>", "Text",
 CellChangeTimes->{{3.6647074465874443`*^9, 3.6647074622718077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"MRestricted", ".", "usoln"}], ")"}], "-", " ", 
                    RowBox[{
                    RowBox[{"evalIn", "[", 
                    RowBox[{"[", "6", "]"}], "]"}], "usoln"}]}], "/.", 
                    RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", 
                    RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "/.", 
                    RowBox[{"\[Mu]C", " ", "\[Rule]", "1"}]}], "/.", 
                    RowBox[{"\[Tau]\[Mu]Cm", "->", "\[Tau]m"}]}], "/.", 
                   RowBox[{"\[Tau]\[Mu]Ssm", "->", "\[Tau]\[Mu]Sm"}]}], "/.", 
                  
                  RowBox[{"\[Chi]\[Mu]Ss", "->", "\[Chi]\[Mu]S"}]}], "/.", 
                 RowBox[{"\[Chi]\[Mu]C", "\[Rule]", "\[Chi]"}]}], "/.", 
                RowBox[{"\[Sigma]\[Alpha]", "\[Rule]", "0"}]}], "/.", 
               RowBox[{"\[Sigma]\[Beta]s", "\[Rule]", "0"}]}], "/.", 
              RowBox[{"\[Sigma]\[Beta]\[Omega]", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"\[Sigma]\[Beta]\[Nu]", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"\[Sigma]Zs", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"\[Sigma]Z\[Omega]", "\[Rule]", "0"}]}], "/.", 
          RowBox[{"\[Sigma]Z\[Nu]", "\[Rule]", "0"}]}], "/.", 
         RowBox[{"\[Sigma]RePsi", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"\[Sigma]\[Theta]", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Sigma]ImPsi", "\[Rule]", "1"}]}], "/.", "ChiRules"}], "/.", 
     "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", "GammaRules"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.6647066890623093`*^9, 3.664706691790002*^9}, {
  3.6647068943171587`*^9, 3.664706908701756*^9}, {3.6647069540302143`*^9, 
  3.664706969798958*^9}, {3.66470700037433*^9, 3.664707289254427*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.664706924454104*^9, {3.66470697154158*^9, 3.6647070247768717`*^9}, {
   3.6647070563570023`*^9, 3.66470728959918*^9}, 3.664733379095149*^9, 
   3.66481538543791*^9, 3.6648185803365498`*^9, 3.671593188977816*^9, 
   3.673232025131199*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Examine which metric components are altered by working in the restricted gauge\
\>", "Text",
 CellChangeTimes->{{3.66470747626091*^9, 3.6647075314465322`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["uold"], "Input",
 CellChangeTimes->{{3.664707556837873*^9, 3.6647075582787333`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "[", "x", "]"}], ",", 
   RowBox[{"d\[Alpha]", "[", "x", "]"}], ",", 
   RowBox[{"\[Beta]s", "[", "x", "]"}], ",", 
   RowBox[{"d\[Beta]s", "[", "x", "]"}], ",", 
   RowBox[{"\[Beta]\[Omega]", "[", "x", "]"}], ",", 
   RowBox[{"d\[Beta]\[Omega]", "[", "x", "]"}], ",", 
   RowBox[{"gss", "[", "x", "]"}], ",", 
   RowBox[{"gqq", "[", "x", "]"}], ",", 
   RowBox[{"gs\[Omega]", "[", "x", "]"}], ",", 
   RowBox[{"dgss", "[", "x", "]"}], ",", 
   RowBox[{"dgqq", "[", "x", "]"}], ",", 
   RowBox[{"dgs\[Omega]", "[", "x", "]"}], ",", 
   RowBox[{"gs\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"g\[Omega]\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"g\[Nu]\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"dgs\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"dg\[Omega]\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"dg\[Nu]\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"\[Beta]\[Nu]", "[", "x", "]"}], ",", 
   RowBox[{"d\[Beta]\[Nu]", "[", "x", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.664707558659122*^9, 3.664733379102551*^9, 
  3.664815385510017*^9, 3.664818580342071*^9, 3.6715931910411797`*^9, 
  3.6732320292545567`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"usolnRestricted", "-", "usoln"}], "/.", 
           RowBox[{"\[Mu]Ss", "\[Rule]", "\[Mu]S"}]}], "/.", 
          RowBox[{"\[Eta]L", "\[Rule]", "\[Mu]S"}]}], "/.", 
         RowBox[{"\[Mu]C", " ", "\[Rule]", "1"}]}], "/.", 
        RowBox[{"\[Tau]\[Mu]Cm", "->", "\[Tau]m"}]}], "/.", 
       RowBox[{"\[Tau]\[Mu]Ssm", "->", "\[Tau]\[Mu]Sm"}]}], "/.", 
      RowBox[{"\[Chi]\[Mu]Ss", "->", "\[Chi]\[Mu]S"}]}], "/.", 
     RowBox[{"\[Chi]\[Mu]C", "\[Rule]", "\[Chi]"}]}], ",", "\[Sigma]Vec", ",",
     "FullSimplify"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.664704907710579*^9, 3.66470504439541*^9}, {
   3.664705076848394*^9, 3.664705077983732*^9}, {3.664705111384432*^9, 
   3.66470512205361*^9}, {3.664707690629591*^9, 3.664707692279337*^9}, 
   3.664733298650469*^9, 3.673232033087484*^9}],

Cell[CellGroupData[{

Cell["\<\
We have that : \[Alpha], \[Beta]\[Nu], gsnu, gomeganu are unaffected. \
Therefore we need: \[Beta]s ,\[Beta]\[Omega], gss, gqq, gs\[Omega], g\[Nu]\
\[Nu]\
\>", "Text",
 CellChangeTimes->{{3.664707551759856*^9, 3.66470758333149*^9}, {
  3.664707630012158*^9, 3.6647076486517982`*^9}, {3.664733472217827*^9, 
  3.66473358205445*^9}}],

Cell["\[Beta]s", "Text",
 CellChangeTimes->{{3.66473371845786*^9, 3.6647337220304527`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "[", 
   RowBox[{"[", "3", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.664733623706107*^9, 3.664733646869293*^9}, 
   3.664734876965056*^9, {3.673232040364463*^9, 3.673232042631475*^9}}],

Cell["\[Beta]\[Omega]", "Text",
 CellChangeTimes->{{3.66473371845786*^9, 3.66473373896771*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "[", 
   RowBox[{"[", "5", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.664733623706107*^9, 3.664733646869293*^9}, 
   3.664733745286916*^9, 3.6647347569615602`*^9}],

Cell["gss", "Text",
 CellChangeTimes->{{3.664733766253039*^9, 3.664733769189101*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uold", "[", 
   RowBox[{"[", "7", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6647347593187857`*^9, 3.66473476190565*^9}, {
   3.664734871915296*^9, 3.6647348729791822`*^9}, 3.664736211325224*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "[", 
   RowBox[{"[", "7", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6647337714911003`*^9, 3.664733771779751*^9}, 
   3.66473620773057*^9}],

Cell["gqq", "Text",
 CellChangeTimes->{{3.664733784311743*^9, 3.664733787966194*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "[", 
   RowBox[{"[", "8", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6647337988323507`*^9, 3.6647337991892223`*^9}, 
   3.6648159377390738`*^9}],

Cell["gs\[Omega]", "Text",
 CellChangeTimes->{{3.664733784311743*^9, 3.664733787966194*^9}, {
  3.664733838817535*^9, 3.664733839633932*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"usolnRestricted", "[", 
         RowBox[{"[", "9", "]"}], "]"}], "/.", 
        RowBox[{"\[Sigma]Z\[Omega]", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Sigma]RePsi", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Sigma]\[Beta]s", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Sigma]\[Theta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Sigma]\[Alpha]", "\[Rule]", "0"}]}], "//", "Expand"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6647337988323507`*^9, 3.6647337991892223`*^9}, {
   3.664733841659585*^9, 3.6647338433392553`*^9}, {3.664816076237897*^9, 
   3.664816087391714*^9}, {3.6648162305433702`*^9, 3.6648162333805027`*^9}, {
   3.6648164286843233`*^9, 3.664816434657631*^9}, {3.664816747566086*^9, 
   3.664816752938582*^9}, {3.664816807854371*^9, 3.6648168372907057`*^9}, 
   3.664817174300702*^9}],

Cell["g\[Nu]\[Nu]", "Text",
 CellChangeTimes->{{3.6647338606811857`*^9, 3.664733863794311*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usolnRestricted", "[", 
   RowBox[{"[", "15", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.664733885941917*^9, 3.6647338860219927`*^9}, 
   3.6648176874869003`*^9, {3.6715932999776573`*^9, 3.671593304008738*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Now let' s see which variables are altered at the special frequency :\
\>", "Text",
 CellChangeTimes->{{3.664818827905692*^9, 3.664818849427712*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"usolnRestricted", "-", "usolnRestrictedMinus"}], ")"}], "/.", 
   "ChiRules"}], ";"}]], "Input",
 CellChangeTimes->{{3.671593386683052*^9, 3.671593405629715*^9}, 
   3.673232072514193*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"usolnRestricted", "-", "usolnRestrictedMinus"}], ")"}], "/.",
          "ChiRules"}], "/.", "UnTauRules"}], "/.", "UnLambdaRules"}], "/.", 
      "GammaRules"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[Beta]"}], " ", "\[Omega]"}]}]}], ",", "\[Sigma]Vec", 
    ",", 
    RowBox[{
     RowBox[{"PowerExpand", "@", 
      RowBox[{"Simplify", "@", "#"}]}], "&"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6648184929632063`*^9, 3.664818499970066*^9}, {
   3.6648185719551888`*^9, 3.664818572399989*^9}, {3.664818802799906*^9, 
   3.664818884806457*^9}, {3.6648189263185663`*^9, 3.664818961382991*^9}, 
   3.671593235111636*^9, {3.671593416060211*^9, 3.67159345440303*^9}, 
   3.673232076098773*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1145, 786},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
CellContext->Notebook,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 120, 2, 28, "Input"],
Cell[680, 24, 1354, 26, 159, "Subtitle"],
Cell[CellGroupData[{
Cell[2059, 54, 389, 9, 44, "Subsection"],
Cell[CellGroupData[{
Cell[2473, 67, 181, 2, 30, "Text"],
Cell[2657, 71, 3842, 105, 80, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6536, 181, 176, 2, 27, "Text"],
Cell[6715, 185, 3153, 92, 63, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[9905, 282, 109, 1, 27, "Text"],
Cell[10017, 285, 651, 15, 28, "Input"],
Cell[10671, 302, 559, 15, 28, "Input"],
Cell[11233, 319, 230, 6, 28, "Input"],
Cell[11466, 327, 2473, 67, 56, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13976, 399, 103, 1, 27, "Text"],
Cell[14082, 402, 2802, 82, 77, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[16921, 489, 180, 2, 27, "Text"],
Cell[17104, 493, 2230, 61, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[19371, 559, 156, 2, 27, "Text"],
Cell[19530, 563, 3907, 110, 109, "Input"],
Cell[23440, 675, 766, 19, 46, "Input"],
Cell[CellGroupData[{
Cell[24231, 698, 268, 6, 49, "Text"],
Cell[24502, 706, 861, 21, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[25400, 732, 101, 1, 27, "Text"],
Cell[25504, 735, 774, 19, 28, "Input"]
}, Closed]],
Cell[26293, 757, 605, 11, 22, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[26947, 774, 292, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[27264, 782, 204, 4, 30, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[27471, 788, 2100, 38, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[29574, 828, 1254, 26, 46, "Input"],
Cell[30831, 856, 498, 12, 28, "Input"],
Cell[31332, 870, 671, 13, 28, "Input"],
Cell[32006, 885, 295, 7, 28, "Input"],
Cell[32304, 894, 554, 11, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[32895, 910, 216, 4, 27, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[33114, 916, 2866, 81, 116, "Input"],
Cell[35983, 999, 3237, 94, 96, "Input"],
Cell[39223, 1095, 8842, 266, 496, "Input"],
Cell[48068, 1363, 1370, 35, 55, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[49441, 1400, 3186, 89, 80, "Input"],
Cell[52630, 1491, 668, 15, 50, "Input"],
Cell[53301, 1508, 1674, 47, 68, "Input"],
Cell[54978, 1557, 2021, 58, 68, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[57036, 1620, 230, 4, 27, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[57269, 1626, 5703, 133, 199, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[62975, 1761, 5500, 132, 199, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[68478, 1895, 849, 17, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[69364, 1917, 148, 3, 27, "Text"],
Cell[69515, 1922, 514, 11, 28, "Input"],
Cell[70032, 1935, 1064, 21, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[71133, 1961, 191, 3, 27, "Text"],
Cell[71327, 1966, 943, 21, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[72273, 1989, 881, 17, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[73157, 2008, 616, 13, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[73776, 2023, 1220, 26, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[75045, 2055, 180, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[75250, 2061, 129, 2, 30, "Text"],
Cell[75382, 2065, 688, 19, 46, "Input"],
Cell[76073, 2086, 2272, 54, 86, "Input"],
Cell[78348, 2142, 748, 22, 51, "Input"],
Cell[79099, 2166, 2676, 68, 80, "Input"],
Cell[81778, 2236, 377, 10, 28, "Input"],
Cell[82158, 2248, 1113, 28, 35, "Input"],
Cell[83274, 2278, 1210, 22, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[84521, 2305, 279, 4, 27, "Text"],
Cell[84803, 2311, 695, 14, 28, "Input"],
Cell[85501, 2327, 2935, 52, 46, "Input"],
Cell[88439, 2381, 954, 16, 28, "Input"],
Cell[89396, 2399, 283, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[89704, 2407, 1980, 40, 46, "Input"],
Cell[91687, 2449, 1921, 31, 53, "Output"]
}, Open  ]],
Cell[93623, 2483, 109, 1, 30, "Text"],
Cell[93735, 2486, 684, 17, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[94456, 2508, 228, 4, 27, "Text"],
Cell[94687, 2514, 2474, 41, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[97198, 2560, 184, 3, 27, "Text"],
Cell[97385, 2565, 1158, 25, 28, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[98592, 2596, 212, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[98829, 2603, 168, 3, 30, "Text"],
Cell[99000, 2608, 114, 1, 30, "Text"],
Cell[99117, 2611, 749, 12, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[99903, 2628, 187, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[100115, 2635, 191, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[100331, 2641, 2669, 55, 80, "Input"],
Cell[103003, 2698, 3795, 70, 70, "Output"]
}, Closed]],
Cell[106813, 2771, 507, 13, 22, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[107357, 2789, 241, 3, 27, "Text"],
Cell[107601, 2794, 454, 10, 28, "Input"],
Cell[108058, 2806, 249, 7, 28, "Input"],
Cell[108310, 2815, 534, 13, 34, "Input"],
Cell[108847, 2830, 2157, 44, 54, "Input"],
Cell[111007, 2876, 4568, 119, 175, "Input"],
Cell[115578, 2997, 497, 12, 34, "Input"],
Cell[116078, 3011, 702, 15, 34, "Input"],
Cell[116783, 3028, 1491, 36, 35, "Input"],
Cell[118277, 3066, 1232, 32, 51, "Input"],
Cell[119512, 3100, 660, 14, 32, "Input"],
Cell[120175, 3116, 1498, 36, 51, "Input"],
Cell[121676, 3154, 5629, 143, 150, "Input"],
Cell[CellGroupData[{
Cell[127330, 3301, 158, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[127513, 3308, 5127, 83, 46, "Input"],
Cell[132643, 3393, 254, 6, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[132958, 3406, 241, 3, 27, "Text"],
Cell[133202, 3411, 506, 11, 28, "Input"],
Cell[133711, 3424, 298, 7, 28, "Input"],
Cell[134012, 3433, 583, 14, 34, "Input"],
Cell[134598, 3449, 1651, 37, 54, "Input"],
Cell[136252, 3488, 4373, 115, 173, "Input"],
Cell[140628, 3605, 574, 13, 34, "Input"],
Cell[141205, 3620, 775, 16, 34, "Input"],
Cell[141983, 3638, 1631, 38, 35, "Input"],
Cell[143617, 3678, 1786, 46, 51, "Input"],
Cell[145406, 3726, 686, 15, 32, "Input"],
Cell[146095, 3743, 1580, 35, 51, "Input"],
Cell[147678, 3780, 5176, 139, 164, "Input"],
Cell[CellGroupData[{
Cell[152879, 3923, 158, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[153062, 3930, 3457, 64, 63, "Input"],
Cell[156522, 3996, 1334, 21, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[157917, 4024, 207, 4, 27, "Text"],
Cell[158127, 4030, 362, 10, 28, "Input"],
Cell[158492, 4042, 969, 24, 28, "Input"],
Cell[159464, 4068, 911, 24, 28, "Input"],
Cell[160378, 4094, 130, 2, 30, "Text"],
Cell[160511, 4098, 1146, 28, 46, "Input"],
Cell[161660, 4128, 252, 5, 28, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[161961, 4139, 371, 6, 27, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[162335, 4147, 712, 16, 28, "Input"],
Cell[163050, 4165, 332, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[163407, 4175, 1615, 35, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[165025, 4212, 3158, 97, 101, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[168232, 4315, 197, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[168454, 4322, 96, 1, 30, "Text"],
Cell[168553, 4325, 1417, 27, 91, "Text"],
Cell[169973, 4354, 541, 13, 28, "Input"],
Cell[CellGroupData[{
Cell[170539, 4371, 811, 21, 46, "Input"],
Cell[171353, 4394, 3733, 115, 101, "Output"]
}, Open  ]],
Cell[175101, 4512, 954, 25, 46, "Input"],
Cell[CellGroupData[{
Cell[176080, 4541, 965, 17, 28, "Input"],
Cell[177048, 4560, 8271, 225, 302, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[185368, 4791, 203, 4, 27, "Text"],
Cell[185574, 4797, 1018, 27, 63, "Input"],
Cell[186595, 4826, 371, 8, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[187003, 4839, 314, 4, 27, "Text"],
Cell[187320, 4845, 1796, 40, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[189153, 4890, 138, 1, 27, "Text"],
Cell[189294, 4893, 231, 6, 28, "Input"],
Cell[189528, 4901, 420, 9, 28, "Input"],
Cell[189951, 4912, 811, 15, 28, "Input"],
Cell[190765, 4929, 1131, 32, 59, "Input"],
Cell[191899, 4963, 419, 9, 28, "Input"],
Cell[192321, 4974, 1136, 27, 53, "Input"],
Cell[193460, 5003, 1517, 44, 59, "Input"],
Cell[194980, 5049, 1137, 29, 55, "Input"],
Cell[196120, 5080, 467, 10, 28, "Input"],
Cell[196590, 5092, 490, 10, 28, "Input"],
Cell[197083, 5104, 373, 9, 28, "Input"],
Cell[197459, 5115, 469, 12, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[197965, 5132, 207, 4, 27, "Text"],
Cell[198175, 5138, 2166, 50, 97, "Input"],
Cell[CellGroupData[{
Cell[200366, 5192, 1324, 38, 80, "Input"],
Cell[201693, 5232, 605, 11, 28, "Output"]
}, Open  ]],
Cell[202313, 5246, 644, 19, 28, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[203018, 5272, 409, 5, 36, "Subsection"],
Cell[203430, 5279, 1045, 28, 63, "Input"],
Cell[CellGroupData[{
Cell[204500, 5311, 112, 1, 30, "Text"],
Cell[204615, 5314, 15393, 403, 683, "Input"],
Cell[CellGroupData[{
Cell[220033, 5721, 389, 10, 28, "Input"],
Cell[220425, 5733, 15491, 417, 586, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[235965, 6156, 164, 2, 27, "Text"],
Cell[236132, 6160, 12642, 332, 471, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[248811, 6497, 218, 3, 27, "Text"],
Cell[249032, 6502, 111, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[249168, 6507, 461, 12, 28, "Input"],
Cell[249632, 6521, 729, 14, 41, "Message"],
Cell[250364, 6537, 731, 14, 41, "Message"],
Cell[251098, 6553, 733, 14, 43, "Message"],
Cell[251834, 6569, 811, 15, 24, "Message"],
Cell[252648, 6586, 4346, 102, 326, "Output"]
}, Closed]],
Cell[257009, 6691, 226, 6, 22, "Input"],
Cell[257238, 6699, 1702, 48, 82, "Input"],
Cell[258943, 6749, 89, 2, 28, "Input"],
Cell[259035, 6753, 2831, 78, 99, "Input"],
Cell[261869, 6833, 572, 14, 50, "Input"],
Cell[262444, 6849, 579, 15, 50, "Input"],
Cell[263026, 6866, 157, 3, 28, "Input"],
Cell[263186, 6871, 1586, 43, 83, "Input"],
Cell[264775, 6916, 588, 15, 48, "Input"],
Cell[265366, 6933, 560, 14, 48, "Input"],
Cell[265929, 6949, 568, 15, 48, "Input"],
Cell[266500, 6966, 560, 14, 48, "Input"],
Cell[267063, 6982, 563, 14, 48, "Input"],
Cell[267629, 6998, 748, 23, 28, "Input"],
Cell[268380, 7023, 971, 27, 46, "Input"],
Cell[CellGroupData[{
Cell[269376, 7054, 134, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[269535, 7059, 694, 18, 46, "Input"],
Cell[270232, 7079, 5571, 143, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275840, 7227, 935, 25, 46, "Input"],
Cell[276778, 7254, 4183, 112, 136, "Output"]
}, Open  ]],
Cell[280976, 7369, 952, 27, 46, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[281989, 7403, 566, 7, 36, "Subsection"],
Cell[CellGroupData[{
Cell[282580, 7414, 97, 1, 30, "Text"],
Cell[282680, 7417, 922, 24, 46, "Input"],
Cell[283605, 7443, 762, 19, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[284404, 7467, 113, 1, 27, "Text"],
Cell[284520, 7470, 440, 13, 28, "Input"],
Cell[284963, 7485, 450, 13, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[285450, 7503, 185, 2, 27, "Text"],
Cell[285638, 7507, 521, 10, 28, "Input"],
Cell[286162, 7519, 3151, 88, 138, "Input"],
Cell[289316, 7609, 579, 13, 40, "Input"],
Cell[289898, 7624, 1177, 30, 60, "Input"],
Cell[291078, 7656, 1179, 30, 60, "Input"],
Cell[292260, 7688, 1410, 39, 56, "Input"],
Cell[293673, 7729, 565, 15, 35, "Input"],
Cell[294241, 7746, 571, 14, 35, "Input"],
Cell[294815, 7762, 575, 15, 35, "Input"],
Cell[295393, 7779, 566, 14, 35, "Input"],
Cell[295962, 7795, 573, 15, 35, "Input"],
Cell[296538, 7812, 122, 1, 30, "Text"],
Cell[296663, 7815, 540, 17, 28, "Input"],
Cell[297206, 7834, 212, 4, 30, "Text"],
Cell[297421, 7840, 127, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[297573, 7845, 430, 13, 28, "Input"],
Cell[298006, 7860, 11221, 314, 394, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[309276, 8180, 164, 2, 27, "Text"],
Cell[309443, 8184, 12174, 329, 513, "Input"],
Cell[321620, 8515, 276, 5, 28, "Input"],
Cell[CellGroupData[{
Cell[321921, 8524, 117, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[322063, 8529, 1696, 41, 63, "Input"],
Cell[323762, 8572, 645, 11, 28, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[324468, 8590, 229, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[324722, 8597, 271, 3, 30, "Text"],
Cell[324996, 8602, 420, 10, 28, "Input"],
Cell[325419, 8614, 261, 7, 28, "Input"],
Cell[325683, 8623, 663, 17, 50, "Input"],
Cell[326349, 8642, 663, 17, 50, "Input"],
Cell[327015, 8661, 682, 17, 50, "Input"],
Cell[327700, 8680, 688, 18, 50, "Input"],
Cell[328391, 8700, 672, 17, 48, "Input"],
Cell[329066, 8719, 670, 17, 48, "Input"],
Cell[329739, 8738, 621, 15, 48, "Input"],
Cell[330363, 8755, 631, 16, 48, "Input"],
Cell[330997, 8773, 619, 15, 48, "Input"],
Cell[331619, 8790, 622, 15, 48, "Input"]
}, Open  ]],
Cell[332256, 8808, 952, 24, 63, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[333245, 8837, 106, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[333376, 8842, 167, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[333568, 8849, 2277, 51, 63, "Input"],
Cell[335848, 8902, 526, 10, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[336423, 8918, 169, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[336617, 8925, 98, 1, 28, "Input"],
Cell[336718, 8928, 1167, 25, 46, "Output"]
}, Open  ]],
Cell[337900, 8956, 993, 23, 46, "Input"],
Cell[CellGroupData[{
Cell[338918, 8983, 341, 7, 30, "Text"],
Cell[339262, 8992, 91, 1, 30, "Text"],
Cell[339356, 8995, 248, 5, 28, "Input"],
Cell[339607, 9002, 95, 1, 30, "Text"],
Cell[339705, 9005, 226, 5, 28, "Input"],
Cell[339934, 9012, 85, 1, 30, "Text"],
Cell[340022, 9015, 240, 5, 28, "Input"],
Cell[340265, 9022, 203, 5, 28, "Input"],
Cell[340471, 9029, 85, 1, 30, "Text"],
Cell[340559, 9032, 208, 5, 28, "Input"],
Cell[340770, 9039, 141, 2, 30, "Text"],
Cell[340914, 9043, 925, 21, 28, "Input"],
Cell[341842, 9066, 95, 1, 30, "Text"],
Cell[341940, 9069, 255, 5, 28, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[342244, 9080, 159, 3, 27, "Text"],
Cell[342406, 9085, 253, 7, 28, "Input"],
Cell[342662, 9094, 915, 24, 46, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
