(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     54820,       1471]
NotebookOptionsPosition[     50841,       1326]
NotebookOutlinePosition[     51280,       1343]
CellTagsIndexPosition[     51237,       1340]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Exit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.653035122861473*^9, 3.653035124203897*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Strong hyperbolicity analysis for HR with live gauges\n",
  FontWeight->"Bold"],
 "David Hilditch and Milton Ruiz. \n",
 StyleBox["In this notebook we show that the formulation of [arXiv:1303.4783] \
 with their \npreferred choice is strongly hyperbolic with a parametrized \
family including the moving-puncture gauge. ",
  FontSize->16]
}], "Subtitle",
 CellChangeTimes->{{3.530345106049459*^9, 3.530345117173244*^9}, {
   3.536995309680488*^9, 3.536995313709453*^9}, 3.5372623602272997`*^9, {
   3.5472123969042664`*^9, 3.547212407211228*^9}, {3.5483997446856956`*^9, 
   3.548399750808976*^9}, {3.651173859883544*^9, 3.651173861961891*^9}, {
   3.6513767653477583`*^9, 3.651376765687461*^9}, {3.651428363782976*^9, 
   3.651428364334887*^9}, {3.6514284082689953`*^9, 3.6514284094535913`*^9}, {
   3.651428445677929*^9, 3.6514284465650663`*^9}, {3.6514307380135527`*^9, 
   3.6514307504933023`*^9}, {3.651675705705524*^9, 3.651675705819215*^9}, {
   3.653035128410108*^9, 3.653035133138555*^9}, 3.673228721162388*^9, {
   3.673230016670929*^9, 3.673230020352199*^9}, 3.673230065336207*^9, {
   3.6779311384234333`*^9, 3.677931155965069*^9}}],

Cell[CellGroupData[{

Cell["Scalar Sector", "Subsubsection",
 CellChangeTimes->{{3.466338036607253*^9, 3.466338038218553*^9}, {
  3.466338073237733*^9, 3.466338075298904*^9}}],

Cell[CellGroupData[{

Cell["Define scalar variables and PP", "Text",
 CellChangeTimes->{{3.466488954440176*^9, 3.466488963580868*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uS", "=", 
   RowBox[{"{", 
    RowBox[{
    "D\[Alpha]", ",", "D\[Beta]s", ",", "Khat", ",", "hatGams", ",", 
     "D\[Gamma]qq", ",", "Kqq", ",", "Theta", ",", "Zs"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4663380885744677`*^9, 3.466338107090262*^9}, {
  3.466338293237855*^9, 3.466338343712699*^9}, {3.54571917310456*^9, 
  3.5457192450002317`*^9}, {3.550641317875174*^9, 3.550641318014831*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PPS", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Beta]s", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Alpha]", "2"]}], "\[Mu]L"}], ",", "0", ",", "0", 
       ",", "0", ",", "0", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], " ", "\[Eta]L"}], ",", "\[Beta]s", ",", 
       "0", ",", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], "\[Mu]S"}], ",", "0", ",", "0", ",", 
       "0", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", "\[Beta]s", ",", "0", ",", "0", ",",
        "0", ",", "0", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "\[Mu]C", ",", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], " ", "\[Mu]C"}], ",", "\[Beta]s", ",", "0",
        ",", "0", ",", "0", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", " ", ",", "0", ",", "\[Beta]s", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "\[Alpha]"}], ",", "0", ",", "0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "\[Alpha]"}], ",", "\[Beta]s", ",", "0", 
       ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "\[Alpha]"}], ",", "0", ",", "\[Beta]s", 
       ",", "\[Alpha]"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"-", "\[Alpha]"}], ",", 
       RowBox[{"\[Alpha]", " ", "\[Mu]C"}], ",", "\[Beta]s"}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";", 
  RowBox[{
   RowBox[{"MatrixForm", "[", "PPS", "]"}], "//", "FullSimplify"}]}]], "Input",\

 CellChangeTimes->{{3.466338082200343*^9, 3.466338171697723*^9}, {
   3.466338346464651*^9, 3.466338537715082*^9}, {3.4663385859056063`*^9, 
   3.466338592614253*^9}, {3.466338643585685*^9, 3.4663387221027393`*^9}, 
   3.4663388013499928`*^9, 3.466338974113709*^9, {3.466339028097637*^9, 
   3.466339035073803*^9}, {3.4663391408072433`*^9, 3.466339145360198*^9}, 
   3.466339185887025*^9, {3.466339346113693*^9, 3.466339349591434*^9}, {
   3.466339740153556*^9, 3.4663397511940193`*^9}, {3.466339801016638*^9, 
   3.4663398133292418`*^9}, {3.466339929377377*^9, 3.46633994874726*^9}, 
   3.466342309574445*^9, 3.46642450220422*^9, 3.4664245551869507`*^9, 
   3.466424679201673*^9, 3.466424733793563*^9, {3.466424769208419*^9, 
   3.4664247994571333`*^9}, 3.4664249221285477`*^9, 3.466425025077598*^9, 
   3.4664253124971037`*^9, 3.4664253846818037`*^9, {3.466425559014119*^9, 
   3.46642556461994*^9}, {3.466425866749668*^9, 3.466425874895287*^9}, 
   3.4664266577775927`*^9, {3.466426719940617*^9, 3.466426747780582*^9}, {
   3.46642701198166*^9, 3.466427043144237*^9}, {3.4664299479959297`*^9, 
   3.466429972839308*^9}, 3.466430018957588*^9, {3.466430073453639*^9, 
   3.4664300814702377`*^9}, {3.466430118882469*^9, 3.466430123141622*^9}, {
   3.466430189328245*^9, 3.466430254617558*^9}, {3.4664303198256617`*^9, 
   3.466430319956855*^9}, {3.466430579492569*^9, 3.4664306223093233`*^9}, {
   3.46643169052168*^9, 3.4664316979404182`*^9}, 3.466431885825563*^9, {
   3.4664319312371483`*^9, 3.466431955408647*^9}, {3.4664320574535933`*^9, 
   3.466432066984577*^9}, {3.466432457744561*^9, 3.466432489636566*^9}, {
   3.466432519909581*^9, 3.466432520255745*^9}, {3.4664327105655737`*^9, 
   3.466432755381548*^9}, {3.466432804313814*^9, 3.4664328181205473`*^9}, {
   3.466433114253559*^9, 3.466433162557366*^9}, {3.4664334654457693`*^9, 
   3.466433475541626*^9}, {3.4664341922080584`*^9, 3.466434199576647*^9}, {
   3.545719330098579*^9, 3.545719445539653*^9}, {3.545719478428615*^9, 
   3.545719661001779*^9}, {3.5457196973299503`*^9, 3.545719736148316*^9}, {
   3.545719825920229*^9, 3.545719826663686*^9}, {3.550641366335266*^9, 
   3.550641371378982*^9}, {3.550641419238769*^9, 3.55064144843087*^9}, {
   3.5506415277096977`*^9, 3.550641534602241*^9}, 3.5506450814430103`*^9, {
   3.550904524546596*^9, 3.55090452762365*^9}, {3.550905530943177*^9, 
   3.5509055463098173`*^9}, {3.5509068309519157`*^9, 3.550906834462285*^9}, {
   3.551172267842067*^9, 3.5511722708829393`*^9}, {3.6530353712561207`*^9, 
   3.653035376957848*^9}, {3.6530354590863934`*^9, 3.6530354666831083`*^9}, {
   3.653035578949193*^9, 3.653035603482641*^9}, {3.653035687610808*^9, 
   3.653035706899673*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Beta]s", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Alpha]", "2"]}], " ", "\[Mu]L"}], "0", "0", "0", 
      "0", "0"},
     {
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", "\[Eta]L"}], "\[Beta]s", "0", 
      RowBox[{
       SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]S"}], "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "\[Beta]s", "0", "0", "0", "0", "0"},
     {"0", "\[Mu]C", 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", "\[Mu]C"}], "\[Beta]s", "0", "0", "0", 
      "0"},
     {"0", "0", "0", "0", "\[Beta]s", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Alpha]"}], "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[Alpha]", "2"]}], "\[Beta]s", "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[Alpha]", "2"]}], "0", "\[Beta]s", "\[Alpha]"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "\[Alpha]"}], 
      RowBox[{"\[Alpha]", " ", "\[Mu]C"}], "\[Beta]s"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.46643245844135*^9, 3.466432483966119*^9}, {
   3.466432521113399*^9, 3.4664325273345537`*^9}, {3.4664327112022257`*^9, 
   3.466432755762356*^9}, {3.466432804654469*^9, 3.466432818497322*^9}, {
   3.4664331148079443`*^9, 3.4664331832998543`*^9}, {3.4664334661801863`*^9, 
   3.4664334759531193`*^9}, {3.466434178893457*^9, 3.466434200238716*^9}, 
   3.466434318305369*^9, 3.4664343790892067`*^9, 3.4664889319720087`*^9, 
   3.4667486765132427`*^9, 3.476521109116888*^9, 3.520049721231389*^9, 
   3.545719739654275*^9, {3.545719792707735*^9, 3.545719838397547*^9}, 
   3.550641390708522*^9, 3.550641539166909*^9, 3.55064160601973*^9, 
   3.550641729233775*^9, 3.550645082305702*^9, 3.55064514755859*^9, 
   3.550904528463263*^9, 3.550905549238513*^9, 3.5509068346942167`*^9, 
   3.550990919596077*^9, 3.551105340049073*^9, 3.551170514690908*^9, 
   3.55117227116938*^9, 3.551172589109844*^9, {3.653035700037547*^9, 
   3.653035707321015*^9}, 3.653035863016458*^9, 3.6530359870450087`*^9, 
   3.671592508118348*^9, 3.673228867713134*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check the Jordan decomposition", "Text",
 CellChangeTimes->{{3.466488973973329*^9, 3.466488980638084*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"JordanDecomposition", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "Det"}], ")"}], "//", 
    "FullSimplify"}], "//", "PowerExpand"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.5457411933287907`*^9, 3.545741272821745*^9}, 
   3.550904744773076*^9, {3.550904797186686*^9, 3.550904812038546*^9}, {
   3.5509050147086067`*^9, 3.550905017091503*^9}, 3.550905558139371*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"8", " ", "\[Mu]C"}], 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SqrtBox["\[Mu]L"], " ", 
    SqrtBox["\[Mu]S"]}]]}]], "Output",
 CellChangeTimes->{{3.545741193859439*^9, 3.545741273398077*^9}, 
   3.550641544596936*^9, 3.550641745542164*^9, 3.5506450840201473`*^9, 
   3.550645148894466*^9, 3.550904538402347*^9, {3.5509048009917717`*^9, 
   3.550904817152052*^9}, 3.550905019814639*^9, 3.550905570631666*^9, 
   3.5509056385884438`*^9, 3.55090684131229*^9, 3.550917707856657*^9, 
   3.5509187336462793`*^9, 3.55099092989153*^9, 3.5511053763482103`*^9, 
   3.551170520636649*^9, {3.551172276560841*^9, 3.551172293053218*^9}, 
   3.5511723389706573`*^9, 3.5511725927648363`*^9, 3.653035720752736*^9, 
   3.653035874529245*^9, 3.6715925105435457`*^9, 3.6732288711600924`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"JordanDecomposition", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "//", "FullSimplify"}], "//", 
     "PowerExpand"}], ")"}], "//", "Simplify"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.466338730029462*^9, 3.4663387764430304`*^9}, {
   3.466338816768654*^9, 3.466338854168943*^9}, {3.466338901705657*^9, 
   3.466338904696612*^9}, 3.550904853505677*^9, {3.550905027377096*^9, 
   3.550905030593708*^9}, 3.550905648003536*^9, {3.550918745365481*^9, 
   3.550918747270824*^9}, 3.551172335618518*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]s"}], "0", "0", "0", "0", "0", 
      "0", "0"},
     {"0", 
      RowBox[{"\[Alpha]", "+", "\[Beta]s"}], "0", "0", "0", "0", "0", "0"},
     {"0", "0", 
      RowBox[{"\[Beta]s", "-", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]C"]}]}], "0", "0", "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"\[Beta]s", "+", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]C"]}]}], "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"\[Beta]s", "-", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]L"]}]}], "0", "0", "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"\[Beta]s", "+", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]L"]}]}], "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"\[Beta]s", "-", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]C"], " ", 
        SqrtBox["\[Mu]S"]}]}], "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"\[Beta]s", "+", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]C"], " ", 
        SqrtBox["\[Mu]S"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.4663387858214197`*^9, {3.466338825765308*^9, 3.466338842209264*^9}, {
   3.466338895632474*^9, 3.466338905476017*^9}, {3.466339154715126*^9, 
   3.466339187767703*^9}, 3.466339351876638*^9, {3.466339728516007*^9, 
   3.466339753369347*^9}, 3.4663398146925917`*^9, {3.46633993347283*^9, 
   3.466339950901986*^9}, 3.4663423108274508`*^9, {3.466424560962785*^9, 
   3.466424571633238*^9}, 3.4664246818503304`*^9, {3.4664247368622637`*^9, 
   3.466424804622072*^9}, 3.466424923778781*^9, 3.4664250266568613`*^9, 
   3.4664251706513767`*^9, 3.4664253140332413`*^9, 3.46642538611845*^9, 
   3.46642557287819*^9, {3.4664258686809177`*^9, 3.466425883871943*^9}, {
   3.4664266591358223`*^9, 3.466426749809803*^9}, {3.46642701504699*^9, 
   3.466427044949988*^9}, 3.4664299530887737`*^9, {3.466430014191313*^9, 
   3.466430030174282*^9}, {3.466430083130842*^9, 3.466430124517021*^9}, 
   3.466430256544715*^9, 3.4664303218696404`*^9, 3.466430387455513*^9, {
   3.466430611288946*^9, 3.466430624151155*^9}, {3.466431887091157*^9, 
   3.466431948446087*^9}, 3.466431987063115*^9, {3.466432058855335*^9, 
   3.4664320679482117`*^9}, {3.46643245939074*^9, 3.466432484475749*^9}, {
   3.4664325219098186`*^9, 3.466432528733369*^9}, {3.466432711930297*^9, 
   3.466432756665042*^9}, {3.4664328062664824`*^9, 3.4664328192254887`*^9}, {
   3.466433115586587*^9, 3.466433184577218*^9}, {3.466433466956668*^9, 
   3.466433477064505*^9}, {3.466434179842926*^9, 3.466434201153859*^9}, 
   3.4664343196090603`*^9, 3.466434380482922*^9, 3.466488932171443*^9, 
   3.46674867671524*^9, 3.476521109257751*^9, 3.5457198433291473`*^9, 
   3.5506415451381187`*^9, 3.5506417464810047`*^9, 3.55064508459715*^9, 
   3.5506451495266333`*^9, 3.550904559689889*^9, 3.550904856310804*^9, 
   3.550905031523098*^9, 3.55090565477343*^9, 3.550906844871303*^9, {
   3.5509187366207523`*^9, 3.550918748121614*^9}, 3.550990932606785*^9, 
   3.551105394691268*^9, 3.551170523350787*^9, 3.551172276766705*^9, {
   3.551172336061112*^9, 3.5511723396051483`*^9}, 3.55117259285845*^9, 
   3.653035729513226*^9, 3.653035874674569*^9, 3.671592510692417*^9, 
   3.673228871321602*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Check the determinant of the E'values", "Text",
 CellChangeTimes->{{3.4664889868161707`*^9, 3.4664890020497837`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], "]"}], "//", 
    "FullSimplify"}], "//", "PowerExpand"}], ")"}]], "Input",
 CellChangeTimes->{{3.466425041811167*^9, 3.466425061569468*^9}, {
   3.466425179153634*^9, 3.466425237823708*^9}, 3.466425319908804*^9, 
   3.466434387033725*^9, {3.466488944084564*^9, 3.4664889473104763`*^9}, 
   3.5457411833237553`*^9, {3.5506417627100067`*^9, 3.550641772477261*^9}, 
   3.550905076277314*^9, 3.550905663039372*^9, 3.550912612944282*^9, {
   3.551172345096754*^9, 3.5511723472143717`*^9}, 3.653035747230893*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"8", " ", "\[Mu]C"}], 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SqrtBox["\[Mu]L"], " ", 
    SqrtBox["\[Mu]S"]}]]}]], "Output",
 CellChangeTimes->{
  3.653035747560431*^9, 3.653035878311598*^9, 3.671592513056958*^9, {
   3.673228874085766*^9, 3.673228891707786*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check speeds", "Text",
 CellChangeTimes->{{3.55110776301423*^9, 3.55110776957241*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Eigenvalues", "[", 
      RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], "//", "FullSimplify"}], "//",
     "PowerExpand"}], ")"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.466489099025548*^9, 3.466489117887825*^9}, 
   3.466760312029727*^9, {3.545719875979724*^9, 3.545719880933538*^9}, 
   3.545721627549797*^9, 3.550905086787017*^9, {3.5509061903874903`*^9, 
   3.550906192523952*^9}, {3.550906229758543*^9, 3.5509062319200497`*^9}, {
   3.550910446579699*^9, 3.550910455283206*^9}, 3.5509133037193823`*^9, {
   3.5509133970731707`*^9, 3.55091341564212*^9}, {3.550918121466367*^9, 
   3.5509181246899776`*^9}, {3.550918157540703*^9, 3.550918159212628*^9}, 
   3.550918719595001*^9, {3.550918954587884*^9, 3.55091896900716*^9}, 
   3.550919030036717*^9, 3.55117236368505*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]s"}]},
      {
       RowBox[{"\[Alpha]", "+", "\[Beta]s"}]},
      {
       RowBox[{"\[Beta]s", "-", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]C"]}]}]},
      {
       RowBox[{"\[Beta]s", "+", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]C"]}]}]},
      {
       RowBox[{"\[Beta]s", "-", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]L"]}]}]},
      {
       RowBox[{"\[Beta]s", "+", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]L"]}]}]},
      {
       RowBox[{"\[Beta]s", "-", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]C"], " ", 
         SqrtBox["\[Mu]S"]}]}]},
      {
       RowBox[{"\[Beta]s", "+", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]C"], " ", 
         SqrtBox["\[Mu]S"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.550918954819253*^9, 3.550918980126018*^9}, 
   3.5509190303630342`*^9, 3.550924530912046*^9, 3.550990945466043*^9, 
   3.551105409475675*^9, 3.5511705254524603`*^9, 3.551172363941305*^9, 
   3.551172598630437*^9, 3.6530357548173532`*^9, 3.67159251642727*^9, 
   3.6732288990268803`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvectors", "Text",
 CellChangeTimes->{{3.551107780617405*^9, 3.5511077925865173`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Eigenvectors", "[", "PPS", "]"}], "//", "Det"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Alpha]", ">", "0"}], "}"}]}], "]"}], "//", "PowerExpand"}],
     "//", "FullSimplify"}], ")"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.5457412938093777`*^9, 3.545741346022263*^9}, {
   3.5506430318561163`*^9, 3.550643107427579*^9}, 3.550905112321537*^9, {
   3.550906310993032*^9, 3.550906335604528*^9}, {3.550918199710471*^9, 
   3.55091821954008*^9}, 3.550918723884256*^9, {3.5511723699999437`*^9, 
   3.5511723721594553`*^9}, {3.551172977839654*^9, 3.551172992859069*^9}, 
   3.653035767895645*^9, 3.6530358854551573`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"32", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SqrtBox["\[Mu]S"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]L", "-", 
       RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], "2"]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Eta]L"}], ")"}], "2"], " ", 
    SuperscriptBox["\[Mu]C", "3"], " ", 
    SqrtBox["\[Mu]L"]}]]}]], "Output",
 CellChangeTimes->{3.65303588576729*^9, 3.671592519124041*^9, 
  3.673228905587059*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Construct characteristic variables", "Text",
 CellChangeTimes->{{3.466489019004558*^9, 3.466489043953109*^9}, {
  3.466748681512586*^9, 3.4667486834178143`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigenvectors", "[", 
       RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], "//",
     "Simplify"}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.466339357524541*^9, 3.466339410497076*^9}, 
   3.4663394881056433`*^9, 3.466339731243134*^9, {3.466339830900556*^9, 
   3.466339862988284*^9}, 3.4663424278895817`*^9, {3.466424562270632*^9, 
   3.46642456758596*^9}, {3.466424604640932*^9, 3.466424609271843*^9}, 
   3.4664247528002043`*^9, {3.466425031137611*^9, 3.466425046604754*^9}, 
   3.46642532171198*^9, {3.466425898233371*^9, 3.466426014094941*^9}, {
   3.4664343629207907`*^9, 3.4664343889572687`*^9}, 3.466434509128551*^9, {
   3.466489049493657*^9, 3.466489067597581*^9}, {3.4664891455656557`*^9, 
   3.466489152205656*^9}, {3.466507636436885*^9, 3.4665076398348*^9}, {
   3.466507933301776*^9, 3.466507948128701*^9}, 3.4665087347786493`*^9, {
   3.466510584641994*^9, 3.466510590752926*^9}, 3.466510666689622*^9, {
   3.4667487981790752`*^9, 3.4667488012576714`*^9}, {3.466749479301639*^9, 
   3.466749481217656*^9}, 3.466760286269629*^9, 3.545719882835446*^9, {
   3.545719998695434*^9, 3.545720031089219*^9}, {3.550905328873952*^9, 
   3.550905374252555*^9}, {3.55090544991957*^9, 3.550905486219309*^9}, {
   3.5509068009570208`*^9, 3.550906802074781*^9}, 3.5509112468296127`*^9, {
   3.5509142780499983`*^9, 3.550914282503585*^9}, {3.653035785303206*^9, 
   3.6530357899226913`*^9}, {3.653035944271141*^9, 3.653035974703198*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["D\[Gamma]qq", "2"], "+", "Kqq"}]], "Output",
 CellChangeTimes->{{3.6530359572810297`*^9, 3.653035992295615*^9}, 
   3.671592521669298*^9, 3.673228912473426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
     ")"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", "uS", ",", "FullSimplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.466510645909053*^9, 3.4665106594496527`*^9}, {
   3.466748819504241*^9, 3.466748823065639*^9}, 3.466760290750696*^9, 
   3.545719891903822*^9, {3.545720040192046*^9, 3.545720040391683*^9}, 
   3.545736947453858*^9, {3.5506418453112593`*^9, 3.550641851130069*^9}, 
   3.550906104346451*^9, 3.5509063595552683`*^9, 3.550911251481394*^9, {
   3.5509142883320303`*^9, 3.550914290684752*^9}, 3.653036002079844*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["D\[Gamma]qq", "2"]}], "+", "Kqq"}]], "Output",
 CellChangeTimes->{3.653036002945158*^9, 3.671592521783383*^9, 
  3.673228913016738*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
     ")"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", "uS", ",", "FullSimplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.466748840457593*^9, 3.466760288124649*^9, 3.545719886542058*^9, {
   3.54572003545603*^9, 3.545720035627223*^9}, 3.5509069755384893`*^9, 
   3.5509112489660683`*^9, {3.5509142841768913`*^9, 3.550914286626637*^9}, 
   3.653035949726829*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["D\[Gamma]qq", "2"]}], "+", "Zs", "-", 
  RowBox[{"Theta", " ", 
   SqrtBox["\[Mu]C"]}]}]], "Output",
 CellChangeTimes->{3.65303595011553*^9, 3.653035997174603*^9, 
  3.671592521839813*^9, 3.673228913568495*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
     ")"}], "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", "uS", ",", "FullSimplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.466748852040537*^9, 3.466760292153713*^9, 3.545719893372231*^9, {
   3.545720044972555*^9, 3.545720047864373*^9}, 3.5457369497482233`*^9, {
   3.5506418474898567`*^9, 3.550641852604926*^9}, 3.550906109747431*^9, 
   3.55090636603209*^9, 3.550911253614884*^9, {3.550914292407237*^9, 
   3.550914294483221*^9}, 3.6530360043430357`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["D\[Gamma]qq", "2"]}], "+", "Zs", "+", 
  RowBox[{"Theta", " ", 
   SqrtBox["\[Mu]C"]}]}]], "Output",
 CellChangeTimes->{3.6530360047487698`*^9, 3.671592521898074*^9, 
  3.673228914104043*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
   ")"}], "[", 
  RowBox[{"[", "5", "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.550923683530792*^9, {3.551172387817593*^9, 3.551172422908002*^9}, {
   3.653036058590824*^9, 3.653036060492133*^9}}],

Cell[BoxData[
 RowBox[{"Khat", "+", 
  FractionBox["D\[Alpha]", 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]L"]}]]}]], "Output",
 CellChangeTimes->{{3.550923672126593*^9, 3.550923684302442*^9}, 
   3.55110547701482*^9, 3.551170538812199*^9, {3.551172376972856*^9, 
   3.55117242331708*^9}, 3.551172463372567*^9, 3.5511726056217623`*^9, 
   3.551175758231851*^9, 3.653035774496997*^9, 3.653036007492283*^9, {
   3.65303604832542*^9, 3.653036061092175*^9}, 3.671592521958726*^9, 
   3.673228914637343*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
   ")"}], "[", 
  RowBox[{"[", "6", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.550922982356749*^9, 3.550923129138686*^9}, {
   3.550923201916654*^9, 3.550923260223309*^9}, {3.5509232917963943`*^9, 
   3.550923299187028*^9}, 3.551172398158408*^9, 3.551172431382269*^9, {
   3.6530360671755867`*^9, 3.653036071972114*^9}}],

Cell[BoxData[
 RowBox[{"Khat", "-", 
  FractionBox["D\[Alpha]", 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]L"]}]]}]], "Output",
 CellChangeTimes->{{3.550922987948201*^9, 3.550923059466612*^9}, {
   3.5509230916449842`*^9, 3.5509231317401047`*^9}, {3.550923203925071*^9, 
   3.550923263039734*^9}, {3.550923295421956*^9, 3.550923301594523*^9}, {
   3.550923669055787*^9, 3.5509236877467813`*^9}, 3.551105487092442*^9, 
   3.551170541106868*^9, {3.5511723770553293`*^9, 3.551172398515307*^9}, 
   3.5511724316436253`*^9, 3.5511724639046373`*^9, 3.5511726057146053`*^9, 
   3.551175758335773*^9, 3.653035774692317*^9, 3.653036010952838*^9, 
   3.653036072703986*^9, 3.671592522010586*^9, 3.6732289151345*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
     ")"}], "[", 
    RowBox[{"[", "7", "]"}], "]"}], ",", "\[Mu]S", ",", "FullSimplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.550925490897654*^9, 3.551172405339603*^9, 3.551172438479826*^9, {
   3.551172516249427*^9, 3.551172531543692*^9}, {3.653036079016363*^9, 
   3.6530361173575068`*^9}}],

Cell[BoxData[
 RowBox[{"hatGams", "-", 
  FractionBox[
   RowBox[{"D\[Beta]s", " ", 
    SqrtBox["\[Mu]C"]}], 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]S"]}]], "+", 
  FractionBox[
   RowBox[{"D\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]C"}], "+", 
      RowBox[{"\[Eta]L", " ", "\[Mu]C"}]}], ")"}]}], 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]L", "-", 
      RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"Khat", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Eta]L", " ", 
       SqrtBox["\[Mu]C"], " ", "\[Mu]L"}], "-", 
      RowBox[{
       SuperscriptBox["\[Mu]C", 
        RowBox[{"3", "/", "2"}]], " ", "\[Mu]S"}]}], ")"}]}], 
   RowBox[{
    SqrtBox["\[Mu]S"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]L"}], "+", 
      RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.550925493069682*^9, 3.551105505123128*^9, 3.551170544593849*^9, {
   3.551172377354142*^9, 3.551172405745223*^9}, {3.551172438745646*^9, 
   3.551172464794079*^9}, {3.5511725174060173`*^9, 3.551172545369401*^9}, 
   3.551172605818386*^9, 3.551172949308868*^9, 3.551175758394643*^9, 
   3.653035775193965*^9, 3.6530360132929897`*^9, {3.653036079513933*^9, 
   3.6530361177252502`*^9}, 3.671592522052842*^9, 3.6732289156075974`*^9, 
   3.673228985123054*^9}]
}, Open  ]],

Cell[TextData[{
 "The above condition can be written as:  ",
 Cell[BoxData[
  RowBox[{"hatGams", "-", 
   FractionBox[
    RowBox[{"D\[Beta]s", " ", 
     SqrtBox["\[Mu]C"]}], 
    RowBox[{"\[Alpha]", " ", 
     SqrtBox["\[Mu]S"]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"(", 
      RowBox[{"\[Mu]L", "-", 
       RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]], 
    FractionBox[
     RowBox[{" ", 
      SqrtBox["\[Mu]C"]}], 
     SqrtBox["\[Mu]S"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"\[Mu]C", " ", "\[Mu]S"}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Eta]L"}], ")"}], 
       FractionBox["D\[Alpha]", 
        RowBox[{"\[Alpha]", " "}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", 
         RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], "Khat"}]}], " ", 
     ")"}]}]}]],
  CellChangeTimes->{{3.653037381972046*^9, 3.653037526336502*^9}, {
    3.653037606512431*^9, 3.6530376430745*^9}, {3.6530376772083893`*^9, 
    3.653037685879774*^9}, 3.6715925319253187`*^9}]
}], "Text",
 CellChangeTimes->{{3.673229100690645*^9, 3.67322913169646*^9}, {
  3.67322920193223*^9, 3.673229203438699*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "PPS", "]"}], "]"}], ".", "uS"}], ")"}], 
     ")"}], "[", 
    RowBox[{"[", "8", "]"}], "]"}], ",", "\[Mu]S", ",", "FullSimplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.653036141381279*^9, {3.653037706036696*^9, 3.653037752033445*^9}}],

Cell[BoxData[
 RowBox[{"hatGams", "+", 
  FractionBox[
   RowBox[{"D\[Beta]s", " ", 
    SqrtBox["\[Mu]C"]}], 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]S"]}]], "+", 
  FractionBox[
   RowBox[{"D\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]C"}], "+", 
      RowBox[{"\[Eta]L", " ", "\[Mu]C"}]}], ")"}]}], 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]L", "-", 
      RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"Khat", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Eta]L"}], " ", 
       SqrtBox["\[Mu]C"], " ", "\[Mu]L"}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]C", 
        RowBox[{"3", "/", "2"}]], " ", "\[Mu]S"}]}], ")"}]}], 
   RowBox[{
    SqrtBox["\[Mu]S"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]L"}], "+", 
      RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.653036141772764*^9, {3.6530377193781137`*^9, 3.653037752409988*^9}, 
   3.671592522182084*^9, 3.67322893120185*^9, 3.673229143340269*^9}]
}, Open  ]],

Cell[TextData[{
 "The above condition can be written as: ",
 Cell[BoxData[
  RowBox[{"hatGams", "+", 
   FractionBox[
    RowBox[{"D\[Beta]s", " ", 
     SqrtBox["\[Mu]C"]}], 
    RowBox[{"\[Alpha]", " ", 
     SqrtBox["\[Mu]S"]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"(", 
      RowBox[{"\[Mu]L", "-", 
       RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}]], 
    FractionBox[
     RowBox[{" ", 
      SqrtBox["\[Mu]C"]}], 
     SqrtBox["\[Mu]S"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"\[Mu]C", " ", "\[Mu]S"}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Eta]L"}], ")"}], 
       FractionBox["D\[Alpha]", 
        RowBox[{"\[Alpha]", " "}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Eta]L", " ", "\[Mu]L"}], "-", 
         RowBox[{"\[Mu]C", " ", "\[Mu]S"}]}], ")"}], "Khat"}]}], " ", 
     ")"}]}]}]],
  CellChangeTimes->{{3.653037758054294*^9, 3.6530377594307632`*^9}, 
    3.671592537759406*^9, {3.673229146033494*^9, 3.6732291845309362`*^9}}]
}], "Text",
 CellChangeTimes->{{3.673229100690645*^9, 3.67322913169646*^9}, {
  3.67322920007668*^9, 3.67322920955869*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Vector Sector", "Subsubsection",
 CellChangeTimes->{{3.466338036607253*^9, 3.466338038218553*^9}, {
  3.466338073237733*^9, 3.466338075298904*^9}, {3.4667741623276176`*^9, 
  3.466774165339857*^9}}],

Cell[CellGroupData[{

Cell["Define scalar variables and PP", "Text",
 CellChangeTimes->{{3.466488954440176*^9, 3.466488963580868*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uA", "=", 
   RowBox[{"{", 
    RowBox[{"D\[Beta]A", ",", "GamA", ",", "KsA", ",", "ZA"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4663380885744677`*^9, 3.466338107090262*^9}, {
  3.466338293237855*^9, 3.466338343712699*^9}, {3.4667743268294497`*^9, 
  3.4667743745685453`*^9}, {3.4667753942892942`*^9, 3.466775408365588*^9}, {
  3.545737744415215*^9, 3.5457377749097424`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PPA", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Beta]s", ",", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], "\[Mu]S"}], ",", "0", ",", "0"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Beta]s", ",", "0", ",", "0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "\[Beta]s", ",", "\[Alpha]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", "\[Alpha]", ",", "\[Beta]s"}], "}"}]}],
     "\[IndentingNewLine]", "}"}]}], ";", 
  RowBox[{
   RowBox[{"MatrixForm", "[", "PPA", "]"}], "//", "FullSimplify"}]}]], "Input",\

 CellChangeTimes->{{3.466338082200343*^9, 3.466338171697723*^9}, {
   3.466338346464651*^9, 3.466338537715082*^9}, {3.4663385859056063`*^9, 
   3.466338592614253*^9}, {3.466338643585685*^9, 3.4663387221027393`*^9}, 
   3.4663388013499928`*^9, 3.466338974113709*^9, {3.466339028097637*^9, 
   3.466339035073803*^9}, {3.4663391408072433`*^9, 3.466339145360198*^9}, 
   3.466339185887025*^9, {3.466339346113693*^9, 3.466339349591434*^9}, {
   3.466339740153556*^9, 3.4663397511940193`*^9}, {3.466339801016638*^9, 
   3.4663398133292418`*^9}, {3.466339929377377*^9, 3.46633994874726*^9}, 
   3.466342309574445*^9, 3.46642450220422*^9, 3.4664245551869507`*^9, 
   3.466424679201673*^9, 3.466424733793563*^9, {3.466424769208419*^9, 
   3.4664247994571333`*^9}, 3.4664249221285477`*^9, 3.466425025077598*^9, 
   3.4664253124971037`*^9, 3.4664253846818037`*^9, {3.466425559014119*^9, 
   3.46642556461994*^9}, {3.466425866749668*^9, 3.466425874895287*^9}, 
   3.4664266577775927`*^9, {3.466426719940617*^9, 3.466426747780582*^9}, {
   3.46642701198166*^9, 3.466427043144237*^9}, {3.4664299479959297`*^9, 
   3.466429972839308*^9}, 3.466430018957588*^9, {3.466430073453639*^9, 
   3.4664300814702377`*^9}, {3.466430118882469*^9, 3.466430123141622*^9}, {
   3.466430189328245*^9, 3.466430254617558*^9}, {3.4664303198256617`*^9, 
   3.466430319956855*^9}, {3.466430579492569*^9, 3.4664306223093233`*^9}, {
   3.46643169052168*^9, 3.4664316979404182`*^9}, 3.466431885825563*^9, {
   3.4664319312371483`*^9, 3.466431955408647*^9}, {3.4664320574535933`*^9, 
   3.466432066984577*^9}, {3.466432457744561*^9, 3.466432489636566*^9}, {
   3.466432519909581*^9, 3.466432520255745*^9}, {3.4664327105655737`*^9, 
   3.466432755381548*^9}, {3.466432804313814*^9, 3.4664328181205473`*^9}, {
   3.466433114253559*^9, 3.466433162557366*^9}, {3.4664334654457693`*^9, 
   3.466433475541626*^9}, {3.4664341922080584`*^9, 3.466434199576647*^9}, {
   3.466774376789678*^9, 3.466774447870776*^9}, {3.4667744828926477`*^9, 
   3.466774494192585*^9}, {3.4667746062976933`*^9, 3.466774622878333*^9}, {
   3.466775374234644*^9, 3.466775383748125*^9}, {3.545738389871181*^9, 
   3.545738427161518*^9}, {3.54574018730956*^9, 3.545740215071924*^9}, 
   3.5457402467452307`*^9, 3.653037046484988*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Beta]s", 
      RowBox[{
       SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]S"}], "0", "0"},
     {"1", "\[Beta]s", "0", "0"},
     {"0", "0", "\[Beta]s", "\[Alpha]"},
     {"0", "0", "\[Alpha]", "\[Beta]s"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.46643245844135*^9, 3.466432483966119*^9}, {
   3.466432521113399*^9, 3.4664325273345537`*^9}, {3.4664327112022257`*^9, 
   3.466432755762356*^9}, {3.466432804654469*^9, 3.466432818497322*^9}, {
   3.4664331148079443`*^9, 3.4664331832998543`*^9}, {3.4664334661801863`*^9, 
   3.4664334759531193`*^9}, {3.466434178893457*^9, 3.466434200238716*^9}, 
   3.466434318305369*^9, 3.4664343790892067`*^9, 3.4664889319720087`*^9, 
   3.4667486765132427`*^9, {3.466774489970922*^9, 3.466774494573216*^9}, 
   3.466774623825861*^9, 3.4667751345719433`*^9, {3.4667753844858503`*^9, 
   3.4667754108604116`*^9}, 3.466775555085555*^9, {3.545740243453115*^9, 
   3.5457402647403307`*^9}, 3.6530370476978693`*^9, 3.671592548499563*^9, 
   3.673229300330264*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check the Jordan decomposition", "Text",
 CellChangeTimes->{{3.466488973973329*^9, 3.466488980638084*^9}, {
  3.466774624743132*^9, 3.466774626378656*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"JordanDecomposition", "[", 
      RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", "MatrixForm"}], "//", 
   "FullSimplify"}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.466338730029462*^9, 3.4663387764430304`*^9}, {
   3.466338816768654*^9, 3.466338854168943*^9}, {3.466338901705657*^9, 
   3.466338904696612*^9}, 3.466774504093563*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]s"}], "0", "0", "0"},
     {"0", 
      RowBox[{"\[Alpha]", "+", "\[Beta]s"}], "0", "0"},
     {"0", "0", 
      RowBox[{"\[Beta]s", "-", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]S"]}]}], "0"},
     {"0", "0", "0", 
      RowBox[{"\[Beta]s", "+", 
       RowBox[{"\[Alpha]", " ", 
        SqrtBox["\[Mu]S"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.4663387858214197`*^9, {3.466338825765308*^9, 3.466338842209264*^9}, {
   3.466338895632474*^9, 3.466338905476017*^9}, {3.466339154715126*^9, 
   3.466339187767703*^9}, 3.466339351876638*^9, {3.466339728516007*^9, 
   3.466339753369347*^9}, 3.4663398146925917`*^9, {3.46633993347283*^9, 
   3.466339950901986*^9}, 3.4663423108274508`*^9, {3.466424560962785*^9, 
   3.466424571633238*^9}, 3.4664246818503304`*^9, {3.4664247368622637`*^9, 
   3.466424804622072*^9}, 3.466424923778781*^9, 3.4664250266568613`*^9, 
   3.4664251706513767`*^9, 3.4664253140332413`*^9, 3.46642538611845*^9, 
   3.46642557287819*^9, {3.4664258686809177`*^9, 3.466425883871943*^9}, {
   3.4664266591358223`*^9, 3.466426749809803*^9}, {3.46642701504699*^9, 
   3.466427044949988*^9}, 3.4664299530887737`*^9, {3.466430014191313*^9, 
   3.466430030174282*^9}, {3.466430083130842*^9, 3.466430124517021*^9}, 
   3.466430256544715*^9, 3.4664303218696404`*^9, 3.466430387455513*^9, {
   3.466430611288946*^9, 3.466430624151155*^9}, {3.466431887091157*^9, 
   3.466431948446087*^9}, 3.466431987063115*^9, {3.466432058855335*^9, 
   3.4664320679482117`*^9}, {3.46643245939074*^9, 3.466432484475749*^9}, {
   3.4664325219098186`*^9, 3.466432528733369*^9}, {3.466432711930297*^9, 
   3.466432756665042*^9}, {3.4664328062664824`*^9, 3.4664328192254887`*^9}, {
   3.466433115586587*^9, 3.466433184577218*^9}, {3.466433466956668*^9, 
   3.466433477064505*^9}, {3.466434179842926*^9, 3.466434201153859*^9}, 
   3.4664343196090603`*^9, 3.466434380482922*^9, 3.466488932171443*^9, 
   3.46674867671524*^9, {3.466774499134819*^9, 3.466774504514076*^9}, 
   3.466774629841378*^9, 3.466775555098179*^9, {3.54574025432376*^9, 
   3.54574026613197*^9}, 3.653037072008461*^9, 3.671592550712304*^9, 
   3.673229303425531*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check the determinant of the E'values", "Text",
 CellChangeTimes->{{3.4664889868161707`*^9, 3.4664890020497837`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Eigenvectors", "[", 
     RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], "]"}], "//", 
   "FullSimplify"}], ")"}]], "Input",
 CellChangeTimes->{{3.466425041811167*^9, 3.466425061569468*^9}, {
   3.466425179153634*^9, 3.466425237823708*^9}, 3.466425319908804*^9, 
   3.466434387033725*^9, {3.466488944084564*^9, 3.4664889473104763`*^9}, 
   3.46677451234159*^9, 3.46677457353726*^9, {3.671592554664509*^9, 
   3.671592557774317*^9}, 3.673229308626833*^9}],

Cell[BoxData[
 FractionBox["4", 
  RowBox[{"\[Alpha]", " ", 
   SqrtBox["\[Mu]S"]}]]], "Output",
 CellChangeTimes->{3.673229309102509*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Eigenvalues", "[", "PPA", "]"}], "//", "FullSimplify"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.466489521420698*^9, 3.466489522521988*^9}, 
   3.466760317777759*^9, {3.466774517473724*^9, 3.4667745204256077`*^9}, 
   3.545740976310611*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]s"}]},
      {
       RowBox[{"\[Alpha]", "+", "\[Beta]s"}]},
      {
       RowBox[{"\[Beta]s", "-", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]S"]}]}]},
      {
       RowBox[{"\[Beta]s", "+", 
        RowBox[{"\[Alpha]", " ", 
         SqrtBox["\[Mu]S"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.545740976638435*^9, 3.653037084834043*^9, 
  3.6715925623402653`*^9, 3.6732293190843763`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Construct characteristic variables", "Text",
 CellChangeTimes->{{3.466489019004558*^9, 3.466489043953109*^9}, {
  3.466748681512586*^9, 3.4667486834178143`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigenvectors", "[", 
       RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], ".", "uA"}], ")"}], "//",
     "FullSimplify"}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.466339357524541*^9, 3.466339410497076*^9}, 
   3.4663394881056433`*^9, 3.466339731243134*^9, {3.466339830900556*^9, 
   3.466339862988284*^9}, 3.4663424278895817`*^9, {3.466424562270632*^9, 
   3.46642456758596*^9}, {3.466424604640932*^9, 3.466424609271843*^9}, 
   3.4664247528002043`*^9, {3.466425031137611*^9, 3.466425046604754*^9}, 
   3.46642532171198*^9, {3.466425898233371*^9, 3.466426014094941*^9}, {
   3.4664343629207907`*^9, 3.4664343889572687`*^9}, 3.466434509128551*^9, {
   3.466489049493657*^9, 3.466489067597581*^9}, {3.4664891455656557`*^9, 
   3.466489152205656*^9}, {3.466507636436885*^9, 3.4665076398348*^9}, {
   3.466507933301776*^9, 3.466507948128701*^9}, 3.4665087347786493`*^9, {
   3.466510584641994*^9, 3.466510590752926*^9}, 3.466510666689622*^9, {
   3.4667487981790752`*^9, 3.4667488012576714`*^9}, {3.466749479301639*^9, 
   3.466749481217656*^9}, 3.466760286269629*^9, {3.466774545586419*^9, 
   3.46677454706903*^9}, 3.4667751589016447`*^9, 3.466775440841407*^9, {
   3.545740810894315*^9, 3.545740826223111*^9}, 3.545741142912393*^9, {
   3.653037095737804*^9, 3.653037108953699*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "KsA"}], "+", "ZA"}]], "Output",
 CellChangeTimes->{{3.6530370969130173`*^9, 3.65303710956024*^9}, 
   3.671592565843443*^9, 3.673229337282291*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigenvectors", "[", 
       RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], ".", "uA"}], ")"}], "//",
     "FullSimplify"}], ")"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.466510645909053*^9, 3.4665106594496527`*^9}, {
   3.466748819504241*^9, 3.466748823065639*^9}, 3.466760290750696*^9, {
   3.4667745529976673`*^9, 3.466774555891759*^9}, {3.466774666985704*^9, 
   3.466774705902462*^9}, {3.4667754336496677`*^9, 3.466775443795394*^9}, 
   3.54574113822313*^9, {3.653037124026976*^9, 3.65303712932727*^9}}],

Cell[BoxData[
 RowBox[{"KsA", "+", "ZA"}]], "Output",
 CellChangeTimes->{3.6530371308174047`*^9, 3.671592565899308*^9, 
  3.673229337360868*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigenvectors", "[", 
       RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], ".", "uA"}], ")"}], "//",
     "FullSimplify"}], ")"}], "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.466748840457593*^9, 3.466760288124649*^9, {3.4667745506735573`*^9, 
   3.466774551483225*^9}, {3.466774644877583*^9, 3.4667746485281763`*^9}, 
   3.46677509329405*^9, 3.4667754372523518`*^9, {3.4667755718215923`*^9, 
   3.466775579053643*^9}, 3.4667756189016943`*^9, {3.5457402711736593`*^9, 
   3.5457402724388523`*^9}, {3.545740828490959*^9, 3.545740851772031*^9}, 
   3.545741136737434*^9, {3.653037111995617*^9, 3.653037116800047*^9}}],

Cell[BoxData[
 RowBox[{"GamA", "-", 
  FractionBox["D\[Beta]A", 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]S"]}]]}]], "Output",
 CellChangeTimes->{{3.653037117115115*^9, 3.6530371329406033`*^9}, 
   3.671592565947132*^9, 3.673229337396853*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigenvectors", "[", 
       RowBox[{"Transpose", "[", "PPA", "]"}], "]"}], ".", "uA"}], ")"}], "//",
     "FullSimplify"}], ")"}], "[", 
  RowBox[{"[", "4", "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.466748852040537*^9, 3.466760292153713*^9, {3.466774559805579*^9, 
   3.466774561065291*^9}, 3.466774654848608*^9, 3.466775086482686*^9, 
   3.466775430689588*^9, 3.466775621961669*^9, 3.545740280684063*^9, {
   3.545740831386985*^9, 3.545740843421414*^9}, 3.545741140405064*^9, {
   3.653037135419908*^9, 3.653037139768845*^9}}],

Cell[BoxData[
 RowBox[{"GamA", "+", 
  FractionBox["D\[Beta]A", 
   RowBox[{"\[Alpha]", " ", 
    SqrtBox["\[Mu]S"]}]]}]], "Output",
 CellChangeTimes->{3.653037140057188*^9, 3.671592566025502*^9, 
  3.6732293374535227`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[TextData[{
 "The tensor sector has the same trivial form as always so we do not discuss \
it here. (",
 StyleBox["see paper",
  FontSlant->"Italic"],
 ")"
}], "Text",
 CellChangeTimes->{{3.653037167798277*^9, 3.653037207241061*^9}, {
   3.653037238453635*^9, 3.653037262761038*^9}, 3.653037849554941*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1306, 848},
WindowMargins->{{52, Automatic}, {Automatic, -10}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 118, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[688, 26, 1171, 19, 125, "Subtitle"],
Cell[CellGroupData[{
Cell[1884, 49, 153, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[2062, 55, 112, 1, 31, "Text"],
Cell[2177, 58, 446, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[2648, 72, 4795, 89, 309, "Input"],
Cell[7446, 163, 2609, 58, 175, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10104, 227, 112, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[10241, 232, 561, 14, 32, "Input"],
Cell[10805, 248, 846, 16, 55, "Output"]
}, Open  ]],
Cell[11666, 267, 686, 16, 32, "Input"],
Cell[12355, 285, 3817, 78, 184, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[16209, 368, 123, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[16357, 373, 672, 13, 32, "Input"],
Cell[17032, 388, 339, 10, 55, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[17420, 404, 92, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[17537, 409, 869, 16, 32, "Input"],
Cell[18409, 427, 1760, 53, 184, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[20218, 486, 96, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[20339, 491, 781, 17, 32, "Input"],
Cell[21123, 510, 565, 18, 62, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[21737, 534, 167, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[21929, 540, 1592, 27, 28, "Input"],
Cell[23524, 569, 199, 4, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23760, 578, 767, 17, 28, "Input"],
Cell[24530, 597, 191, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24758, 607, 599, 16, 28, "Input"],
Cell[25360, 625, 266, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25663, 637, 693, 17, 28, "Input"],
Cell[26359, 656, 247, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26643, 668, 379, 11, 28, "Input"],
Cell[27025, 681, 507, 10, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27569, 696, 502, 12, 28, "Input"],
Cell[28074, 710, 710, 12, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28821, 727, 530, 15, 28, "Input"],
Cell[29354, 744, 1394, 39, 57, "Output"]
}, Open  ]],
Cell[30763, 786, 1228, 38, 43, "Text"],
Cell[CellGroupData[{
Cell[32016, 828, 430, 13, 28, "Input"],
Cell[32449, 843, 1098, 35, 57, "Output"]
}, Open  ]],
Cell[33562, 881, 1177, 37, 43, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[34788, 924, 204, 3, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[35017, 931, 112, 1, 30, "Text"],
Cell[35132, 934, 423, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[35580, 947, 3025, 52, 130, "Input"],
Cell[38608, 1001, 1536, 32, 94, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[40193, 1039, 161, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[40379, 1045, 470, 11, 28, "Input"],
Cell[40852, 1058, 2747, 54, 98, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[43648, 1118, 123, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[43796, 1123, 531, 11, 28, "Input"],
Cell[44330, 1136, 138, 4, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44505, 1145, 304, 7, 28, "Input"],
Cell[44812, 1154, 1066, 32, 98, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[45927, 1192, 167, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[46119, 1198, 1420, 25, 28, "Input"],
Cell[47542, 1225, 186, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47765, 1234, 639, 14, 28, "Input"],
Cell[48407, 1250, 144, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48588, 1258, 743, 16, 28, "Input"],
Cell[49334, 1276, 248, 6, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49619, 1287, 632, 15, 28, "Input"],
Cell[50254, 1304, 223, 6, 52, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[50516, 1315, 309, 8, 28, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
